Module: Google::Apis::BackupdrV1

Defined in:
lib/google/apis/backupdr_v1.rb,
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/service.rb,
lib/google/apis/backupdr_v1/gem_version.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Backup and DR Service API

Defined Under Namespace

Classes: AbandonBackupRequest, AcceleratorConfig, AccessConfig, AdvancedMachineFeatures, AliasIpRange, AllocationAffinity, AlloyDbClusterBackupPlanAssociationProperties, AlloyDbClusterBackupProperties, AlloyDbClusterDataSourceProperties, AlloyDbClusterDataSourceReferenceProperties, AlloyDbPitrWindow, AttachedDisk, AuditConfig, AuditLogConfig, Backup, BackupApplianceBackupConfig, BackupApplianceBackupProperties, BackupApplianceLockInfo, BackupConfigDetails, BackupConfigInfo, BackupDrPlanConfig, BackupDrPlanRule, BackupDrTemplateConfig, BackupGcpResource, BackupLocation, BackupLock, BackupPlan, BackupPlanAssociation, BackupPlanRevision, BackupRule, BackupVault, BackupWindow, BackupdrService, Binding, CancelOperationRequest, CloudSqlInstanceBackupPlanAssociationProperties, CloudSqlInstanceBackupProperties, CloudSqlInstanceDataSourceProperties, CloudSqlInstanceDataSourceReferenceProperties, CloudSqlInstanceInitializationConfig, ComputeInstanceBackupPlanProperties, ComputeInstanceBackupProperties, ComputeInstanceDataSourceProperties, ComputeInstanceRestoreProperties, ComputeInstanceTargetEnvironment, ConfidentialInstanceConfig, CustomerEncryptionKey, DataSource, DataSourceBackupApplianceApplication, DataSourceBackupConfigInfo, DataSourceGcpResource, DataSourceGcpResourceInfo, DataSourceReference, DiskBackupPlanProperties, DiskBackupProperties, DiskDataSourceProperties, DiskRestoreProperties, DiskTargetEnvironment, DisplayDevice, Empty, EncryptionConfig, EndTrialRequest, Entry, Expr, FetchAccessTokenRequest, FetchAccessTokenResponse, FetchBackupPlanAssociationsForResourceTypeResponse, FetchBackupsForResourceTypeResponse, FetchDataSourceReferencesForResourceTypeResponse, FetchMsComplianceMetadataRequest, FetchMsComplianceMetadataResponse, FetchUsableBackupVaultsResponse, FilestoreInstanceBackupPlanAssociationProperties, FilestoreInstanceBackupProperties, FilestoreInstanceDataSourceProperties, FilestoreInstanceDataSourceReferenceProperties, FinalizeBackupRequest, GcpBackupConfig, GcpBackupPlanInfo, GcpResource, GoogleCloudBackupdrV1OperationMetadata, GuestOsFeature, InitializeParams, InitializeServiceRequest, InitiateBackupRequest, InitiateBackupResponse, InstanceParams, ListBackupPlanAssociationsResponse, ListBackupPlanRevisionsResponse, ListBackupPlansResponse, ListBackupVaultsResponse, ListBackupsResponse, ListDataSourceReferencesResponse, ListDataSourcesResponse, ListLocationsResponse, ListManagementServersResponse, ListOperationsResponse, ListResourceBackupConfigsResponse, Location, LocationMetadata, ManagementServer, ManagementUri, Metadata, NetworkConfig, NetworkInterface, NetworkPerformanceConfig, NodeAffinity, Operation, PitrSettings, Policy, RegionDiskTargetEnvironment, RemoveDataSourceRequest, ResourceBackupConfig, RestoreBackupRequest, RestoreBackupResponse, RuleConfigInfo, Scheduling, SchedulingDuration, ServiceAccount, ServiceLockInfo, SetIamPolicyRequest, SetInternalStatusRequest, SetInternalStatusResponse, StandardSchedule, Status, SubscribeTrialRequest, Tags, TargetResource, TestIamPermissionsRequest, TestIamPermissionsResponse, Trial, TriggerBackupRequest, WeekDayOfMonth, WorkforceIdentityBasedManagementUri, WorkforceIdentityBasedOAuth2ClientId

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-backupdr_v1 gem

"0.54.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260408"
VERSION =

Version of the Backup and DR Service API this client connects to. This is NOT the gem version.

'V1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'