Class: Google::Apis::BackupdrV1::AlloyDbClusterBackupProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

AlloyDbClusterBackupProperties represents AlloyDB cluster backup properties. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlloyDbClusterBackupProperties

Returns a new instance of AlloyDbClusterBackupProperties.



350
351
352
# File 'lib/google/apis/backupdr_v1/classes.rb', line 350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chain_idString

Output only. The chain id of this backup. Backups belonging to the same chain are sharing the same chain id. This property is calculated and maintained by BackupDR. Corresponds to the JSON property chainId

Returns:

  • (String)


332
333
334
# File 'lib/google/apis/backupdr_v1/classes.rb', line 332

def chain_id
  @chain_id
end

#database_versionString

Output only. The PostgreSQL major version of the AlloyDB cluster when the backup was taken. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/backupdr_v1/classes.rb', line 338

def database_version
  @database_version
end

#descriptionString

An optional text description for the backup. Corresponds to the JSON property description

Returns:

  • (String)


343
344
345
# File 'lib/google/apis/backupdr_v1/classes.rb', line 343

def description
  @description
end

#stored_bytesFixnum

Output only. Storage usage of this particular backup Corresponds to the JSON property storedBytes

Returns:

  • (Fixnum)


348
349
350
# File 'lib/google/apis/backupdr_v1/classes.rb', line 348

def stored_bytes
  @stored_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



355
356
357
358
359
360
# File 'lib/google/apis/backupdr_v1/classes.rb', line 355

def update!(**args)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @database_version = args[:database_version] if args.key?(:database_version)
  @description = args[:description] if args.key?(:description)
  @stored_bytes = args[:stored_bytes] if args.key?(:stored_bytes)
end