Class: Google::Apis::BackupdrV1::AlloyDbClusterDataSourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

AlloyDBClusterDataSourceProperties represents the properties of a AlloyDB cluster resource that are stored in the DataSource. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlloyDbClusterDataSourceProperties

Returns a new instance of AlloyDbClusterDataSourceProperties.



290
291
292
# File 'lib/google/apis/backupdr_v1/classes.rb', line 290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_uidString

Output only. The cluster UID of the AlloyDB cluster backed up by the datasource. Corresponds to the JSON property clusterUid

Returns:

  • (String)


277
278
279
# File 'lib/google/apis/backupdr_v1/classes.rb', line 277

def cluster_uid
  @cluster_uid
end

#nameString

Output only. Name of the AlloyDB cluster backed up by the datasource. Corresponds to the JSON property name

Returns:

  • (String)


282
283
284
# File 'lib/google/apis/backupdr_v1/classes.rb', line 282

def name
  @name
end

#pitr_windowsArray<Google::Apis::BackupdrV1::AlloyDbPitrWindow>

Output only. Point in time recovery windows. The order is guaranteed to be ascending by start time. Corresponds to the JSON property pitrWindows



288
289
290
# File 'lib/google/apis/backupdr_v1/classes.rb', line 288

def pitr_windows
  @pitr_windows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



295
296
297
298
299
# File 'lib/google/apis/backupdr_v1/classes.rb', line 295

def update!(**args)
  @cluster_uid = args[:cluster_uid] if args.key?(:cluster_uid)
  @name = args[:name] if args.key?(:name)
  @pitr_windows = args[:pitr_windows] if args.key?(:pitr_windows)
end