Class: Google::Apis::BackupdrV1::AttachedDisk
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::AttachedDisk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#auto_delete ⇒ Boolean
(also: #auto_delete?)
Optional.
-
#boot ⇒ Boolean
(also: #boot?)
Optional.
-
#device_name ⇒ String
Optional.
-
#disk_encryption_key ⇒ Google::Apis::BackupdrV1::CustomerEncryptionKey
A customer-supplied encryption key.
-
#disk_interface ⇒ String
Optional.
-
#disk_size_gb ⇒ Fixnum
Optional.
-
#disk_type ⇒ String
Optional.
-
#disk_type_deprecated ⇒ String
Specifies the type of the disk.
-
#guest_os_feature ⇒ Array<Google::Apis::BackupdrV1::GuestOsFeature>
Optional.
-
#index ⇒ Fixnum
Optional.
-
#initialize_params ⇒ Google::Apis::BackupdrV1::InitializeParams
Specifies the parameters to initialize this disk.
-
#kind ⇒ String
Optional.
-
#license ⇒ Array<String>
Optional.
-
#mode ⇒ String
Optional.
-
#saved_state ⇒ String
Optional.
-
#source ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttachedDisk
constructor
A new instance of AttachedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttachedDisk
Returns a new instance of AttachedDisk.
494 495 496 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ Boolean Also known as: auto_delete?
Optional. Specifies whether the disk will be auto-deleted when the instance is
deleted (but not when the disk is detached from the instance).
Corresponds to the JSON property autoDelete
403 404 405 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 403 def auto_delete @auto_delete end |
#boot ⇒ Boolean Also known as: boot?
Optional. Indicates that this is a boot disk. The virtual machine will use the
first partition of the disk for its root filesystem.
Corresponds to the JSON property boot
410 411 412 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 410 def boot @boot end |
#device_name ⇒ String
Optional. This is used as an identifier for the disks. This is the unique name
has to provided to modify disk parameters like disk_name and replica_zones (in
case of RePDs)
Corresponds to the JSON property deviceName
418 419 420 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 418 def device_name @device_name end |
#disk_encryption_key ⇒ Google::Apis::BackupdrV1::CustomerEncryptionKey
A customer-supplied encryption key.
Corresponds to the JSON property diskEncryptionKey
423 424 425 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 423 def disk_encryption_key @disk_encryption_key end |
#disk_interface ⇒ String
Optional. Specifies the disk interface to use for attaching this disk.
Corresponds to the JSON property diskInterface
428 429 430 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 428 def disk_interface @disk_interface end |
#disk_size_gb ⇒ Fixnum
Optional. The size of the disk in GB.
Corresponds to the JSON property diskSizeGb
433 434 435 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 433 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Optional. Output only. The URI of the disk type resource. For example:
projects/project/zones/zone/diskTypes/pd-standard or pd-ssd
Corresponds to the JSON property diskType
439 440 441 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 439 def disk_type @disk_type end |
#disk_type_deprecated ⇒ String
Specifies the type of the disk.
Corresponds to the JSON property diskTypeDeprecated
444 445 446 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 444 def disk_type_deprecated @disk_type_deprecated end |
#guest_os_feature ⇒ Array<Google::Apis::BackupdrV1::GuestOsFeature>
Optional. A list of features to enable on the guest operating system.
Applicable only for bootable images.
Corresponds to the JSON property guestOsFeature
450 451 452 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 450 def guest_os_feature @guest_os_feature end |
#index ⇒ Fixnum
Optional. A zero-based index to this disk, where 0 is reserved for the boot
disk.
Corresponds to the JSON property index
456 457 458 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 456 def index @index end |
#initialize_params ⇒ Google::Apis::BackupdrV1::InitializeParams
Specifies the parameters to initialize this disk.
Corresponds to the JSON property initializeParams
461 462 463 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 461 def initialize_params @initialize_params end |
#kind ⇒ String
Optional. Type of the resource.
Corresponds to the JSON property kind
466 467 468 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 466 def kind @kind end |
#license ⇒ Array<String>
Optional. Any valid publicly visible licenses.
Corresponds to the JSON property license
471 472 473 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 471 def license @license end |
#mode ⇒ String
Optional. The mode in which to attach this disk.
Corresponds to the JSON property mode
476 477 478 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 476 def mode @mode end |
#saved_state ⇒ String
Optional. Output only. The state of the disk.
Corresponds to the JSON property savedState
481 482 483 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 481 def saved_state @saved_state end |
#source ⇒ String
Optional. Specifies a valid partial or full URL to an existing Persistent Disk
resource.
Corresponds to the JSON property source
487 488 489 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 487 def source @source end |
#type ⇒ String
Optional. Specifies the type of the disk.
Corresponds to the JSON property type
492 493 494 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 492 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 499 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @boot = args[:boot] if args.key?(:boot) @device_name = args[:device_name] if args.key?(:device_name) @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key) @disk_interface = args[:disk_interface] if args.key?(:disk_interface) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @disk_type_deprecated = args[:disk_type_deprecated] if args.key?(:disk_type_deprecated) @guest_os_feature = args[:guest_os_feature] if args.key?(:guest_os_feature) @index = args[:index] if args.key?(:index) @initialize_params = args[:initialize_params] if args.key?(:initialize_params) @kind = args[:kind] if args.key?(:kind) @license = args[:license] if args.key?(:license) @mode = args[:mode] if args.key?(:mode) @saved_state = args[:saved_state] if args.key?(:saved_state) @source = args[:source] if args.key?(:source) @type = args[:type] if args.key?(:type) end |