Class: Google::Apis::BackupdrV1::Backup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message describing a Backup object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backup

Returns a new instance of Backup.



738
739
740
# File 'lib/google/apis/backupdr_v1/classes.rb', line 738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alloy_db_backup_propertiesGoogle::Apis::BackupdrV1::AlloyDbClusterBackupProperties

AlloyDbClusterBackupProperties represents AlloyDB cluster backup properties. . Corresponds to the JSON property alloyDbBackupProperties



598
599
600
# File 'lib/google/apis/backupdr_v1/classes.rb', line 598

def alloy_db_backup_properties
  @alloy_db_backup_properties
end

#backup_appliance_backup_propertiesGoogle::Apis::BackupdrV1::BackupApplianceBackupProperties

BackupApplianceBackupProperties represents BackupDR backup appliance's properties. Corresponds to the JSON property backupApplianceBackupProperties



604
605
606
# File 'lib/google/apis/backupdr_v1/classes.rb', line 604

def backup_appliance_backup_properties
  @backup_appliance_backup_properties
end

#backup_appliance_locksArray<Google::Apis::BackupdrV1::BackupLock>

Optional. The list of BackupLocks taken by the accessor Backup Appliance. Corresponds to the JSON property backupApplianceLocks



609
610
611
# File 'lib/google/apis/backupdr_v1/classes.rb', line 609

def backup_appliance_locks
  @backup_appliance_locks
end

#backup_retention_inheritanceString

Output only. Setting for how the enforced retention end time is inherited. This value is copied from this backup's BackupVault. Corresponds to the JSON property backupRetentionInheritance

Returns:

  • (String)


615
616
617
# File 'lib/google/apis/backupdr_v1/classes.rb', line 615

def backup_retention_inheritance
  @backup_retention_inheritance
end

#backup_typeString

Output only. Type of the backup, unspecified, scheduled or ondemand. Corresponds to the JSON property backupType

Returns:

  • (String)


620
621
622
# File 'lib/google/apis/backupdr_v1/classes.rb', line 620

def backup_type
  @backup_type
end

#cloud_sql_instance_backup_propertiesGoogle::Apis::BackupdrV1::CloudSqlInstanceBackupProperties

CloudSqlInstanceBackupProperties represents Cloud SQL Instance Backup properties. Corresponds to the JSON property cloudSqlInstanceBackupProperties



626
627
628
# File 'lib/google/apis/backupdr_v1/classes.rb', line 626

def cloud_sql_instance_backup_properties
  @cloud_sql_instance_backup_properties
end

#compute_instance_backup_propertiesGoogle::Apis::BackupdrV1::ComputeInstanceBackupProperties

ComputeInstanceBackupProperties represents Compute Engine instance backup properties. Corresponds to the JSON property computeInstanceBackupProperties



632
633
634
# File 'lib/google/apis/backupdr_v1/classes.rb', line 632

def compute_instance_backup_properties
  @compute_instance_backup_properties
end

#consistency_timeString

Output only. The point in time when this backup was captured from the source. Corresponds to the JSON property consistencyTime

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/backupdr_v1/classes.rb', line 637

def consistency_time
  @consistency_time
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


642
643
644
# File 'lib/google/apis/backupdr_v1/classes.rb', line 642

def create_time
  @create_time
end

#descriptionString

Output only. The description of the Backup instance (2048 characters or less). Corresponds to the JSON property description

Returns:

  • (String)


647
648
649
# File 'lib/google/apis/backupdr_v1/classes.rb', line 647

def description
  @description
end

#disk_backup_propertiesGoogle::Apis::BackupdrV1::DiskBackupProperties

DiskBackupProperties represents the properties of a Disk backup. Corresponds to the JSON property diskBackupProperties



652
653
654
# File 'lib/google/apis/backupdr_v1/classes.rb', line 652

def disk_backup_properties
  @disk_backup_properties
end

#enforced_retention_end_timeString

Optional. The backup can not be deleted before this time. Corresponds to the JSON property enforcedRetentionEndTime

Returns:

  • (String)


657
658
659
# File 'lib/google/apis/backupdr_v1/classes.rb', line 657

def enforced_retention_end_time
  @enforced_retention_end_time
end

#etagString

Optional. Server specified ETag to prevent updates from overwriting each other. Corresponds to the JSON property etag

Returns:

  • (String)


662
663
664
# File 'lib/google/apis/backupdr_v1/classes.rb', line 662

def etag
  @etag
end

#expire_timeString

Optional. When this backup is automatically expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


667
668
669
# File 'lib/google/apis/backupdr_v1/classes.rb', line 667

def expire_time
  @expire_time
end

#filestore_instance_backup_propertiesGoogle::Apis::BackupdrV1::FilestoreInstanceBackupProperties

FilestoreInstanceBackupProperties represents the properties of a Filestore instance that are backed up by the datasource. . Corresponds to the JSON property filestoreInstanceBackupProperties



673
674
675
# File 'lib/google/apis/backupdr_v1/classes.rb', line 673

def filestore_instance_backup_properties
  @filestore_instance_backup_properties
end

#gcp_backup_plan_infoGoogle::Apis::BackupdrV1::GcpBackupPlanInfo

GCPBackupPlanInfo captures the plan configuration details of Google Cloud resources at the time of backup. Corresponds to the JSON property gcpBackupPlanInfo



679
680
681
# File 'lib/google/apis/backupdr_v1/classes.rb', line 679

def gcp_backup_plan_info
  @gcp_backup_plan_info
end

#gcp_resourceGoogle::Apis::BackupdrV1::BackupGcpResource

Minimum details to identify a Google Cloud resource for a backup. Corresponds to the JSON property gcpResource



684
685
686
# File 'lib/google/apis/backupdr_v1/classes.rb', line 684

def gcp_resource
  @gcp_resource
end

#kms_key_versionsArray<String>

Optional. Output only. The list of KMS key versions used to encrypt the backup. Corresponds to the JSON property kmsKeyVersions

Returns:

  • (Array<String>)


689
690
691
# File 'lib/google/apis/backupdr_v1/classes.rb', line 689

def kms_key_versions
  @kms_key_versions
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. No labels currently defined. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


695
696
697
# File 'lib/google/apis/backupdr_v1/classes.rb', line 695

def labels
  @labels
end

#nameString

Output only. Identifier. Name of the backup to create. It must have the format "projects//locations//backupVaults//dataSources/datasource/backups/backup" . backup cannot be changed after creation. It must be between 3-63 characters long and must be unique within the datasource. Corresponds to the JSON property name

Returns:

  • (String)


703
704
705
# File 'lib/google/apis/backupdr_v1/classes.rb', line 703

def name
  @name
end

#resource_size_bytesFixnum

Output only. source resource size in bytes at the time of the backup. Corresponds to the JSON property resourceSizeBytes

Returns:

  • (Fixnum)


708
709
710
# File 'lib/google/apis/backupdr_v1/classes.rb', line 708

def resource_size_bytes
  @resource_size_bytes
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Optional. Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


713
714
715
# File 'lib/google/apis/backupdr_v1/classes.rb', line 713

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Optional. Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


719
720
721
# File 'lib/google/apis/backupdr_v1/classes.rb', line 719

def satisfies_pzs
  @satisfies_pzs
end

#service_locksArray<Google::Apis::BackupdrV1::BackupLock>

Output only. The list of BackupLocks taken by the service to prevent the deletion of the backup. Corresponds to the JSON property serviceLocks



726
727
728
# File 'lib/google/apis/backupdr_v1/classes.rb', line 726

def service_locks
  @service_locks
end

#stateString

Output only. The Backup resource instance state. Corresponds to the JSON property state

Returns:

  • (String)


731
732
733
# File 'lib/google/apis/backupdr_v1/classes.rb', line 731

def state
  @state
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


736
737
738
# File 'lib/google/apis/backupdr_v1/classes.rb', line 736

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
# File 'lib/google/apis/backupdr_v1/classes.rb', line 743

def update!(**args)
  @alloy_db_backup_properties = args[:alloy_db_backup_properties] if args.key?(:alloy_db_backup_properties)
  @backup_appliance_backup_properties = args[:backup_appliance_backup_properties] if args.key?(:backup_appliance_backup_properties)
  @backup_appliance_locks = args[:backup_appliance_locks] if args.key?(:backup_appliance_locks)
  @backup_retention_inheritance = args[:backup_retention_inheritance] if args.key?(:backup_retention_inheritance)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @cloud_sql_instance_backup_properties = args[:cloud_sql_instance_backup_properties] if args.key?(:cloud_sql_instance_backup_properties)
  @compute_instance_backup_properties = args[:compute_instance_backup_properties] if args.key?(:compute_instance_backup_properties)
  @consistency_time = args[:consistency_time] if args.key?(:consistency_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disk_backup_properties = args[:disk_backup_properties] if args.key?(:disk_backup_properties)
  @enforced_retention_end_time = args[:enforced_retention_end_time] if args.key?(:enforced_retention_end_time)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @filestore_instance_backup_properties = args[:filestore_instance_backup_properties] if args.key?(:filestore_instance_backup_properties)
  @gcp_backup_plan_info = args[:gcp_backup_plan_info] if args.key?(:gcp_backup_plan_info)
  @gcp_resource = args[:gcp_resource] if args.key?(:gcp_resource)
  @kms_key_versions = args[:kms_key_versions] if args.key?(:kms_key_versions)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resource_size_bytes = args[:resource_size_bytes] if args.key?(:resource_size_bytes)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_locks = args[:service_locks] if args.key?(:service_locks)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end