Class: Google::Apis::BackupdrV1::BackupApplianceBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::BackupApplianceBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupApplianceBackupConfig captures the backup configuration for applications that are protected by Backup Appliances.
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application.
-
#backup_appliance_id ⇒ Fixnum
The ID of the backup appliance.
-
#backup_appliance_name ⇒ String
The name of the backup appliance.
-
#host_name ⇒ String
The name of the host where the application is running.
-
#sla_id ⇒ Fixnum
The ID of the SLA of this application.
-
#slp_name ⇒ String
The name of the SLP associated with the application.
-
#slt_name ⇒ String
The name of the SLT associated with the application.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupApplianceBackupConfig
constructor
A new instance of BackupApplianceBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupApplianceBackupConfig
Returns a new instance of BackupApplianceBackupConfig.
813 814 815 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_name ⇒ String
The name of the application.
Corresponds to the JSON property applicationName
781 782 783 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 781 def application_name @application_name end |
#backup_appliance_id ⇒ Fixnum
The ID of the backup appliance.
Corresponds to the JSON property backupApplianceId
786 787 788 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 786 def backup_appliance_id @backup_appliance_id end |
#backup_appliance_name ⇒ String
The name of the backup appliance.
Corresponds to the JSON property backupApplianceName
791 792 793 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 791 def backup_appliance_name @backup_appliance_name end |
#host_name ⇒ String
The name of the host where the application is running.
Corresponds to the JSON property hostName
796 797 798 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 796 def host_name @host_name end |
#sla_id ⇒ Fixnum
The ID of the SLA of this application.
Corresponds to the JSON property slaId
801 802 803 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 801 def sla_id @sla_id end |
#slp_name ⇒ String
The name of the SLP associated with the application.
Corresponds to the JSON property slpName
806 807 808 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 806 def slp_name @slp_name end |
#slt_name ⇒ String
The name of the SLT associated with the application.
Corresponds to the JSON property sltName
811 812 813 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 811 def slt_name @slt_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
818 819 820 821 822 823 824 825 826 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 818 def update!(**args) @application_name = args[:application_name] if args.key?(:application_name) @backup_appliance_id = args[:backup_appliance_id] if args.key?(:backup_appliance_id) @backup_appliance_name = args[:backup_appliance_name] if args.key?(:backup_appliance_name) @host_name = args[:host_name] if args.key?(:host_name) @sla_id = args[:sla_id] if args.key?(:sla_id) @slp_name = args[:slp_name] if args.key?(:slp_name) @slt_name = args[:slt_name] if args.key?(:slt_name) end |