Class: Google::Apis::BackupdrV1::BackupApplianceLockInfo
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::BackupApplianceLockInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupApplianceLockInfo contains metadata about the backupappliance that created the lock.
Instance Attribute Summary collapse
-
#backup_appliance_id ⇒ Fixnum
Required.
-
#backup_appliance_name ⇒ String
Required.
-
#backup_image ⇒ String
The image name that depends on this Backup.
-
#job_name ⇒ String
The job name on the backup/recovery appliance that created this lock.
-
#lock_reason ⇒ String
Required.
-
#sla_id ⇒ Fixnum
The SLA on the backup/recovery appliance that owns the lock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupApplianceLockInfo
constructor
A new instance of BackupApplianceLockInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupApplianceLockInfo
Returns a new instance of BackupApplianceLockInfo.
906 907 908 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_appliance_id ⇒ Fixnum
Required. The ID of the backup/recovery appliance that created this lock.
Corresponds to the JSON property backupApplianceId
877 878 879 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 877 def backup_appliance_id @backup_appliance_id end |
#backup_appliance_name ⇒ String
Required. The name of the backup/recovery appliance that created this lock.
Corresponds to the JSON property backupApplianceName
882 883 884 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 882 def backup_appliance_name @backup_appliance_name end |
#backup_image ⇒ String
The image name that depends on this Backup.
Corresponds to the JSON property backupImage
887 888 889 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 887 def backup_image @backup_image end |
#job_name ⇒ String
The job name on the backup/recovery appliance that created this lock.
Corresponds to the JSON property jobName
892 893 894 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 892 def job_name @job_name end |
#lock_reason ⇒ String
Required. The reason for the lock: e.g. MOUNT/RESTORE/BACKUP/etc. The value of
this string is only meaningful to the client and it is not interpreted by the
BackupVault service.
Corresponds to the JSON property lockReason
899 900 901 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 899 def lock_reason @lock_reason end |
#sla_id ⇒ Fixnum
The SLA on the backup/recovery appliance that owns the lock.
Corresponds to the JSON property slaId
904 905 906 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 904 def sla_id @sla_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
911 912 913 914 915 916 917 918 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 911 def update!(**args) @backup_appliance_id = args[:backup_appliance_id] if args.key?(:backup_appliance_id) @backup_appliance_name = args[:backup_appliance_name] if args.key?(:backup_appliance_name) @backup_image = args[:backup_image] if args.key?(:backup_image) @job_name = args[:job_name] if args.key?(:job_name) @lock_reason = args[:lock_reason] if args.key?(:lock_reason) @sla_id = args[:sla_id] if args.key?(:sla_id) end |