Class: Google::Apis::BackupdrV1::BackupConfigDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

BackupConfigDetails has information about how the resource is configured for backups and about the most recent backup taken for this configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupConfigDetails

Returns a new instance of BackupConfigDetails.



993
994
995
# File 'lib/google/apis/backupdr_v1/classes.rb', line 993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicable_resourceString

Output only. The full resource name of the resource that is applicable for the backup configuration. Example: "//compute.googleapis.com/projects/project/zones/ zone/instances/instance" Corresponds to the JSON property applicableResource

Returns:

  • (String)


932
933
934
# File 'lib/google/apis/backupdr_v1/classes.rb', line 932

def applicable_resource
  @applicable_resource
end

#backup_config_sourceString

Output only. The full resource name of the backup config source resource. For example, "//backupdr.googleapis.com/v1/projects/project/locations/region/ backupPlans/backupplanId" or "//compute.googleapis.com/projects/project/ locations/region/resourcePolicies/resourcePolicyId". Corresponds to the JSON property backupConfigSource

Returns:

  • (String)


940
941
942
# File 'lib/google/apis/backupdr_v1/classes.rb', line 940

def backup_config_source
  @backup_config_source
end

#backup_config_source_display_nameString

Output only. The display name of the backup config source resource. Corresponds to the JSON property backupConfigSourceDisplayName

Returns:

  • (String)


945
946
947
# File 'lib/google/apis/backupdr_v1/classes.rb', line 945

def backup_config_source_display_name
  @backup_config_source_display_name
end

#backup_dr_plan_configGoogle::Apis::BackupdrV1::BackupDrPlanConfig

BackupDrPlanConfig has additional information about Google Cloud Backup and DR' s Plan backup configuration. Corresponds to the JSON property backupDrPlanConfig



951
952
953
# File 'lib/google/apis/backupdr_v1/classes.rb', line 951

def backup_dr_plan_config
  @backup_dr_plan_config
end

#backup_dr_template_configGoogle::Apis::BackupdrV1::BackupDrTemplateConfig

Provides additional information about Google Cloud Backup and DR's Template backup configuration. Corresponds to the JSON property backupDrTemplateConfig



957
958
959
# File 'lib/google/apis/backupdr_v1/classes.rb', line 957

def backup_dr_template_config
  @backup_dr_template_config
end

#backup_locationsArray<Google::Apis::BackupdrV1::BackupLocation>

The locations where the backups are to be stored. Corresponds to the JSON property backupLocations



962
963
964
# File 'lib/google/apis/backupdr_v1/classes.rb', line 962

def backup_locations
  @backup_locations
end

#backup_vaultString

Output only. The full resource name of the backup vault that will store the backups generated through this backup configuration. Example: "//backupdr.googleapis. com/v1/projects/project/locations/region/backupVaults/backupvaultId" Corresponds to the JSON property backupVault

Returns:

  • (String)


970
971
972
# File 'lib/google/apis/backupdr_v1/classes.rb', line 970

def backup_vault
  @backup_vault
end

#latest_successful_backup_timeString

Output only. Timestamp of the latest successful backup created via this backup configuration. Corresponds to the JSON property latestSuccessfulBackupTime

Returns:

  • (String)


976
977
978
# File 'lib/google/apis/backupdr_v1/classes.rb', line 976

def latest_successful_backup_time
  @latest_successful_backup_time
end

#pitr_settingsGoogle::Apis::BackupdrV1::PitrSettings

Point in time recovery settings of the backup configuration resource. Corresponds to the JSON property pitrSettings



981
982
983
# File 'lib/google/apis/backupdr_v1/classes.rb', line 981

def pitr_settings
  @pitr_settings
end

#stateString

Output only. The state of the backup config resource. Corresponds to the JSON property state

Returns:

  • (String)


986
987
988
# File 'lib/google/apis/backupdr_v1/classes.rb', line 986

def state
  @state
end

#typeString

Output only. The type of the backup config resource. Corresponds to the JSON property type

Returns:

  • (String)


991
992
993
# File 'lib/google/apis/backupdr_v1/classes.rb', line 991

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/google/apis/backupdr_v1/classes.rb', line 998

def update!(**args)
  @applicable_resource = args[:applicable_resource] if args.key?(:applicable_resource)
  @backup_config_source = args[:backup_config_source] if args.key?(:backup_config_source)
  @backup_config_source_display_name = args[:backup_config_source_display_name] if args.key?(:backup_config_source_display_name)
  @backup_dr_plan_config = args[:backup_dr_plan_config] if args.key?(:backup_dr_plan_config)
  @backup_dr_template_config = args[:backup_dr_template_config] if args.key?(:backup_dr_template_config)
  @backup_locations = args[:backup_locations] if args.key?(:backup_locations)
  @backup_vault = args[:backup_vault] if args.key?(:backup_vault)
  @latest_successful_backup_time = args[:latest_successful_backup_time] if args.key?(:latest_successful_backup_time)
  @pitr_settings = args[:pitr_settings] if args.key?(:pitr_settings)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end