Class: Google::Apis::BackupdrV1::BackupConfigInfo
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::BackupConfigInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupConfigInfo has information about how the resource is configured for Backup and about the most recent backup to this vault.
Instance Attribute Summary collapse
-
#backup_appliance_backup_config ⇒ Google::Apis::BackupdrV1::BackupApplianceBackupConfig
BackupApplianceBackupConfig captures the backup configuration for applications that are protected by Backup Appliances.
-
#gcp_backup_config ⇒ Google::Apis::BackupdrV1::GcpBackupConfig
GcpBackupConfig captures the Backup configuration details for Google Cloud resources.
-
#last_backup_error ⇒ Google::Apis::BackupdrV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#last_backup_state ⇒ String
Output only.
-
#last_successful_backup_consistency_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupConfigInfo
constructor
A new instance of BackupConfigInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupConfigInfo
Returns a new instance of BackupConfigInfo.
1052 1053 1054 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_appliance_backup_config ⇒ Google::Apis::BackupdrV1::BackupApplianceBackupConfig
BackupApplianceBackupConfig captures the backup configuration for applications
that are protected by Backup Appliances.
Corresponds to the JSON property backupApplianceBackupConfig
1022 1023 1024 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1022 def backup_appliance_backup_config @backup_appliance_backup_config end |
#gcp_backup_config ⇒ Google::Apis::BackupdrV1::GcpBackupConfig
GcpBackupConfig captures the Backup configuration details for Google Cloud
resources. All Google Cloud resources regardless of type are protected with
backup plan associations.
Corresponds to the JSON property gcpBackupConfig
1029 1030 1031 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1029 def gcp_backup_config @gcp_backup_config end |
#last_backup_error ⇒ Google::Apis::BackupdrV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property lastBackupError
1039 1040 1041 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1039 def last_backup_error @last_backup_error end |
#last_backup_state ⇒ String
Output only. The status of the last backup to this BackupVault
Corresponds to the JSON property lastBackupState
1044 1045 1046 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1044 def last_backup_state @last_backup_state end |
#last_successful_backup_consistency_time ⇒ String
Output only. If the last backup were successful, this field has the
consistency date.
Corresponds to the JSON property lastSuccessfulBackupConsistencyTime
1050 1051 1052 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1050 def last_successful_backup_consistency_time @last_successful_backup_consistency_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1057 1058 1059 1060 1061 1062 1063 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1057 def update!(**args) @backup_appliance_backup_config = args[:backup_appliance_backup_config] if args.key?(:backup_appliance_backup_config) @gcp_backup_config = args[:gcp_backup_config] if args.key?(:gcp_backup_config) @last_backup_error = args[:last_backup_error] if args.key?(:last_backup_error) @last_backup_state = args[:last_backup_state] if args.key?(:last_backup_state) @last_successful_backup_consistency_time = args[:last_successful_backup_consistency_time] if args.key?(:last_successful_backup_consistency_time) end |