Class: Google::Apis::BackupdrV1::BackupDrTemplateConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Provides additional information about Google Cloud Backup and DR's Template backup configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupDrTemplateConfig

Returns a new instance of BackupDrTemplateConfig.



1129
1130
1131
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#first_party_management_uriString

Output only. The URI of the BackupDr template resource for the first party identity users. Corresponds to the JSON property firstPartyManagementUri

Returns:

  • (String)


1121
1122
1123
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1121

def first_party_management_uri
  @first_party_management_uri
end

#third_party_management_uriString

Output only. The URI of the BackupDr template resource for the third party identity users. Corresponds to the JSON property thirdPartyManagementUri

Returns:

  • (String)


1127
1128
1129
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1127

def third_party_management_uri
  @third_party_management_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1134
1135
1136
1137
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1134

def update!(**args)
  @first_party_management_uri = args[:first_party_management_uri] if args.key?(:first_party_management_uri)
  @third_party_management_uri = args[:third_party_management_uri] if args.key?(:third_party_management_uri)
end