Class: Google::Apis::BackupdrV1::BackupLock

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

BackupLock represents a single lock on a Backup resource. An unexpired lock on a Backup prevents the Backup from being deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupLock

Returns a new instance of BackupLock.



1220
1221
1222
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_appliance_lock_infoGoogle::Apis::BackupdrV1::BackupApplianceLockInfo

BackupApplianceLockInfo contains metadata about the backupappliance that created the lock. Corresponds to the JSON property backupApplianceLockInfo



1206
1207
1208
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1206

def backup_appliance_lock_info
  @backup_appliance_lock_info
end

#lock_until_timeString

Required. The time after which this lock is not considered valid and will no longer protect the Backup from deletion. Corresponds to the JSON property lockUntilTime

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1212

def lock_until_time
  @lock_until_time
end

#service_lock_infoGoogle::Apis::BackupdrV1::ServiceLockInfo

ServiceLockInfo represents the details of a lock taken by the service on a Backup resource. Corresponds to the JSON property serviceLockInfo



1218
1219
1220
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1218

def service_lock_info
  @service_lock_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1225
1226
1227
1228
1229
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1225

def update!(**args)
  @backup_appliance_lock_info = args[:backup_appliance_lock_info] if args.key?(:backup_appliance_lock_info)
  @lock_until_time = args[:lock_until_time] if args.key?(:lock_until_time)
  @service_lock_info = args[:service_lock_info] if args.key?(:service_lock_info)
end