Class: Google::Apis::BackupdrV1::BackupPlanRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

BackupPlanRevision represents a snapshot of a BackupPlan at a point in time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupPlanRevision

Returns a new instance of BackupPlanRevision.



1521
1522
1523
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plan_snapshotGoogle::Apis::BackupdrV1::BackupPlan

A BackupPlan specifies some common fields, such as description as well as one or more BackupRule messages. Each BackupRule has a retention policy and defines a schedule by which the system is to perform backup workloads. Corresponds to the JSON property backupPlanSnapshot



1496
1497
1498
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1496

def backup_plan_snapshot
  @backup_plan_snapshot
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1501
1502
1503
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1501

def create_time
  @create_time
end

#nameString

Output only. Identifier. The resource name of the BackupPlanRevision. Format: projects/project/locations/location/backupPlans/backup_plan/revisions/ revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


1508
1509
1510
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1508

def name
  @name
end

#revision_idString

Output only. The user friendly revision ID of the BackupPlanRevision. Example: v0, v1, v2, etc. Corresponds to the JSON property revisionId

Returns:

  • (String)


1514
1515
1516
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1514

def revision_id
  @revision_id
end

#stateString

Output only. Resource State Corresponds to the JSON property state

Returns:

  • (String)


1519
1520
1521
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1519

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1526
1527
1528
1529
1530
1531
1532
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1526

def update!(**args)
  @backup_plan_snapshot = args[:backup_plan_snapshot] if args.key?(:backup_plan_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @state = args[:state] if args.key?(:state)
end