Class: Google::Apis::BackupdrV1::BackupVault

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message describing a BackupVault object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupVault

Returns a new instance of BackupVault.



1688
1689
1690
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_restrictionString

Optional. Note: This field is added for future use case and will not be supported in the current release. Access restriction for the backup vault. Default value is WITHIN_ORGANIZATION if not provided during creation. Corresponds to the JSON property accessRestriction

Returns:

  • (String)


1586
1587
1588
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1586

def access_restriction
  @access_restriction
end

#annotationsHash<String,String>

Optional. User annotations. See https://google.aip.dev/128#annotations Stores small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1592
1593
1594
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1592

def annotations
  @annotations
end

#backup_countFixnum

Output only. The number of backups in this backup vault. Corresponds to the JSON property backupCount

Returns:

  • (Fixnum)


1597
1598
1599
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1597

def backup_count
  @backup_count
end

#backup_minimum_enforced_retention_durationString

Required. The default and minimum enforced retention for each backup within the backup vault. The enforced retention for each backup can be extended. Note: Longer minimum enforced retention period impacts potential storage costs post introductory trial. We recommend starting with a short duration of 3 days or less. Corresponds to the JSON property backupMinimumEnforcedRetentionDuration

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1606

def backup_minimum_enforced_retention_duration
  @backup_minimum_enforced_retention_duration
end

#backup_retention_inheritanceString

Optional. Setting for how a backup's enforced retention end time is inherited. Corresponds to the JSON property backupRetentionInheritance

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1611

def backup_retention_inheritance
  @backup_retention_inheritance
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1616
1617
1618
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1616

def create_time
  @create_time
end

#deletableBoolean Also known as: deletable?

Output only. Set to true when there are no backups nested under this resource. Corresponds to the JSON property deletable

Returns:

  • (Boolean)


1621
1622
1623
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1621

def deletable
  @deletable
end

#descriptionString

Optional. The description of the BackupVault instance (2048 characters or less) . Corresponds to the JSON property description

Returns:

  • (String)


1628
1629
1630
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1628

def description
  @description
end

#effective_timeString

Optional. Time after which the BackupVault resource is locked. Corresponds to the JSON property effectiveTime

Returns:

  • (String)


1633
1634
1635
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1633

def effective_time
  @effective_time
end

#encryption_configGoogle::Apis::BackupdrV1::EncryptionConfig

Message describing the EncryptionConfig of backup vault. This determines how data within the vault is encrypted at rest. Corresponds to the JSON property encryptionConfig



1639
1640
1641
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1639

def encryption_config
  @encryption_config
end

#etagString

Optional. Server specified ETag for the backup vault resource to prevent simultaneous updates from overwiting each other. Corresponds to the JSON property etag

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1645

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. No labels currently defined: Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1651
1652
1653
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1651

def labels
  @labels
end

#nameString

Output only. Identifier. Name of the backup vault to create. It must have the format"projects/project/locations/location/backupVaults/backupvault". backupvault`cannot be changed after creation. It must be between 3-63 characters long and must be unique within the project and location. Corresponds to the JSON propertyname`

Returns:

  • (String)


1659
1660
1661
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1659

def name
  @name
end

#service_accountString

Output only. Service account used by the BackupVault Service for this BackupVault. The user should grant this account permissions in their workload project to enable the service to run backups and restores there. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1666

def 
  @service_account
end

#stateString

Output only. The BackupVault resource instance state. Corresponds to the JSON property state

Returns:

  • (String)


1671
1672
1673
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1671

def state
  @state
end

#total_stored_bytesFixnum

Output only. Total size of the storage used by all backup resources. Corresponds to the JSON property totalStoredBytes

Returns:

  • (Fixnum)


1676
1677
1678
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1676

def total_stored_bytes
  @total_stored_bytes
end

#uidString

Output only. Immutable after resource creation until resource deletion. Corresponds to the JSON property uid

Returns:

  • (String)


1681
1682
1683
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1681

def uid
  @uid
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1686
1687
1688
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1686

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1693

def update!(**args)
  @access_restriction = args[:access_restriction] if args.key?(:access_restriction)
  @annotations = args[:annotations] if args.key?(:annotations)
  @backup_count = args[:backup_count] if args.key?(:backup_count)
  @backup_minimum_enforced_retention_duration = args[:backup_minimum_enforced_retention_duration] if args.key?(:backup_minimum_enforced_retention_duration)
  @backup_retention_inheritance = args[:backup_retention_inheritance] if args.key?(:backup_retention_inheritance)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deletable = args[:deletable] if args.key?(:deletable)
  @description = args[:description] if args.key?(:description)
  @effective_time = args[:effective_time] if args.key?(:effective_time)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
  @total_stored_bytes = args[:total_stored_bytes] if args.key?(:total_stored_bytes)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end