Class: Google::Apis::BackupdrV1::ComputeInstanceDataSourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ComputeInstanceDataSourceProperties represents the properties of a ComputeEngine resource that are stored in the DataSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeInstanceDataSourceProperties

Returns a new instance of ComputeInstanceDataSourceProperties.



2211
2212
2213
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the Compute Engine instance. Corresponds to the JSON property description

Returns:

  • (String)


2189
2190
2191
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2189

def description
  @description
end

#machine_typeString

The machine type of the instance. Corresponds to the JSON property machineType

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2194

def machine_type
  @machine_type
end

#nameString

Name of the compute instance backed up by the datasource. Corresponds to the JSON property name

Returns:

  • (String)


2199
2200
2201
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2199

def name
  @name
end

#total_disk_countFixnum

The total number of disks attached to the Instance. Corresponds to the JSON property totalDiskCount

Returns:

  • (Fixnum)


2204
2205
2206
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2204

def total_disk_count
  @total_disk_count
end

#total_disk_size_gbFixnum

The sum of all the disk sizes. Corresponds to the JSON property totalDiskSizeGb

Returns:

  • (Fixnum)


2209
2210
2211
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2209

def total_disk_size_gb
  @total_disk_size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2216
2217
2218
2219
2220
2221
2222
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2216

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @name = args[:name] if args.key?(:name)
  @total_disk_count = args[:total_disk_count] if args.key?(:total_disk_count)
  @total_disk_size_gb = args[:total_disk_size_gb] if args.key?(:total_disk_size_gb)
end