Class: Google::Apis::BackupdrV1::ComputeInstanceTargetEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ComputeInstanceTargetEnvironment represents Compute Engine target environment to be used during restore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeInstanceTargetEnvironment

Returns a new instance of ComputeInstanceTargetEnvironment.



2428
2429
2430
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#projectString

Required. Target project for the Compute Engine instance. Corresponds to the JSON property project

Returns:

  • (String)


2414
2415
2416
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2414

def project
  @project
end

#use_project_service_accountBoolean Also known as: use_project_service_account?

Optional. Whether to use the project service account for the Compute Engine instance. Corresponds to the JSON property useProjectServiceAccount

Returns:

  • (Boolean)


2420
2421
2422
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2420

def 
  @use_project_service_account
end

#zoneString

Required. The zone of the Compute Engine instance. Corresponds to the JSON property zone

Returns:

  • (String)


2426
2427
2428
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2426

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2433
2434
2435
2436
2437
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2433

def update!(**args)
  @project = args[:project] if args.key?(:project)
  @use_project_service_account = args[:use_project_service_account] if args.key?(:use_project_service_account)
  @zone = args[:zone] if args.key?(:zone)
end