Class: Google::Apis::BackupdrV1::DataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message describing a DataSource object. Datasource object used to represent Datasource details for both admin and basic view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSource

Returns a new instance of DataSource.



2607
2608
2609
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_blocked_by_vault_access_restrictionBoolean Also known as: backup_blocked_by_vault_access_restriction?

Output only. This field is set to true if the backup is blocked by vault access restriction. Corresponds to the JSON property backupBlockedByVaultAccessRestriction

Returns:

  • (Boolean)


2534
2535
2536
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2534

def backup_blocked_by_vault_access_restriction
  @backup_blocked_by_vault_access_restriction
end

#backup_config_infoGoogle::Apis::BackupdrV1::BackupConfigInfo

BackupConfigInfo has information about how the resource is configured for Backup and about the most recent backup to this vault. Corresponds to the JSON property backupConfigInfo



2541
2542
2543
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2541

def backup_config_info
  @backup_config_info
end

#backup_countFixnum

Number of backups in the data source. Corresponds to the JSON property backupCount

Returns:

  • (Fixnum)


2546
2547
2548
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2546

def backup_count
  @backup_count
end

#config_stateString

Output only. The backup configuration state. Corresponds to the JSON property configState

Returns:

  • (String)


2551
2552
2553
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2551

def config_state
  @config_state
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2556

def create_time
  @create_time
end

#data_source_backup_appliance_applicationGoogle::Apis::BackupdrV1::DataSourceBackupApplianceApplication

BackupApplianceApplication describes a Source Resource when it is an application backed up by a BackupAppliance. Corresponds to the JSON property dataSourceBackupApplianceApplication



2562
2563
2564
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2562

def data_source_backup_appliance_application
  @data_source_backup_appliance_application
end

#data_source_gcp_resourceGoogle::Apis::BackupdrV1::DataSourceGcpResource

DataSourceGcpResource is used for protected resources that are Google Cloud Resources. This name is easeier to understand than GcpResourceDataSource or GcpDataSourceResource Corresponds to the JSON property dataSourceGcpResource



2569
2570
2571
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2569

def data_source_gcp_resource
  @data_source_gcp_resource
end

#etagString

Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other. Corresponds to the JSON property etag

Returns:

  • (String)


2575
2576
2577
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2575

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. No labels currently defined: Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2581
2582
2583
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2581

def labels
  @labels
end

#nameString

Output only. Identifier. Name of the datasource to create. It must have the format"projects/project/locations/location/backupVaults/backupvault/ dataSources/datasource". datasource cannot be changed after creation. It must be between 3-63 characters long and must be unique within the backup vault. Corresponds to the JSON property name

Returns:

  • (String)


2590
2591
2592
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2590

def name
  @name
end

#stateString

Output only. The DataSource resource instance state. Corresponds to the JSON property state

Returns:

  • (String)


2595
2596
2597
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2595

def state
  @state
end

#total_stored_bytesFixnum

The number of bytes (metadata and data) stored in this datasource. Corresponds to the JSON property totalStoredBytes

Returns:

  • (Fixnum)


2600
2601
2602
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2600

def total_stored_bytes
  @total_stored_bytes
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2605
2606
2607
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2605

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2612

def update!(**args)
  @backup_blocked_by_vault_access_restriction = args[:backup_blocked_by_vault_access_restriction] if args.key?(:backup_blocked_by_vault_access_restriction)
  @backup_config_info = args[:backup_config_info] if args.key?(:backup_config_info)
  @backup_count = args[:backup_count] if args.key?(:backup_count)
  @config_state = args[:config_state] if args.key?(:config_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source_backup_appliance_application = args[:data_source_backup_appliance_application] if args.key?(:data_source_backup_appliance_application)
  @data_source_gcp_resource = args[:data_source_gcp_resource] if args.key?(:data_source_gcp_resource)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @total_stored_bytes = args[:total_stored_bytes] if args.key?(:total_stored_bytes)
  @update_time = args[:update_time] if args.key?(:update_time)
end