Class: Google::Apis::BackupdrV1::DataSourceBackupApplianceApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

BackupApplianceApplication describes a Source Resource when it is an application backed up by a BackupAppliance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSourceBackupApplianceApplication

Returns a new instance of DataSourceBackupApplianceApplication.



2669
2670
2671
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_idFixnum

Appliance Id of the Backup Appliance. Corresponds to the JSON property applianceId

Returns:

  • (Fixnum)


2637
2638
2639
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2637

def appliance_id
  @appliance_id
end

#application_idFixnum

The appid field of the application within the Backup Appliance. Corresponds to the JSON property applicationId

Returns:

  • (Fixnum)


2642
2643
2644
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2642

def application_id
  @application_id
end

#application_nameString

The name of the Application as known to the Backup Appliance. Corresponds to the JSON property applicationName

Returns:

  • (String)


2647
2648
2649
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2647

def application_name
  @application_name
end

#backup_applianceString

Appliance name. Corresponds to the JSON property backupAppliance

Returns:

  • (String)


2652
2653
2654
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2652

def backup_appliance
  @backup_appliance
end

#host_idFixnum

Hostid of the application host. Corresponds to the JSON property hostId

Returns:

  • (Fixnum)


2657
2658
2659
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2657

def host_id
  @host_id
end

#hostnameString

Hostname of the host where the application is running. Corresponds to the JSON property hostname

Returns:

  • (String)


2662
2663
2664
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2662

def hostname
  @hostname
end

#typeString

The type of the application. e.g. VMBackup Corresponds to the JSON property type

Returns:

  • (String)


2667
2668
2669
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2667

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2674
2675
2676
2677
2678
2679
2680
2681
2682
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2674

def update!(**args)
  @appliance_id = args[:appliance_id] if args.key?(:appliance_id)
  @application_id = args[:application_id] if args.key?(:application_id)
  @application_name = args[:application_name] if args.key?(:application_name)
  @backup_appliance = args[:backup_appliance] if args.key?(:backup_appliance)
  @host_id = args[:host_id] if args.key?(:host_id)
  @hostname = args[:hostname] if args.key?(:hostname)
  @type = args[:type] if args.key?(:type)
end