Class: Google::Apis::BackupdrV1::DataSourceBackupConfigInfo
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DataSourceBackupConfigInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Information of backup configuration on the DataSource.
Instance Attribute Summary collapse
-
#last_backup_state ⇒ String
Output only.
-
#last_successful_backup_consistency_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceBackupConfigInfo
constructor
A new instance of DataSourceBackupConfigInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceBackupConfigInfo
Returns a new instance of DataSourceBackupConfigInfo.
2666 2667 2668 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_backup_state ⇒ String
Output only. The status of the last backup in this DataSource
Corresponds to the JSON property lastBackupState
2659 2660 2661 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2659 def last_backup_state @last_backup_state end |
#last_successful_backup_consistency_time ⇒ String
Output only. Timestamp of the last successful backup to this DataSource.
Corresponds to the JSON property lastSuccessfulBackupConsistencyTime
2664 2665 2666 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2664 def last_successful_backup_consistency_time @last_successful_backup_consistency_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2671 2672 2673 2674 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2671 def update!(**args) @last_backup_state = args[:last_backup_state] if args.key?(:last_backup_state) @last_successful_backup_consistency_time = args[:last_successful_backup_consistency_time] if args.key?(:last_successful_backup_consistency_time) end |