Class: Google::Apis::BackupdrV1::DiskBackupProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

DiskBackupProperties represents the properties of a Disk backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskBackupProperties

Returns a new instance of DiskBackupProperties.



3019
3020
3021
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_modeString

The access mode of the source disk. Corresponds to the JSON property accessMode

Returns:

  • (String)


2927
2928
2929
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2927

def access_mode
  @access_mode
end

#architectureString

The architecture of the source disk. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


2932
2933
2934
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2932

def architecture
  @architecture
end

#descriptionString

A description of the source disk. Corresponds to the JSON property description

Returns:

  • (String)


2937
2938
2939
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2937

def description
  @description
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Indicates whether the source disk is using confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


2942
2943
2944
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2942

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_flushBoolean Also known as: guest_flush?

Optional. Defines if the guest flush is enabled for the source disk. Default value is false. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


2949
2950
2951
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2949

def guest_flush
  @guest_flush
end

#guest_os_featureArray<Google::Apis::BackupdrV1::GuestOsFeature>

A list of guest OS features that are applicable to this backup. Corresponds to the JSON property guestOsFeature



2955
2956
2957
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2955

def guest_os_feature
  @guest_os_feature
end

#labelsHash<String,String>

The labels of the source disk. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2960
2961
2962
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2960

def labels
  @labels
end

#licensesArray<String>

A list of publicly available licenses that are applicable to this backup. This is applicable if the original image had licenses attached, e.g. Windows image. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2966
2967
2968
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2966

def licenses
  @licenses
end

#physical_block_size_bytesFixnum

The physical block size of the source disk. Corresponds to the JSON property physicalBlockSizeBytes

Returns:

  • (Fixnum)


2971
2972
2973
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2971

def physical_block_size_bytes
  @physical_block_size_bytes
end

#provisioned_iopsFixnum

The number of IOPS provisioned for the source disk. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


2976
2977
2978
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2976

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

The number of throughput provisioned for the source disk. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


2981
2982
2983
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2981

def provisioned_throughput
  @provisioned_throughput
end

#regionString

Region and zone are mutually exclusive fields. The URL of the region of the source disk. Corresponds to the JSON property region

Returns:

  • (String)


2987
2988
2989
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2987

def region
  @region
end

#replica_zonesArray<String>

The URL of the Zones where the source disk should be replicated. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


2992
2993
2994
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2992

def replica_zones
  @replica_zones
end

#size_gbFixnum

Size(in GB) of the source disk. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


2997
2998
2999
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2997

def size_gb
  @size_gb
end

#source_diskString

The source disk used to create this backup. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


3002
3003
3004
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3002

def source_disk
  @source_disk
end

#storage_poolString

The storage pool of the source disk. Corresponds to the JSON property storagePool

Returns:

  • (String)


3007
3008
3009
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3007

def storage_pool
  @storage_pool
end

#typeString

The URL of the type of the disk. Corresponds to the JSON property type

Returns:

  • (String)


3012
3013
3014
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3012

def type
  @type
end

#zoneString

The URL of the Zone where the source disk. Corresponds to the JSON property zone

Returns:

  • (String)


3017
3018
3019
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3017

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3024

def update!(**args)
  @access_mode = args[:access_mode] if args.key?(:access_mode)
  @architecture = args[:architecture] if args.key?(:architecture)
  @description = args[:description] if args.key?(:description)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @guest_os_feature = args[:guest_os_feature] if args.key?(:guest_os_feature)
  @labels = args[:labels] if args.key?(:labels)
  @licenses = args[:licenses] if args.key?(:licenses)
  @physical_block_size_bytes = args[:physical_block_size_bytes] if args.key?(:physical_block_size_bytes)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @region = args[:region] if args.key?(:region)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
  @type = args[:type] if args.key?(:type)
  @zone = args[:zone] if args.key?(:zone)
end