Class: Google::Apis::BackupdrV1::DiskDataSourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

DiskDataSourceProperties represents the properties of a Disk resource that are stored in the DataSource. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskDataSourceProperties

Returns a new instance of DiskDataSourceProperties.



3071
3072
3073
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the disk. Corresponds to the JSON property description

Returns:

  • (String)


3054
3055
3056
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3054

def description
  @description
end

#nameString

Name of the disk backed up by the datasource. Corresponds to the JSON property name

Returns:

  • (String)


3059
3060
3061
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3059

def name
  @name
end

#size_gbFixnum

The size of the disk in GB. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


3064
3065
3066
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3064

def size_gb
  @size_gb
end

#typeString

The type of the disk. Corresponds to the JSON property type

Returns:

  • (String)


3069
3070
3071
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3069

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3076
3077
3078
3079
3080
3081
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3076

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @type = args[:type] if args.key?(:type)
end