Class: Google::Apis::BackupdrV1::EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::EncryptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Message describing the EncryptionConfig of backup vault. This determines how data within the vault is encrypted at rest.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionConfig
constructor
A new instance of EncryptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionConfig
Returns a new instance of EncryptionConfig.
3313 3314 3315 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The Cloud KMS key name to encrypt backups in this backup vault. Must
be in the same region as the vault. Some workload backups like compute disk
backups may use their inherited source key instead. Format: projects/project/
locations/location/keyRings/ring/cryptoKeys/key
Corresponds to the JSON property kmsKeyName
3311 3312 3313 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3311 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3318 3319 3320 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3318 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |