Class: Google::Apis::BackupdrV1::FetchAccessTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::FetchAccessTokenResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response message for FetchAccessToken.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
The token is valid until this time.
-
#read_location ⇒ String
The location in bucket that can be used for reading.
-
#token ⇒ String
Input only.
-
#write_location ⇒ String
The location in bucket that can be used for writing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchAccessTokenResponse
constructor
A new instance of FetchAccessTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchAccessTokenResponse
Returns a new instance of FetchAccessTokenResponse.
3473 3474 3475 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
The token is valid until this time.
Corresponds to the JSON property expireTime
3456 3457 3458 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3456 def expire_time @expire_time end |
#read_location ⇒ String
The location in bucket that can be used for reading.
Corresponds to the JSON property readLocation
3461 3462 3463 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3461 def read_location @read_location end |
#token ⇒ String
Input only. The downscoped token that was created.
Corresponds to the JSON property token
3466 3467 3468 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3466 def token @token end |
#write_location ⇒ String
The location in bucket that can be used for writing.
Corresponds to the JSON property writeLocation
3471 3472 3473 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3471 def write_location @write_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3478 3479 3480 3481 3482 3483 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3478 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @read_location = args[:read_location] if args.key?(:read_location) @token = args[:token] if args.key?(:token) @write_location = args[:write_location] if args.key?(:write_location) end |