Class: Google::Apis::BackupdrV1::FetchResourceBackupConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::FetchResourceBackupConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response for FetchResourceBackupConfigs.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#resource_backup_configs ⇒ Array<Google::Apis::BackupdrV1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchResourceBackupConfigsResponse
constructor
A new instance of FetchResourceBackupConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchResourceBackupConfigsResponse
Returns a new instance of FetchResourceBackupConfigsResponse.
3552 3553 3554 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3545 3546 3547 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3545 def next_page_token @next_page_token end |
#resource_backup_configs ⇒ Array<Google::Apis::BackupdrV1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Corresponds to the JSON property resourceBackupConfigs
3550 3551 3552 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3550 def resource_backup_configs @resource_backup_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3557 3558 3559 3560 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3557 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_backup_configs = args[:resource_backup_configs] if args.key?(:resource_backup_configs) end |