Class: Google::Apis::BackupdrV1::FetchUsableBackupVaultsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Response message for fetching usable BackupVaults.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchUsableBackupVaultsResponse

Returns a new instance of FetchUsableBackupVaultsResponse.



3561
3562
3563
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_vaultsArray<Google::Apis::BackupdrV1::BackupVault>

The list of BackupVault instances in the project for the specified location. If the 'location' value in the request is "-", the response contains a list of instances from all locations. In case any location is unreachable, the response will only return backup vaults in reachable locations and the ' unreachable' field will be populated with a list of unreachable locations. Corresponds to the JSON property backupVaults



3549
3550
3551
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3549

def backup_vaults
  @backup_vaults
end

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3554
3555
3556
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3554

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3559
3560
3561
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3559

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3566
3567
3568
3569
3570
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3566

def update!(**args)
  @backup_vaults = args[:backup_vaults] if args.key?(:backup_vaults)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end