Class: Google::Apis::BackupdrV1::FilestoreInstanceDataSourceReferenceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

FilestoreInstanceDataSourceReferenceProperties represents the properties of a Filestore resource that are stored in the DataSourceReference. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilestoreInstanceDataSourceReferenceProperties

Returns a new instance of FilestoreInstanceDataSourceReferenceProperties.



3679
3680
3681
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_create_timeString

Output only. The instance creation timestamp. Corresponds to the JSON property instanceCreateTime

Returns:

  • (String)


3671
3672
3673
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3671

def instance_create_time
  @instance_create_time
end

#nameString

Output only. Name of the Filestore instance backed up by the datasource. Format: projects/project/instances/instance Corresponds to the JSON property name

Returns:

  • (String)


3677
3678
3679
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3677

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3684
3685
3686
3687
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3684

def update!(**args)
  @instance_create_time = args[:instance_create_time] if args.key?(:instance_create_time)
  @name = args[:name] if args.key?(:name)
end