Class: Google::Apis::BackupdrV1::GcpBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

GcpBackupConfig captures the Backup configuration details for Google Cloud resources. All Google Cloud resources regardless of type are protected with backup plan associations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpBackupConfig

Returns a new instance of GcpBackupConfig.



3906
3907
3908
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_planString

The name of the backup plan. Corresponds to the JSON property backupPlan

Returns:

  • (String)


3879
3880
3881
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3879

def backup_plan
  @backup_plan
end

#backup_plan_associationString

The name of the backup plan association. Corresponds to the JSON property backupPlanAssociation

Returns:

  • (String)


3884
3885
3886
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3884

def backup_plan_association
  @backup_plan_association
end

#backup_plan_descriptionString

The description of the backup plan. Corresponds to the JSON property backupPlanDescription

Returns:

  • (String)


3889
3890
3891
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3889

def backup_plan_description
  @backup_plan_description
end

#backup_plan_revision_idString

The user friendly id of the backup plan revision. E.g. v0, v1 etc. Corresponds to the JSON property backupPlanRevisionId

Returns:

  • (String)


3894
3895
3896
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3894

def backup_plan_revision_id
  @backup_plan_revision_id
end

#backup_plan_revision_nameString

The name of the backup plan revision. Corresponds to the JSON property backupPlanRevisionName

Returns:

  • (String)


3899
3900
3901
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3899

def backup_plan_revision_name
  @backup_plan_revision_name
end

#backup_plan_rulesArray<String>

The names of the backup plan rules which point to this backupvault Corresponds to the JSON property backupPlanRules

Returns:

  • (Array<String>)


3904
3905
3906
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3904

def backup_plan_rules
  @backup_plan_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3911
3912
3913
3914
3915
3916
3917
3918
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3911

def update!(**args)
  @backup_plan = args[:backup_plan] if args.key?(:backup_plan)
  @backup_plan_association = args[:backup_plan_association] if args.key?(:backup_plan_association)
  @backup_plan_description = args[:backup_plan_description] if args.key?(:backup_plan_description)
  @backup_plan_revision_id = args[:backup_plan_revision_id] if args.key?(:backup_plan_revision_id)
  @backup_plan_revision_name = args[:backup_plan_revision_name] if args.key?(:backup_plan_revision_name)
  @backup_plan_rules = args[:backup_plan_rules] if args.key?(:backup_plan_rules)
end