Class: Google::Apis::BackupdrV1::GoogleCloudBackupdrV1OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::GoogleCloudBackupdrV1OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#additional_info ⇒ Hash<String,String>
Output only.
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBackupdrV1OperationMetadata
constructor
A new instance of GoogleCloudBackupdrV1OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBackupdrV1OperationMetadata
Returns a new instance of GoogleCloudBackupdrV1OperationMetadata.
3951 3952 3953 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_info ⇒ Hash<String,String>
Output only. AdditionalInfo contains additional Info related to backup plan
association resource.
Corresponds to the JSON property additionalInfo
3910 3911 3912 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3910 def additional_info @additional_info end |
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
3915 3916 3917 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3915 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3920 3921 3922 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3920 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3925 3926 3927 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3925 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to 'Code.CANCELLED'.
Corresponds to the JSON property requestedCancellation
3933 3934 3935 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3933 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
3939 3940 3941 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3939 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
3944 3945 3946 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3944 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
3949 3950 3951 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3949 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3956 def update!(**args) @additional_info = args[:additional_info] if args.key?(:additional_info) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |