Class: Google::Apis::BackupdrV1::InitializeParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Specifies the parameters to initialize this disk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InitializeParams

Returns a new instance of InitializeParams.



4003
4004
4005
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_nameString

Optional. Specifies the disk name. If not specified, the default is to use the name of the instance. Corresponds to the JSON property diskName

Returns:

  • (String)


3995
3996
3997
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3995

def disk_name
  @disk_name
end

#replica_zonesArray<String>

Optional. URL of the zone where the disk should be created. Required for each regional disk associated with the instance. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


4001
4002
4003
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4001

def replica_zones
  @replica_zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4008
4009
4010
4011
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4008

def update!(**args)
  @disk_name = args[:disk_name] if args.key?(:disk_name)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
end