Class: Google::Apis::BackupdrV1::InitiateBackupRequest
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::InitiateBackupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
request message for InitiateBackup.
Instance Attribute Summary collapse
-
#backup_id ⇒ String
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InitiateBackupRequest
constructor
A new instance of InitiateBackupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InitiateBackupRequest
Returns a new instance of InitiateBackupRequest.
4144 4145 4146 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_id ⇒ String
Required. Resource ID of the Backup resource.
Corresponds to the JSON property backupId
4128 4129 4130 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4128 def backup_id @backup_id end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes since the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
4142 4143 4144 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4142 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4149 4150 4151 4152 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4149 def update!(**args) @backup_id = args[:backup_id] if args.key?(:backup_id) @request_id = args[:request_id] if args.key?(:request_id) end |