Class: Google::Apis::BackupdrV1::LabelKeyValPair

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message for a label key-value pair.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LabelKeyValPair

Returns a new instance of LabelKeyValPair.



4232
4233
4234
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Key of the label. The key must follow the format: \\pLl\\pLo0,62. This means the key must start with a lowercase letter or a lowercase international character, followed by zero or more lowercase letters, lowercase international characters, numbers, underscores, or dashes. The key must be at most 63 characters long. International characters are allowed. Corresponds to the JSON property key

Returns:

  • (String)


4222
4223
4224
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4222

def key
  @key
end

#valueString

Value of the label. The value must follow the format: [\\pLl\\pLo\\pN_-] 1,63`. This means the value must be one or more lowercase letters, lowercase international characters, numbers, underscores, or dashes. The value must be at most 63 characters long. International characters are allowed. Corresponds to the JSON propertyvalue`

Returns:

  • (String)


4230
4231
4232
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4230

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4237
4238
4239
4240
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4237

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end