Class: Google::Apis::BackupdrV1::ListBackupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListBackupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response message for listing Backups.
Instance Attribute Summary collapse
-
#backups ⇒ Array<Google::Apis::BackupdrV1::Backup>
The list of Backup instances in the project for the specified location.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupsResponse
constructor
A new instance of ListBackupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupsResponse
Returns a new instance of ListBackupsResponse.
4313 4314 4315 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Array<Google::Apis::BackupdrV1::Backup>
The list of Backup instances in the project for the specified location. If the
'location' value in the request is "-", the response contains a list of
instances from all locations. In case any location is unreachable, the
response will only return data sources in reachable locations and the '
unreachable' field will be populated with a list of unreachable locations.
Corresponds to the JSON property backups
4301 4302 4303 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4301 def backups @backups end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4306 4307 4308 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4306 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4311 4312 4313 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4311 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4318 4319 4320 4321 4322 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4318 def update!(**args) @backups = args[:backups] if args.key?(:backups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |