Class: Google::Apis::BackupdrV1::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::BackupdrV1::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
4381 4382 4383 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::BackupdrV1::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
4374 4375 4376 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4374 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
4379 4380 4381 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4379 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4386 4387 4388 4389 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4386 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |