Class: Google::Apis::BackupdrV1::ListManagementServersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Response message for listing management servers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListManagementServersResponse

Returns a new instance of ListManagementServersResponse.



4533
4534
4535
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_serversArray<Google::Apis::BackupdrV1::ManagementServer>

The list of ManagementServer instances in the project for the specified location. If the 'location' value in the request is "-", the response contains a list of instances from all locations. In case any location is unreachable, the response will only return management servers in reachable locations and the 'unreachable' field will be populated with a list of unreachable locations. Corresponds to the JSON property managementServers



4521
4522
4523
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4521

def management_servers
  @management_servers
end

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4526
4527
4528
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4526

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4531
4532
4533
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4531

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4538
4539
4540
4541
4542
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4538

def update!(**args)
  @management_servers = args[:management_servers] if args.key?(:management_servers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end