Class: Google::Apis::BackupdrV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



4567
4568
4569
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4552

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::BackupdrV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



4557
4558
4559
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4557

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4565
4566
4567
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4565

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4572
4573
4574
4575
4576
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4572

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end