Class: Google::Apis::BackupdrV1::ListResourceBackupConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListResourceBackupConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response for ListResourceBackupConfigs.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#resource_backup_configs ⇒ Array<Google::Apis::BackupdrV1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListResourceBackupConfigsResponse
constructor
A new instance of ListResourceBackupConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListResourceBackupConfigsResponse
Returns a new instance of ListResourceBackupConfigsResponse.
4516 4517 4518 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4509 4510 4511 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4509 def next_page_token @next_page_token end |
#resource_backup_configs ⇒ Array<Google::Apis::BackupdrV1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Corresponds to the JSON property resourceBackupConfigs
4514 4515 4516 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4514 def resource_backup_configs @resource_backup_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4521 4522 4523 4524 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4521 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_backup_configs = args[:resource_backup_configs] if args.key?(:resource_backup_configs) end |