Class: Google::Apis::BackupdrV1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



4560
4561
4562
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


4535
4536
4537
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4535

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4541
4542
4543
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4541

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4546

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


4552
4553
4554
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4552

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


4558
4559
4560
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4558

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4565
4566
4567
4568
4569
4570
4571
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4565

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end