Class: Google::Apis::BackupdrV1::LocationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::LocationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Instance Attribute Summary collapse
-
#unsupported_features ⇒ Array<String>
List of features that are not supported in the location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationMetadata
constructor
A new instance of LocationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationMetadata
Returns a new instance of LocationMetadata.
4583 4584 4585 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#unsupported_features ⇒ Array<String>
List of features that are not supported in the location.
Corresponds to the JSON property unsupportedFeatures
4581 4582 4583 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4581 def unsupported_features @unsupported_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4588 4589 4590 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4588 def update!(**args) @unsupported_features = args[:unsupported_features] if args.key?(:unsupported_features) end |