Class: Google::Apis::BackupdrV1::ManagementServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ManagementServer describes a single BackupDR ManagementServer instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementServer

Returns a new instance of ManagementServer.



4772
4773
4774
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ba_proxy_uriArray<String>

Output only. The hostname or ip address of the exposed AGM endpoints, used by BAs to connect to BA proxy. Corresponds to the JSON property baProxyUri

Returns:

  • (Array<String>)


4684
4685
4686
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4684

def ba_proxy_uri
  @ba_proxy_uri
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4689
4690
4691
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4689

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ManagementServer instance (2048 characters or less). Corresponds to the JSON property description

Returns:

  • (String)


4695
4696
4697
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4695

def description
  @description
end

#etagString

Optional. Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other. Corresponds to the JSON property etag

Returns:

  • (String)


4701
4702
4703
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4701

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. Labels currently defined: 1. migrate_from_go= If set to true, the MS is created in migration ready mode. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4708
4709
4710
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4708

def labels
  @labels
end

#management_uriGoogle::Apis::BackupdrV1::ManagementUri

ManagementURI for the Management Server resource. Corresponds to the JSON property managementUri



4713
4714
4715
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4713

def management_uri
  @management_uri
end

#nameString

Output only. Identifier. The resource name. Corresponds to the JSON property name

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4718

def name
  @name
end

#networksArray<Google::Apis::BackupdrV1::NetworkConfig>

Optional. VPC networks to which the ManagementServer instance is connected. For this version, only a single network is supported. This field is optional if MS is created without PSA Corresponds to the JSON property networks



4725
4726
4727
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4725

def networks
  @networks
end

#oauth2_client_idString

Output only. The OAuth 2.0 client id is required to make API calls to the Backup and DR instance API of this ManagementServer. This is the value that should be provided in the 'aud' field of the OIDC ID Token (see openid specification https://openid.net/specs/openid-connect-core-1_0.html#IDToken). Corresponds to the JSON property oauth2ClientId

Returns:

  • (String)


4733
4734
4735
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4733

def oauth2_client_id
  @oauth2_client_id
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


4738
4739
4740
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4738

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


4744
4745
4746
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4744

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The ManagementServer state. Corresponds to the JSON property state

Returns:

  • (String)


4750
4751
4752
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4750

def state
  @state
end

#typeString

Optional. The type of the ManagementServer resource. Corresponds to the JSON property type

Returns:

  • (String)


4755
4756
4757
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4755

def type
  @type
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4760
4761
4762
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4760

def update_time
  @update_time
end

#workforce_identity_based_management_uriGoogle::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri

ManagementURI depending on the Workforce Identity i.e. either 1p or 3p. Corresponds to the JSON property workforceIdentityBasedManagementUri



4765
4766
4767
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4765

def workforce_identity_based_management_uri
  @workforce_identity_based_management_uri
end

#workforce_identity_based_oauth2_client_idGoogle::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId

OAuth Client ID depending on the Workforce Identity i.e. either 1p or 3p, Corresponds to the JSON property workforceIdentityBasedOauth2ClientId



4770
4771
4772
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4770

def workforce_identity_based_oauth2_client_id
  @workforce_identity_based_oauth2_client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
4792
4793
4794
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4777

def update!(**args)
  @ba_proxy_uri = args[:ba_proxy_uri] if args.key?(:ba_proxy_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @management_uri = args[:management_uri] if args.key?(:management_uri)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workforce_identity_based_management_uri = args[:workforce_identity_based_management_uri] if args.key?(:workforce_identity_based_management_uri)
  @workforce_identity_based_oauth2_client_id = args[:workforce_identity_based_oauth2_client_id] if args.key?(:workforce_identity_based_oauth2_client_id)
end