Class: Google::Apis::BackupdrV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



5141
5142
5143
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_infoHash<String,String>

Output only. AdditionalInfo contains additional Info related to backup plan association resource. Corresponds to the JSON property additionalInfo

Returns:

  • (Hash<String,String>)


5100
5101
5102
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5100

def additional_info
  @additional_info
end

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


5105
5106
5107
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5105

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5110
5111
5112
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5110

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


5115
5116
5117
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5115

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to 'Code.CANCELLED'. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


5123
5124
5125
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5123

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


5129
5130
5131
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5129

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


5134
5135
5136
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5134

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


5139
5140
5141
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5139

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5146
5147
5148
5149
5150
5151
5152
5153
5154
5155
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5146

def update!(**args)
  @additional_info = args[:additional_info] if args.key?(:additional_info)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end