Class: Google::Apis::BackupdrV1::RemoveDataSourceRequest
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::RemoveDataSourceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Message for deleting a DataSource.
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveDataSourceRequest
constructor
A new instance of RemoveDataSourceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveDataSourceRequest
Returns a new instance of RemoveDataSourceRequest.
5229 5230 5231 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
5227 5228 5229 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5227 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5234 5235 5236 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5234 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) end |