Class: Google::Apis::BackupdrV1::RestoreBackupRequest
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::RestoreBackupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Request message for restoring from a Backup.
Instance Attribute Summary collapse
-
#clear_overrides_field_mask ⇒ String
Optional.
-
#compute_instance_restore_properties ⇒ Google::Apis::BackupdrV1::ComputeInstanceRestoreProperties
ComputeInstanceRestoreProperties represents Compute Engine instance properties to be overridden during restore.
-
#compute_instance_target_environment ⇒ Google::Apis::BackupdrV1::ComputeInstanceTargetEnvironment
ComputeInstanceTargetEnvironment represents Compute Engine target environment to be used during restore.
-
#disk_restore_properties ⇒ Google::Apis::BackupdrV1::DiskRestoreProperties
DiskRestoreProperties represents the properties of a Disk restore.
-
#disk_target_environment ⇒ Google::Apis::BackupdrV1::DiskTargetEnvironment
DiskTargetEnvironment represents the target environment for the disk.
-
#region_disk_target_environment ⇒ Google::Apis::BackupdrV1::RegionDiskTargetEnvironment
RegionDiskTargetEnvironment represents the target environment for the disk.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreBackupRequest
constructor
A new instance of RestoreBackupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreBackupRequest
Returns a new instance of RestoreBackupRequest.
5480 5481 5482 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5480 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clear_overrides_field_mask ⇒ String
Optional. A field mask used to clear server-side default values for fields
within the instance_properties oneof. When a field in this mask is cleared,
the server will not apply its default logic (like inheriting a value from the
source) for that field. The most common current use case is clearing default
encryption keys. Examples of field mask paths: - Compute Instance Disks:
compute_instance_restore_properties.disks.*.disk_encryption_key - Single Disk:
disk_restore_properties.disk_encryption_key
Corresponds to the JSON property clearOverridesFieldMask
5437 5438 5439 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5437 def clear_overrides_field_mask @clear_overrides_field_mask end |
#compute_instance_restore_properties ⇒ Google::Apis::BackupdrV1::ComputeInstanceRestoreProperties
ComputeInstanceRestoreProperties represents Compute Engine instance properties
to be overridden during restore.
Corresponds to the JSON property computeInstanceRestoreProperties
5443 5444 5445 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5443 def compute_instance_restore_properties @compute_instance_restore_properties end |
#compute_instance_target_environment ⇒ Google::Apis::BackupdrV1::ComputeInstanceTargetEnvironment
ComputeInstanceTargetEnvironment represents Compute Engine target environment
to be used during restore.
Corresponds to the JSON property computeInstanceTargetEnvironment
5449 5450 5451 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5449 def compute_instance_target_environment @compute_instance_target_environment end |
#disk_restore_properties ⇒ Google::Apis::BackupdrV1::DiskRestoreProperties
DiskRestoreProperties represents the properties of a Disk restore.
Corresponds to the JSON property diskRestoreProperties
5454 5455 5456 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5454 def disk_restore_properties @disk_restore_properties end |
#disk_target_environment ⇒ Google::Apis::BackupdrV1::DiskTargetEnvironment
DiskTargetEnvironment represents the target environment for the disk.
Corresponds to the JSON property diskTargetEnvironment
5459 5460 5461 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5459 def disk_target_environment @disk_target_environment end |
#region_disk_target_environment ⇒ Google::Apis::BackupdrV1::RegionDiskTargetEnvironment
RegionDiskTargetEnvironment represents the target environment for the disk.
Corresponds to the JSON property regionDiskTargetEnvironment
5464 5465 5466 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5464 def region_disk_target_environment @region_disk_target_environment end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
5478 5479 5480 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5478 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5485 5486 5487 5488 5489 5490 5491 5492 5493 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5485 def update!(**args) @clear_overrides_field_mask = args[:clear_overrides_field_mask] if args.key?(:clear_overrides_field_mask) @compute_instance_restore_properties = args[:compute_instance_restore_properties] if args.key?(:compute_instance_restore_properties) @compute_instance_target_environment = args[:compute_instance_target_environment] if args.key?(:compute_instance_target_environment) @disk_restore_properties = args[:disk_restore_properties] if args.key?(:disk_restore_properties) @disk_target_environment = args[:disk_target_environment] if args.key?(:disk_target_environment) @region_disk_target_environment = args[:region_disk_target_environment] if args.key?(:region_disk_target_environment) @request_id = args[:request_id] if args.key?(:request_id) end |