Class: Google::Apis::BackupdrV1::RestoreDiskFromInstanceOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Options for creating a disk from a source Compute Instance backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreDiskFromInstanceOptions

Returns a new instance of RestoreDiskFromInstanceOptions.



5531
5532
5533
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boot_diskBoolean Also known as: boot_disk?

Specifies that the boot disk should be restored from the instance backup. This field should only be set to true if selected. Corresponds to the JSON property bootDisk

Returns:

  • (Boolean)


5523
5524
5525
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5523

def boot_disk
  @boot_disk
end

#source_device_nameString

The device name of the disk to restore from the VM backup. Corresponds to the JSON property sourceDeviceName

Returns:

  • (String)


5529
5530
5531
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5529

def source_device_name
  @source_device_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5536
5537
5538
5539
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5536

def update!(**args)
  @boot_disk = args[:boot_disk] if args.key?(:boot_disk)
  @source_device_name = args[:source_device_name] if args.key?(:source_device_name)
end