Class: Google::Apis::BackupdrV1::Scheduling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Sets the scheduling options for an Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scheduling

Returns a new instance of Scheduling.



5637
5638
5639
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_restartBoolean Also known as: automatic_restart?

Optional. Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). Corresponds to the JSON property automaticRestart

Returns:

  • (Boolean)


5593
5594
5595
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5593

def automatic_restart
  @automatic_restart
end

#instance_termination_actionString

Optional. Specifies the termination action for the instance. Corresponds to the JSON property instanceTerminationAction

Returns:

  • (String)


5599
5600
5601
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5599

def instance_termination_action
  @instance_termination_action
end

#local_ssd_recovery_timeoutGoogle::Apis::BackupdrV1::SchedulingDuration

A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property localSsdRecoveryTimeout



5607
5608
5609
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5607

def local_ssd_recovery_timeout
  @local_ssd_recovery_timeout
end

#min_node_cpusFixnum

Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


5613
5614
5615
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5613

def min_node_cpus
  @min_node_cpus
end

#node_affinitiesArray<Google::Apis::BackupdrV1::NodeAffinity>

Optional. A set of node affinity and anti-affinity configurations. Overrides reservationAffinity. Corresponds to the JSON property nodeAffinities



5619
5620
5621
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5619

def node_affinities
  @node_affinities
end

#on_host_maintenanceString

Optional. Defines the maintenance behavior for this instance. Corresponds to the JSON property onHostMaintenance

Returns:

  • (String)


5624
5625
5626
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5624

def on_host_maintenance
  @on_host_maintenance
end

#preemptibleBoolean Also known as: preemptible?

Optional. Defines whether the instance is preemptible. Corresponds to the JSON property preemptible

Returns:

  • (Boolean)


5629
5630
5631
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5629

def preemptible
  @preemptible
end

#provisioning_modelString

Optional. Specifies the provisioning model of the instance. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


5635
5636
5637
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5635

def provisioning_model
  @provisioning_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5642

def update!(**args)
  @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart)
  @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action)
  @local_ssd_recovery_timeout = args[:local_ssd_recovery_timeout] if args.key?(:local_ssd_recovery_timeout)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
  @node_affinities = args[:node_affinities] if args.key?(:node_affinities)
  @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance)
  @preemptible = args[:preemptible] if args.key?(:preemptible)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
end