Class: Google::Apis::BackupdrV1::SchedulingDuration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingDuration

Returns a new instance of SchedulingDuration.



5671
5672
5673
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Optional. Span of time that's a fraction of a second at nanosecond resolution. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


5664
5665
5666
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5664

def nanos
  @nanos
end

#secondsFixnum

Optional. Span of time at a resolution of a second. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


5669
5670
5671
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5669

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5676
5677
5678
5679
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5676

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end