Class: Google::Apis::BackupdrV1::SetInternalStatusRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Request message for SetStatusInternal method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetInternalStatusRequest

Returns a new instance of SetInternalStatusRequest.



5810
5811
5812
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_config_stateString

Required. Output only. The new BackupConfigState to set for the DataSource. Corresponds to the JSON property backupConfigState

Returns:

  • (String)


5788
5789
5790
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5788

def backup_config_state
  @backup_config_state
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000- 0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


5798
5799
5800
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5798

def request_id
  @request_id
end

#valueString

Required. The value required for this method to work. This field must be the 32-byte SHA256 hash of the DataSourceID. The DataSourceID used here is only the final piece of the fully qualified resource path for this DataSource (i.e. the part after '.../dataSources/'). This field exists to make this method difficult to call since it is intended for use only by Backup Appliances. Corresponds to the JSON property value NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5808
5809
5810
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5808

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5815
5816
5817
5818
5819
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5815

def update!(**args)
  @backup_config_state = args[:backup_config_state] if args.key?(:backup_config_state)
  @request_id = args[:request_id] if args.key?(:request_id)
  @value = args[:value] if args.key?(:value)
end