Class: Google::Apis::BackupdrV1::BackupDrPlanRule
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::BackupDrPlanRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupDrPlanRule has rule specific information of the backup plan resource.
Instance Attribute Summary collapse
-
#last_successful_backup_time ⇒ String
Output only.
-
#rule_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupDrPlanRule
constructor
A new instance of BackupDrPlanRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupDrPlanRule
Returns a new instance of BackupDrPlanRule.
1101 1102 1103 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_successful_backup_time ⇒ String
Output only. Timestamp of the latest successful backup created via this backup
rule.
Corresponds to the JSON property lastSuccessfulBackupTime
1094 1095 1096 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1094 def last_successful_backup_time @last_successful_backup_time end |
#rule_id ⇒ String
Output only. Unique Id of the backup rule.
Corresponds to the JSON property ruleId
1099 1100 1101 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1099 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1106 1107 1108 1109 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1106 def update!(**args) @last_successful_backup_time = args[:last_successful_backup_time] if args.key?(:last_successful_backup_time) @rule_id = args[:rule_id] if args.key?(:rule_id) end |