Class: Google::Apis::BackupdrV1::BackupPlanAssociation
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::BackupPlanAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
A BackupPlanAssociation represents a single BackupPlanAssociation which contains details like workload, backup plan etc
Instance Attribute Summary collapse
-
#alloydb_cluster_backup_plan_association_properties ⇒ Google::Apis::BackupdrV1::AlloyDbClusterBackupPlanAssociationProperties
Properties for an AlloyDB cluster backup plan association.
-
#backup_plan ⇒ String
Required.
-
#backup_plan_revision_id ⇒ String
Output only.
-
#backup_plan_revision_name ⇒ String
Output only.
-
#cloud_sql_instance_backup_plan_association_properties ⇒ Google::Apis::BackupdrV1::CloudSqlInstanceBackupPlanAssociationProperties
Cloud SQL instance's BPA properties.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ String
Output only.
-
#filestore_instance_backup_plan_association_properties ⇒ Google::Apis::BackupdrV1::FilestoreInstanceBackupPlanAssociationProperties
Filestore instance's BPA properties.
-
#name ⇒ String
Output only.
-
#resource ⇒ String
Required.
-
#resource_type ⇒ String
Required.
-
#rules_config_info ⇒ Array<Google::Apis::BackupdrV1::RuleConfigInfo>
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupPlanAssociation
constructor
A new instance of BackupPlanAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupPlanAssociation
Returns a new instance of BackupPlanAssociation.
1463 1464 1465 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alloydb_cluster_backup_plan_association_properties ⇒ Google::Apis::BackupdrV1::AlloyDbClusterBackupPlanAssociationProperties
Properties for an AlloyDB cluster backup plan association.
Corresponds to the JSON property alloydbClusterBackupPlanAssociationProperties
1384 1385 1386 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1384 def alloydb_cluster_backup_plan_association_properties @alloydb_cluster_backup_plan_association_properties end |
#backup_plan ⇒ String
Required. Resource name of backup plan which needs to be applied on workload.
Format: projects/project/locations/location/backupPlans/backupPlanId
Corresponds to the JSON property backupPlan
1390 1391 1392 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1390 def backup_plan @backup_plan end |
#backup_plan_revision_id ⇒ String
Output only. The user friendly revision ID of the BackupPlanRevision.
Example: v0, v1, v2, etc.
Corresponds to the JSON property backupPlanRevisionId
1396 1397 1398 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1396 def backup_plan_revision_id @backup_plan_revision_id end |
#backup_plan_revision_name ⇒ String
Output only. The resource id of the BackupPlanRevision. Format: projects/
project/locations/location/backupPlans/backup_plan/revisions/revision_id
Corresponds to the JSON property backupPlanRevisionName
1403 1404 1405 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1403 def backup_plan_revision_name @backup_plan_revision_name end |
#cloud_sql_instance_backup_plan_association_properties ⇒ Google::Apis::BackupdrV1::CloudSqlInstanceBackupPlanAssociationProperties
Cloud SQL instance's BPA properties.
Corresponds to the JSON property cloudSqlInstanceBackupPlanAssociationProperties
1408 1409 1410 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1408 def cloud_sql_instance_backup_plan_association_properties @cloud_sql_instance_backup_plan_association_properties end |
#create_time ⇒ String
Output only. The time when the instance was created.
Corresponds to the JSON property createTime
1413 1414 1415 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1413 def create_time @create_time end |
#data_source ⇒ String
Output only. Resource name of data source which will be used as storage
location for backups taken. Format : projects/project/locations/location/
backupVaults/backupvault/dataSources/datasource
Corresponds to the JSON property dataSource
1420 1421 1422 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1420 def data_source @data_source end |
#filestore_instance_backup_plan_association_properties ⇒ Google::Apis::BackupdrV1::FilestoreInstanceBackupPlanAssociationProperties
Filestore instance's BPA properties.
Corresponds to the JSON property filestoreInstanceBackupPlanAssociationProperties
1425 1426 1427 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1425 def filestore_instance_backup_plan_association_properties @filestore_instance_backup_plan_association_properties end |
#name ⇒ String
Output only. Identifier. The resource name of BackupPlanAssociation in below
format Format : projects/project/locations/location/backupPlanAssociations/
backupPlanAssociationId
Corresponds to the JSON property name
1432 1433 1434 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1432 def name @name end |
#resource ⇒ String
Required. Immutable. Resource name of workload on which the backup plan is
applied. The format can either be the resource name (e.g., "projects/my-
project/zones/us-central1-a/instances/my-instance") or the full resource URI (
e.g., "https://www.googleapis.com/compute/v1/projects/my-project/zones/us-
central1-a/instances/my-instance").
Corresponds to the JSON property resource
1441 1442 1443 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1441 def resource @resource end |
#resource_type ⇒ String
Required. Immutable. Resource type of workload on which backupplan is applied
Corresponds to the JSON property resourceType
1446 1447 1448 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1446 def resource_type @resource_type end |
#rules_config_info ⇒ Array<Google::Apis::BackupdrV1::RuleConfigInfo>
Output only. The config info related to backup rules.
Corresponds to the JSON property rulesConfigInfo
1451 1452 1453 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1451 def rules_config_info @rules_config_info end |
#state ⇒ String
Output only. The BackupPlanAssociation resource state.
Corresponds to the JSON property state
1456 1457 1458 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1456 def state @state end |
#update_time ⇒ String
Output only. The time when the instance was updated.
Corresponds to the JSON property updateTime
1461 1462 1463 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1461 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1468 def update!(**args) @alloydb_cluster_backup_plan_association_properties = args[:alloydb_cluster_backup_plan_association_properties] if args.key?(:alloydb_cluster_backup_plan_association_properties) @backup_plan = args[:backup_plan] if args.key?(:backup_plan) @backup_plan_revision_id = args[:backup_plan_revision_id] if args.key?(:backup_plan_revision_id) @backup_plan_revision_name = args[:backup_plan_revision_name] if args.key?(:backup_plan_revision_name) @cloud_sql_instance_backup_plan_association_properties = args[:cloud_sql_instance_backup_plan_association_properties] if args.key?(:cloud_sql_instance_backup_plan_association_properties) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @filestore_instance_backup_plan_association_properties = args[:filestore_instance_backup_plan_association_properties] if args.key?(:filestore_instance_backup_plan_association_properties) @name = args[:name] if args.key?(:name) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @rules_config_info = args[:rules_config_info] if args.key?(:rules_config_info) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |