Class: Google::Apis::BackupdrV1::BackupRule
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::BackupRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupRule binds the backup schedule to a retention policy.
Instance Attribute Summary collapse
-
#backup_retention_days ⇒ Fixnum
Required.
-
#rule_id ⇒ String
Required.
-
#standard_schedule ⇒ Google::Apis::BackupdrV1::StandardSchedule
StandardScheduledefines a schedule that run within the confines of a defined window of days.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupRule
constructor
A new instance of BackupRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupRule
Returns a new instance of BackupRule.
1565 1566 1567 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_retention_days ⇒ Fixnum
Required. Configures the duration for which backup data will be kept. It is
defined in “days”. The value should be greater than or equal to minimum
enforced retention of the backup vault. Minimum value is 1 and maximum value
is 36159 for custom retention on-demand backup. Minimum and maximum values are
workload specific for all other rules. Note: Longer retention can lead to
higher storage costs post introductory trial. We recommend starting with a
short duration of 3 days or less.
Corresponds to the JSON property backupRetentionDays
1548 1549 1550 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1548 def backup_retention_days @backup_retention_days end |
#rule_id ⇒ String
Required. Immutable. The unique id of this BackupRule. The rule_id is
unique per BackupPlan.The rule_id must start with a lowercase letter
followed by up to 62 lowercase letters, numbers, or hyphens. Pattern, /a-z,62
/.
Corresponds to the JSON property ruleId
1556 1557 1558 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1556 def rule_id @rule_id end |
#standard_schedule ⇒ Google::Apis::BackupdrV1::StandardSchedule
StandardSchedule defines a schedule that run within the confines of a
defined window of days. We can define recurrence type for schedule as HOURLY,
DAILY, WEEKLY, MONTHLY or YEARLY.
Corresponds to the JSON property standardSchedule
1563 1564 1565 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1563 def standard_schedule @standard_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1570 1571 1572 1573 1574 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 1570 def update!(**args) @backup_retention_days = args[:backup_retention_days] if args.key?(:backup_retention_days) @rule_id = args[:rule_id] if args.key?(:rule_id) @standard_schedule = args[:standard_schedule] if args.key?(:standard_schedule) end |