Class: Google::Apis::BackupdrV1::ComputeInstanceBackupPlanProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ComputeInstanceBackupPlanProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Properties for a compute instance backup plan.
Instance Attribute Summary collapse
-
#boot_disk_only ⇒ Boolean
(also: #boot_disk_only?)
Optional.
-
#disk_exclusion_labels ⇒ Google::Apis::BackupdrV1::DiskExclusionLabels
Message for selective disk backup exclusion labels.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComputeInstanceBackupPlanProperties
constructor
A new instance of ComputeInstanceBackupPlanProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComputeInstanceBackupPlanProperties
Returns a new instance of ComputeInstanceBackupPlanProperties.
2055 2056 2057 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boot_disk_only ⇒ Boolean Also known as: boot_disk_only?
Optional. If true, only the boot disk will be backed up.
Corresponds to the JSON property bootDiskOnly
2039 2040 2041 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2039 def boot_disk_only @boot_disk_only end |
#disk_exclusion_labels ⇒ Google::Apis::BackupdrV1::DiskExclusionLabels
Message for selective disk backup exclusion labels.
Corresponds to the JSON property diskExclusionLabels
2045 2046 2047 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2045 def disk_exclusion_labels @disk_exclusion_labels end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
Optional. Indicates whether to perform a guest flush operation before taking a
compute backup. When set to false, the system will create crash-consistent
backups. Default value is false.
Corresponds to the JSON property guestFlush
2052 2053 2054 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2052 def guest_flush @guest_flush end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2060 def update!(**args) @boot_disk_only = args[:boot_disk_only] if args.key?(:boot_disk_only) @disk_exclusion_labels = args[:disk_exclusion_labels] if args.key?(:disk_exclusion_labels) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) end |