Class: Google::Apis::BackupdrV1::ComputeInstanceBackupPlanProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ComputeInstanceBackupPlanProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
--- ComputeInstanceBackupPlanProperties Message ---
Instance Attribute Summary collapse
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComputeInstanceBackupPlanProperties
constructor
A new instance of ComputeInstanceBackupPlanProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComputeInstanceBackupPlanProperties
Returns a new instance of ComputeInstanceBackupPlanProperties.
2044 2045 2046 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2044 def initialize(**args) update!(**args) end |
Instance Attribute Details
#guest_flush ⇒ Boolean Also known as: guest_flush?
Optional. Indicates whether to perform a guest flush operation before taking a
compute backup. When set to false, the system will create crash-consistent
backups. Default value is false.
Corresponds to the JSON property guestFlush
2041 2042 2043 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2041 def guest_flush @guest_flush end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2049 2050 2051 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2049 def update!(**args) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) end |