Class: Google::Apis::BackupdrV1::ComputeInstanceBackupProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ComputeInstanceBackupProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
ComputeInstanceBackupProperties represents Compute Engine instance backup properties.
Instance Attribute Summary collapse
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#description ⇒ String
An optional text description for the instances that are created from these properties.
-
#disk ⇒ Array<Google::Apis::BackupdrV1::AttachedDisk>
An array of disks that are associated with the instances that are created from these properties.
-
#excluded_disks ⇒ Array<String>
Optional.
-
#guest_accelerator ⇒ Array<Google::Apis::BackupdrV1::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from these properties.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Optional.
-
#included_disks ⇒ Array<String>
Optional.
-
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance.
-
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from these properties.
-
#machine_type ⇒ String
The machine type to use for instances that are created from these properties.
-
#metadata ⇒ Google::Apis::BackupdrV1::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances.
-
#network_interface ⇒ Array<Google::Apis::BackupdrV1::NetworkInterface>
An array of network access configurations for this interface.
-
#scheduling ⇒ Google::Apis::BackupdrV1::Scheduling
Sets the scheduling options for an Instance.
-
#service_account ⇒ Array<Google::Apis::BackupdrV1::ServiceAccount>
A list of service accounts with specified scopes.
-
#source_instance ⇒ String
The source instance used to create this backup.
-
#tags ⇒ Google::Apis::BackupdrV1::Tags
A set of instance tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComputeInstanceBackupProperties
constructor
A new instance of ComputeInstanceBackupProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComputeInstanceBackupProperties
Returns a new instance of ComputeInstanceBackupProperties.
2180 2181 2182 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Enables instances created based on these properties to send packets with
source IP addresses other than their own and receive packets with destination
IP addresses other than their own. If these instances will be used as an IP
gateway or it will be set as the next-hop in a Route resource, specify true.
If unsure, leave this set to false. See the https://cloud.google.com/vpc/
docs/using-routes#canipforward documentation for more information.
Corresponds to the JSON property canIpForward
2080 2081 2082 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2080 def can_ip_forward @can_ip_forward end |
#description ⇒ String
An optional text description for the instances that are created from these
properties.
Corresponds to the JSON property description
2087 2088 2089 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2087 def description @description end |
#disk ⇒ Array<Google::Apis::BackupdrV1::AttachedDisk>
An array of disks that are associated with the instances that are created from
these properties.
Corresponds to the JSON property disk
2093 2094 2095 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2093 def disk @disk end |
#excluded_disks ⇒ Array<String>
Optional. List of disks excluded from the backup.
Corresponds to the JSON property excludedDisks
2098 2099 2100 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2098 def excluded_disks @excluded_disks end |
#guest_accelerator ⇒ Array<Google::Apis::BackupdrV1::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created
from these properties.
Corresponds to the JSON property guestAccelerator
2104 2105 2106 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2104 def guest_accelerator @guest_accelerator end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
Optional. Indicates whether to perform a guest flush operation before taking a
compute backup. When set to false, the system will create crash-consistent
backups. Default value is false.
Corresponds to the JSON property guestFlush
2111 2112 2113 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2111 def guest_flush @guest_flush end |
#included_disks ⇒ Array<String>
Optional. List of disks included in the backup.
Corresponds to the JSON property includedDisks
2117 2118 2119 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2117 def included_disks @included_disks end |
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance. Supported options are "STOP" and "
NONE". The default value is "NONE" if it is not specified.
Corresponds to the JSON property keyRevocationActionType
2123 2124 2125 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2123 def key_revocation_action_type @key_revocation_action_type end |
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from these properties.
Corresponds to the JSON property labels
2128 2129 2130 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2128 def labels @labels end |
#machine_type ⇒ String
The machine type to use for instances that are created from these properties.
Corresponds to the JSON property machineType
2133 2134 2135 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2133 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::BackupdrV1::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
2138 2139 2140 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2138 def @metadata end |
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances. The instance may be scheduled on
the specified or newer cpu/platform. Applicable values are the friendly names
of CPU platforms, such as minCpuPlatform: Intel Haswell or minCpuPlatform:
Intel Sandy Bridge. For more information, read https://cloud.google.com/
compute/docs/instances/specify-min-cpu-platform.
Corresponds to the JSON property minCpuPlatform
2147 2148 2149 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2147 def min_cpu_platform @min_cpu_platform end |
#network_interface ⇒ Array<Google::Apis::BackupdrV1::NetworkInterface>
An array of network access configurations for this interface.
Corresponds to the JSON property networkInterface
2152 2153 2154 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2152 def network_interface @network_interface end |
#scheduling ⇒ Google::Apis::BackupdrV1::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
2157 2158 2159 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2157 def scheduling @scheduling end |
#service_account ⇒ Array<Google::Apis::BackupdrV1::ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from these
properties. Use metadata queries to obtain the access tokens for these
instances.
Corresponds to the JSON property serviceAccount
2165 2166 2167 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2165 def service_account @service_account end |
#source_instance ⇒ String
The source instance used to create this backup. This can be a partial or full
URL to the resource. For example, the following are valid values: -https://www.
googleapis.com/compute/v1/projects/project/zones/zone/instances/instance -
projects/project/zones/zone/instances/instance
Corresponds to the JSON property sourceInstance
2173 2174 2175 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2173 def source_instance @source_instance end |
#tags ⇒ Google::Apis::BackupdrV1::Tags
A set of instance tags.
Corresponds to the JSON property tags
2178 2179 2180 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2178 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2185 def update!(**args) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @description = args[:description] if args.key?(:description) @disk = args[:disk] if args.key?(:disk) @excluded_disks = args[:excluded_disks] if args.key?(:excluded_disks) @guest_accelerator = args[:guest_accelerator] if args.key?(:guest_accelerator) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) @included_disks = args[:included_disks] if args.key?(:included_disks) @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type) @labels = args[:labels] if args.key?(:labels) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @network_interface = args[:network_interface] if args.key?(:network_interface) @scheduling = args[:scheduling] if args.key?(:scheduling) @service_account = args[:service_account] if args.key?(:service_account) @source_instance = args[:source_instance] if args.key?(:source_instance) @tags = args[:tags] if args.key?(:tags) end |