Class: Google::Apis::BackupdrV1::ComputeInstanceBackupProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ComputeInstanceBackupProperties represents Compute Engine instance backup properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeInstanceBackupProperties

Returns a new instance of ComputeInstanceBackupProperties.



2157
2158
2159
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set to false. See the https://cloud.google.com/vpc/ docs/using-routes#canipforward documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


2067
2068
2069
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2067

def can_ip_forward
  @can_ip_forward
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2074

def description
  @description
end

#diskArray<Google::Apis::BackupdrV1::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disk



2080
2081
2082
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2080

def disk
  @disk
end

#guest_acceleratorArray<Google::Apis::BackupdrV1::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerator



2086
2087
2088
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2086

def guest_accelerator
  @guest_accelerator
end

#guest_flushBoolean Also known as: guest_flush?

Optional. Indicates whether to perform a guest flush operation before taking a compute backup. When set to false, the system will create crash-consistent backups. Default value is false. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


2093
2094
2095
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2093

def guest_flush
  @guest_flush
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and " NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


2100
2101
2102
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2100

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2105
2106
2107
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2105

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from these properties. Corresponds to the JSON property machineType

Returns:

  • (String)


2110
2111
2112
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2110

def machine_type
  @machine_type
end

#metadataGoogle::Apis::BackupdrV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



2115
2116
2117
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2115

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: Intel Haswell or minCpuPlatform: Intel Sandy Bridge. For more information, read https://cloud.google.com/ compute/docs/instances/specify-min-cpu-platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


2124
2125
2126
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2124

def min_cpu_platform
  @min_cpu_platform
end

#network_interfaceArray<Google::Apis::BackupdrV1::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterface



2129
2130
2131
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2129

def network_interface
  @network_interface
end

#schedulingGoogle::Apis::BackupdrV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



2134
2135
2136
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2134

def scheduling
  @scheduling
end

#service_accountArray<Google::Apis::BackupdrV1::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccount



2142
2143
2144
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2142

def 
  @service_account
end

#source_instanceString

The source instance used to create this backup. This can be a partial or full URL to the resource. For example, the following are valid values: -https://www. googleapis.com/compute/v1/projects/project/zones/zone/instances/instance - projects/project/zones/zone/instances/instance Corresponds to the JSON property sourceInstance

Returns:

  • (String)


2150
2151
2152
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2150

def source_instance
  @source_instance
end

#tagsGoogle::Apis::BackupdrV1::Tags

A set of instance tags. Corresponds to the JSON property tags



2155
2156
2157
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2155

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2162

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @description = args[:description] if args.key?(:description)
  @disk = args[:disk] if args.key?(:disk)
  @guest_accelerator = args[:guest_accelerator] if args.key?(:guest_accelerator)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interface = args[:network_interface] if args.key?(:network_interface)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_instance = args[:source_instance] if args.key?(:source_instance)
  @tags = args[:tags] if args.key?(:tags)
end