Class: Google::Apis::BackupdrV1::CustomerEncryptionKey
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::CustomerEncryptionKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
A customer-supplied encryption key.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
-
#kms_key_service_account ⇒ String
Optional.
-
#raw_key ⇒ String
Optional.
-
#rsa_encrypted_key ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomerEncryptionKey
constructor
A new instance of CustomerEncryptionKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomerEncryptionKey
Returns a new instance of CustomerEncryptionKey.
2479 2480 2481 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The name of the encryption key that is stored in Google Cloud KMS.
Corresponds to the JSON property kmsKeyName
2460 2461 2462 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2460 def kms_key_name @kms_key_name end |
#kms_key_service_account ⇒ String
Optional. The service account being used for the encryption request for the
given KMS key. If absent, the Compute Engine default service account is used.
Corresponds to the JSON property kmsKeyServiceAccount
2466 2467 2468 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2466 def kms_key_service_account @kms_key_service_account end |
#raw_key ⇒ String
Optional. Specifies a 256-bit customer-supplied encryption key.
Corresponds to the JSON property rawKey
2471 2472 2473 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2471 def raw_key @raw_key end |
#rsa_encrypted_key ⇒ String
Optional. RSA-wrapped 2048-bit customer-supplied encryption key to either
encrypt or decrypt this resource.
Corresponds to the JSON property rsaEncryptedKey
2477 2478 2479 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2477 def rsa_encrypted_key @rsa_encrypted_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2484 2485 2486 2487 2488 2489 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2484 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_service_account = args[:kms_key_service_account] if args.key?(:kms_key_service_account) @raw_key = args[:raw_key] if args.key?(:raw_key) @rsa_encrypted_key = args[:rsa_encrypted_key] if args.key?(:rsa_encrypted_key) end |