Class: Google::Apis::BackupdrV1::DataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message describing a DataSource object. Datasource object used to represent Datasource details for both admin and basic view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSource

Returns a new instance of DataSource.



2582
2583
2584
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_blocked_by_vault_access_restrictionBoolean Also known as: backup_blocked_by_vault_access_restriction?

Output only. This field is set to true if the backup is blocked by vault access restriction. Corresponds to the JSON property backupBlockedByVaultAccessRestriction

Returns:

  • (Boolean)


2509
2510
2511
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2509

def backup_blocked_by_vault_access_restriction
  @backup_blocked_by_vault_access_restriction
end

#backup_config_infoGoogle::Apis::BackupdrV1::BackupConfigInfo

BackupConfigInfo has information about how the resource is configured for Backup and about the most recent backup to this vault. Corresponds to the JSON property backupConfigInfo



2516
2517
2518
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2516

def backup_config_info
  @backup_config_info
end

#backup_countFixnum

Number of backups in the data source. Corresponds to the JSON property backupCount

Returns:

  • (Fixnum)


2521
2522
2523
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2521

def backup_count
  @backup_count
end

#config_stateString

Output only. The backup configuration state. Corresponds to the JSON property configState

Returns:

  • (String)


2526
2527
2528
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2526

def config_state
  @config_state
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2531
2532
2533
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2531

def create_time
  @create_time
end

#data_source_backup_appliance_applicationGoogle::Apis::BackupdrV1::DataSourceBackupApplianceApplication

BackupApplianceApplication describes a Source Resource when it is an application backed up by a BackupAppliance. Corresponds to the JSON property dataSourceBackupApplianceApplication



2537
2538
2539
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2537

def data_source_backup_appliance_application
  @data_source_backup_appliance_application
end

#data_source_gcp_resourceGoogle::Apis::BackupdrV1::DataSourceGcpResource

DataSourceGcpResource is used for protected resources that are Google Cloud Resources. This name is easeier to understand than GcpResourceDataSource or GcpDataSourceResource Corresponds to the JSON property dataSourceGcpResource



2544
2545
2546
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2544

def data_source_gcp_resource
  @data_source_gcp_resource
end

#etagString

Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other. Corresponds to the JSON property etag

Returns:

  • (String)


2550
2551
2552
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2550

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. No labels currently defined: Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2556
2557
2558
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2556

def labels
  @labels
end

#nameString

Output only. Identifier. Name of the datasource to create. It must have the format"projects/project/locations/location/backupVaults/backupvault/ dataSources/datasource". datasource cannot be changed after creation. It must be between 3-63 characters long and must be unique within the backup vault. Corresponds to the JSON property name

Returns:

  • (String)


2565
2566
2567
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2565

def name
  @name
end

#stateString

Output only. The DataSource resource instance state. Corresponds to the JSON property state

Returns:

  • (String)


2570
2571
2572
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2570

def state
  @state
end

#total_stored_bytesFixnum

The number of bytes (metadata and data) stored in this datasource. Corresponds to the JSON property totalStoredBytes

Returns:

  • (Fixnum)


2575
2576
2577
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2575

def total_stored_bytes
  @total_stored_bytes
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2580
2581
2582
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2580

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2587

def update!(**args)
  @backup_blocked_by_vault_access_restriction = args[:backup_blocked_by_vault_access_restriction] if args.key?(:backup_blocked_by_vault_access_restriction)
  @backup_config_info = args[:backup_config_info] if args.key?(:backup_config_info)
  @backup_count = args[:backup_count] if args.key?(:backup_count)
  @config_state = args[:config_state] if args.key?(:config_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source_backup_appliance_application = args[:data_source_backup_appliance_application] if args.key?(:data_source_backup_appliance_application)
  @data_source_gcp_resource = args[:data_source_gcp_resource] if args.key?(:data_source_gcp_resource)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @total_stored_bytes = args[:total_stored_bytes] if args.key?(:total_stored_bytes)
  @update_time = args[:update_time] if args.key?(:update_time)
end