Class: Google::Apis::BackupdrV1::DataSourceBackupApplianceApplication
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DataSourceBackupApplianceApplication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupApplianceApplication describes a Source Resource when it is an application backed up by a BackupAppliance.
Instance Attribute Summary collapse
-
#appliance_id ⇒ Fixnum
Appliance Id of the Backup Appliance.
-
#application_id ⇒ Fixnum
The appid field of the application within the Backup Appliance.
-
#application_name ⇒ String
The name of the Application as known to the Backup Appliance.
-
#backup_appliance ⇒ String
Appliance name.
-
#host_id ⇒ Fixnum
Hostid of the application host.
-
#hostname ⇒ String
Hostname of the host where the application is running.
-
#type ⇒ String
The type of the application.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceBackupApplianceApplication
constructor
A new instance of DataSourceBackupApplianceApplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceBackupApplianceApplication
Returns a new instance of DataSourceBackupApplianceApplication.
2644 2645 2646 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appliance_id ⇒ Fixnum
Appliance Id of the Backup Appliance.
Corresponds to the JSON property applianceId
2612 2613 2614 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2612 def appliance_id @appliance_id end |
#application_id ⇒ Fixnum
The appid field of the application within the Backup Appliance.
Corresponds to the JSON property applicationId
2617 2618 2619 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2617 def application_id @application_id end |
#application_name ⇒ String
The name of the Application as known to the Backup Appliance.
Corresponds to the JSON property applicationName
2622 2623 2624 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2622 def application_name @application_name end |
#backup_appliance ⇒ String
Appliance name.
Corresponds to the JSON property backupAppliance
2627 2628 2629 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2627 def backup_appliance @backup_appliance end |
#host_id ⇒ Fixnum
Hostid of the application host.
Corresponds to the JSON property hostId
2632 2633 2634 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2632 def host_id @host_id end |
#hostname ⇒ String
Hostname of the host where the application is running.
Corresponds to the JSON property hostname
2637 2638 2639 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2637 def hostname @hostname end |
#type ⇒ String
The type of the application. e.g. VMBackup
Corresponds to the JSON property type
2642 2643 2644 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2642 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2649 2650 2651 2652 2653 2654 2655 2656 2657 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2649 def update!(**args) @appliance_id = args[:appliance_id] if args.key?(:appliance_id) @application_id = args[:application_id] if args.key?(:application_id) @application_name = args[:application_name] if args.key?(:application_name) @backup_appliance = args[:backup_appliance] if args.key?(:backup_appliance) @host_id = args[:host_id] if args.key?(:host_id) @hostname = args[:hostname] if args.key?(:hostname) @type = args[:type] if args.key?(:type) end |