Class: Google::Apis::BackupdrV1::DataSourceBackupApplianceApplication
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DataSourceBackupApplianceApplication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
BackupApplianceApplication describes a Source Resource when it is an application backed up by a BackupAppliance.
Instance Attribute Summary collapse
-
#appliance_id ⇒ Fixnum
Appliance Id of the Backup Appliance.
-
#application_id ⇒ Fixnum
The appid field of the application within the Backup Appliance.
-
#application_name ⇒ String
The name of the Application as known to the Backup Appliance.
-
#backup_appliance ⇒ String
Appliance name.
-
#host_id ⇒ Fixnum
Hostid of the application host.
-
#hostname ⇒ String
Hostname of the host where the application is running.
-
#type ⇒ String
The type of the application.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceBackupApplianceApplication
constructor
A new instance of DataSourceBackupApplianceApplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceBackupApplianceApplication
Returns a new instance of DataSourceBackupApplianceApplication.
2636 2637 2638 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appliance_id ⇒ Fixnum
Appliance Id of the Backup Appliance.
Corresponds to the JSON property applianceId
2604 2605 2606 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2604 def appliance_id @appliance_id end |
#application_id ⇒ Fixnum
The appid field of the application within the Backup Appliance.
Corresponds to the JSON property applicationId
2609 2610 2611 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2609 def application_id @application_id end |
#application_name ⇒ String
The name of the Application as known to the Backup Appliance.
Corresponds to the JSON property applicationName
2614 2615 2616 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2614 def application_name @application_name end |
#backup_appliance ⇒ String
Appliance name.
Corresponds to the JSON property backupAppliance
2619 2620 2621 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2619 def backup_appliance @backup_appliance end |
#host_id ⇒ Fixnum
Hostid of the application host.
Corresponds to the JSON property hostId
2624 2625 2626 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2624 def host_id @host_id end |
#hostname ⇒ String
Hostname of the host where the application is running.
Corresponds to the JSON property hostname
2629 2630 2631 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2629 def hostname @hostname end |
#type ⇒ String
The type of the application. e.g. VMBackup
Corresponds to the JSON property type
2634 2635 2636 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2634 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2641 2642 2643 2644 2645 2646 2647 2648 2649 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2641 def update!(**args) @appliance_id = args[:appliance_id] if args.key?(:appliance_id) @application_id = args[:application_id] if args.key?(:application_id) @application_name = args[:application_name] if args.key?(:application_name) @backup_appliance = args[:backup_appliance] if args.key?(:backup_appliance) @host_id = args[:host_id] if args.key?(:host_id) @hostname = args[:hostname] if args.key?(:hostname) @type = args[:type] if args.key?(:type) end |