Class: Google::Apis::BackupdrV1::DataSourceGcpResource
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DataSourceGcpResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
DataSourceGcpResource is used for protected resources that are Google Cloud Resources. This name is easeier to understand than GcpResourceDataSource or GcpDataSourceResource
Instance Attribute Summary collapse
-
#alloy_db_cluster_datasource_properties ⇒ Google::Apis::BackupdrV1::AlloyDbClusterDataSourceProperties
AlloyDBClusterDataSourceProperties represents the properties of a AlloyDB cluster resource that are stored in the DataSource.
-
#cloud_sql_instance_datasource_properties ⇒ Google::Apis::BackupdrV1::CloudSqlInstanceDataSourceProperties
CloudSqlInstanceDataSourceProperties represents the properties of a Cloud SQL resource that are stored in the DataSource.
-
#compute_instance_datasource_properties ⇒ Google::Apis::BackupdrV1::ComputeInstanceDataSourceProperties
ComputeInstanceDataSourceProperties represents the properties of a ComputeEngine resource that are stored in the DataSource.
-
#disk_datasource_properties ⇒ Google::Apis::BackupdrV1::DiskDataSourceProperties
DiskDataSourceProperties represents the properties of a Disk resource that are stored in the DataSource.
-
#filestore_instance_datasource_properties ⇒ Google::Apis::BackupdrV1::FilestoreInstanceDataSourceProperties
FilestoreInstanceDataSourceProperties represents the properties of a Filestore resource that are stored in the DataSource.
-
#gcp_resourcename ⇒ String
Output only.
-
#location ⇒ String
Location of the resource: //"global"/"unspecified".
-
#type ⇒ String
The type of the Google Cloud resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceGcpResource
constructor
A new instance of DataSourceGcpResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceGcpResource
Returns a new instance of DataSourceGcpResource.
2729 2730 2731 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alloy_db_cluster_datasource_properties ⇒ Google::Apis::BackupdrV1::AlloyDbClusterDataSourceProperties
AlloyDBClusterDataSourceProperties represents the properties of a AlloyDB
cluster resource that are stored in the DataSource. .
Corresponds to the JSON property alloyDbClusterDatasourceProperties
2687 2688 2689 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2687 def alloy_db_cluster_datasource_properties @alloy_db_cluster_datasource_properties end |
#cloud_sql_instance_datasource_properties ⇒ Google::Apis::BackupdrV1::CloudSqlInstanceDataSourceProperties
CloudSqlInstanceDataSourceProperties represents the properties of a Cloud SQL
resource that are stored in the DataSource.
Corresponds to the JSON property cloudSqlInstanceDatasourceProperties
2693 2694 2695 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2693 def cloud_sql_instance_datasource_properties @cloud_sql_instance_datasource_properties end |
#compute_instance_datasource_properties ⇒ Google::Apis::BackupdrV1::ComputeInstanceDataSourceProperties
ComputeInstanceDataSourceProperties represents the properties of a
ComputeEngine resource that are stored in the DataSource.
Corresponds to the JSON property computeInstanceDatasourceProperties
2699 2700 2701 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2699 def compute_instance_datasource_properties @compute_instance_datasource_properties end |
#disk_datasource_properties ⇒ Google::Apis::BackupdrV1::DiskDataSourceProperties
DiskDataSourceProperties represents the properties of a Disk resource that are
stored in the DataSource. .
Corresponds to the JSON property diskDatasourceProperties
2705 2706 2707 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2705 def disk_datasource_properties @disk_datasource_properties end |
#filestore_instance_datasource_properties ⇒ Google::Apis::BackupdrV1::FilestoreInstanceDataSourceProperties
FilestoreInstanceDataSourceProperties represents the properties of a Filestore
resource that are stored in the DataSource. .
Corresponds to the JSON property filestoreInstanceDatasourceProperties
2711 2712 2713 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2711 def filestore_instance_datasource_properties @filestore_instance_datasource_properties end |
#gcp_resourcename ⇒ String
Output only. Full resource pathname URL of the source Google Cloud resource.
Corresponds to the JSON property gcpResourcename
2716 2717 2718 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2716 def gcp_resourcename @gcp_resourcename end |
#location ⇒ String
Location of the resource: //"global"/"unspecified".
Corresponds to the JSON property location
2721 2722 2723 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2721 def location @location end |
#type ⇒ String
The type of the Google Cloud resource. Use the Unified Resource Type, eg.
compute.googleapis.com/Instance.
Corresponds to the JSON property type
2727 2728 2729 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2727 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2734 def update!(**args) @alloy_db_cluster_datasource_properties = args[:alloy_db_cluster_datasource_properties] if args.key?(:alloy_db_cluster_datasource_properties) @cloud_sql_instance_datasource_properties = args[:cloud_sql_instance_datasource_properties] if args.key?(:cloud_sql_instance_datasource_properties) @compute_instance_datasource_properties = args[:compute_instance_datasource_properties] if args.key?(:compute_instance_datasource_properties) @disk_datasource_properties = args[:disk_datasource_properties] if args.key?(:disk_datasource_properties) @filestore_instance_datasource_properties = args[:filestore_instance_datasource_properties] if args.key?(:filestore_instance_datasource_properties) @gcp_resourcename = args[:gcp_resourcename] if args.key?(:gcp_resourcename) @location = args[:location] if args.key?(:location) @type = args[:type] if args.key?(:type) end |