Class: Google::Apis::BackupdrV1::DiskBackupPlanProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DiskBackupPlanProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
--- DiskBackupPlanProperties Message ---
Instance Attribute Summary collapse
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskBackupPlanProperties
constructor
A new instance of DiskBackupPlanProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskBackupPlanProperties
Returns a new instance of DiskBackupPlanProperties.
2877 2878 2879 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#guest_flush ⇒ Boolean Also known as: guest_flush?
Optional. Indicates whether to perform a guest flush operation before taking a
disk backup. When set to false, the system will create crash-consistent
backups. Default value is false.
Corresponds to the JSON property guestFlush
2874 2875 2876 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2874 def guest_flush @guest_flush end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2882 2883 2884 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2882 def update!(**args) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) end |