Class: Google::Apis::BackupdrV1::DiskBackupProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DiskBackupProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
DiskBackupProperties represents the properties of a Disk backup.
Instance Attribute Summary collapse
-
#access_mode ⇒ String
The access mode of the source disk.
-
#architecture ⇒ String
The architecture of the source disk.
-
#description ⇒ String
A description of the source disk.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Indicates whether the source disk is using confidential compute mode.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Optional.
-
#guest_os_feature ⇒ Array<Google::Apis::BackupdrV1::GuestOsFeature>
A list of guest OS features that are applicable to this backup.
-
#labels ⇒ Hash<String,String>
The labels of the source disk.
-
#licenses ⇒ Array<String>
A list of publicly available licenses that are applicable to this backup.
-
#physical_block_size_bytes ⇒ Fixnum
The physical block size of the source disk.
-
#provisioned_iops ⇒ Fixnum
The number of IOPS provisioned for the source disk.
-
#provisioned_throughput ⇒ Fixnum
The number of throughput provisioned for the source disk.
-
#region ⇒ String
Region and zone are mutually exclusive fields.
-
#replica_zones ⇒ Array<String>
The URL of the Zones where the source disk should be replicated.
-
#size_gb ⇒ Fixnum
Size(in GB) of the source disk.
-
#source_disk ⇒ String
The source disk used to create this backup.
-
#storage_pool ⇒ String
The storage pool of the source disk.
-
#type ⇒ String
The URL of the type of the disk.
-
#zone ⇒ String
The URL of the Zone where the source disk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskBackupProperties
constructor
A new instance of DiskBackupProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskBackupProperties
Returns a new instance of DiskBackupProperties.
2994 2995 2996 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_mode ⇒ String
The access mode of the source disk.
Corresponds to the JSON property accessMode
2902 2903 2904 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2902 def access_mode @access_mode end |
#architecture ⇒ String
The architecture of the source disk. Valid values are ARM64 or X86_64.
Corresponds to the JSON property architecture
2907 2908 2909 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2907 def architecture @architecture end |
#description ⇒ String
A description of the source disk.
Corresponds to the JSON property description
2912 2913 2914 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2912 def description @description end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Indicates whether the source disk is using confidential compute mode.
Corresponds to the JSON property enableConfidentialCompute
2917 2918 2919 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2917 def enable_confidential_compute @enable_confidential_compute end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
Optional. Defines if the guest flush is enabled for the source disk. Default
value is false.
Corresponds to the JSON property guestFlush
2924 2925 2926 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2924 def guest_flush @guest_flush end |
#guest_os_feature ⇒ Array<Google::Apis::BackupdrV1::GuestOsFeature>
A list of guest OS features that are applicable to this backup.
Corresponds to the JSON property guestOsFeature
2930 2931 2932 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2930 def guest_os_feature @guest_os_feature end |
#labels ⇒ Hash<String,String>
The labels of the source disk.
Corresponds to the JSON property labels
2935 2936 2937 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2935 def labels @labels end |
#licenses ⇒ Array<String>
A list of publicly available licenses that are applicable to this backup. This
is applicable if the original image had licenses attached, e.g. Windows image.
Corresponds to the JSON property licenses
2941 2942 2943 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2941 def licenses @licenses end |
#physical_block_size_bytes ⇒ Fixnum
The physical block size of the source disk.
Corresponds to the JSON property physicalBlockSizeBytes
2946 2947 2948 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2946 def physical_block_size_bytes @physical_block_size_bytes end |
#provisioned_iops ⇒ Fixnum
The number of IOPS provisioned for the source disk.
Corresponds to the JSON property provisionedIops
2951 2952 2953 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2951 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
The number of throughput provisioned for the source disk.
Corresponds to the JSON property provisionedThroughput
2956 2957 2958 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2956 def provisioned_throughput @provisioned_throughput end |
#region ⇒ String
Region and zone are mutually exclusive fields. The URL of the region of the
source disk.
Corresponds to the JSON property region
2962 2963 2964 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2962 def region @region end |
#replica_zones ⇒ Array<String>
The URL of the Zones where the source disk should be replicated.
Corresponds to the JSON property replicaZones
2967 2968 2969 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2967 def replica_zones @replica_zones end |
#size_gb ⇒ Fixnum
Size(in GB) of the source disk.
Corresponds to the JSON property sizeGb
2972 2973 2974 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2972 def size_gb @size_gb end |
#source_disk ⇒ String
The source disk used to create this backup.
Corresponds to the JSON property sourceDisk
2977 2978 2979 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2977 def source_disk @source_disk end |
#storage_pool ⇒ String
The storage pool of the source disk.
Corresponds to the JSON property storagePool
2982 2983 2984 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2982 def storage_pool @storage_pool end |
#type ⇒ String
The URL of the type of the disk.
Corresponds to the JSON property type
2987 2988 2989 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2987 def type @type end |
#zone ⇒ String
The URL of the Zone where the source disk.
Corresponds to the JSON property zone
2992 2993 2994 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2992 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 2999 def update!(**args) @access_mode = args[:access_mode] if args.key?(:access_mode) @architecture = args[:architecture] if args.key?(:architecture) @description = args[:description] if args.key?(:description) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) @guest_os_feature = args[:guest_os_feature] if args.key?(:guest_os_feature) @labels = args[:labels] if args.key?(:labels) @licenses = args[:licenses] if args.key?(:licenses) @physical_block_size_bytes = args[:physical_block_size_bytes] if args.key?(:physical_block_size_bytes) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) @region = args[:region] if args.key?(:region) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @size_gb = args[:size_gb] if args.key?(:size_gb) @source_disk = args[:source_disk] if args.key?(:source_disk) @storage_pool = args[:storage_pool] if args.key?(:storage_pool) @type = args[:type] if args.key?(:type) @zone = args[:zone] if args.key?(:zone) end |