Class: Google::Apis::BackupdrV1::DiskDataSourceProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DiskDataSourceProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
DiskDataSourceProperties represents the properties of a Disk resource that are stored in the DataSource. .
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the disk.
-
#name ⇒ String
Name of the disk backed up by the datasource.
-
#size_gb ⇒ Fixnum
The size of the disk in GB.
-
#type ⇒ String
The type of the disk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskDataSourceProperties
constructor
A new instance of DiskDataSourceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskDataSourceProperties
Returns a new instance of DiskDataSourceProperties.
3046 3047 3048 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the disk.
Corresponds to the JSON property description
3029 3030 3031 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3029 def description @description end |
#name ⇒ String
Name of the disk backed up by the datasource.
Corresponds to the JSON property name
3034 3035 3036 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3034 def name @name end |
#size_gb ⇒ Fixnum
The size of the disk in GB.
Corresponds to the JSON property sizeGb
3039 3040 3041 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3039 def size_gb @size_gb end |
#type ⇒ String
The type of the disk.
Corresponds to the JSON property type
3044 3045 3046 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3044 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3051 3052 3053 3054 3055 3056 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3051 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @size_gb = args[:size_gb] if args.key?(:size_gb) @type = args[:type] if args.key?(:type) end |