Class: Google::Apis::BackupdrV1::DiskDataSourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

DiskDataSourceProperties represents the properties of a Disk resource that are stored in the DataSource. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskDataSourceProperties

Returns a new instance of DiskDataSourceProperties.



3038
3039
3040
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the disk. Corresponds to the JSON property description

Returns:

  • (String)


3021
3022
3023
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3021

def description
  @description
end

#nameString

Name of the disk backed up by the datasource. Corresponds to the JSON property name

Returns:

  • (String)


3026
3027
3028
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3026

def name
  @name
end

#size_gbFixnum

The size of the disk in GB. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


3031
3032
3033
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3031

def size_gb
  @size_gb
end

#typeString

The type of the disk. Corresponds to the JSON property type

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3036

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3043
3044
3045
3046
3047
3048
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3043

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @type = args[:type] if args.key?(:type)
end