Class: Google::Apis::BackupdrV1::DiskExclusionLabels
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DiskExclusionLabels
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Message for selective disk backup exclusion labels.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskExclusionLabels
constructor
A new instance of DiskExclusionLabels.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskExclusionLabels
Returns a new instance of DiskExclusionLabels.
3094 3095 3096 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Array<Google::Apis::BackupdrV1::LabelKeyValPair>
Optional. Labels used to identify disks for exclusion from the backup. If a
disk carries any of these labels, it will be excluded (OR logic).
Corresponds to the JSON property labels
3092 3093 3094 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3092 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3099 3100 3101 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3099 def update!(**args) @labels = args[:labels] if args.key?(:labels) end |