Class: Google::Apis::BackupdrV1::DiskRestoreProperties
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::DiskRestoreProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
DiskRestoreProperties represents the properties of a Disk restore.
Instance Attribute Summary collapse
-
#access_mode ⇒ String
Optional.
-
#architecture ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#disk_encryption_key ⇒ Google::Apis::BackupdrV1::CustomerEncryptionKey
A customer-supplied encryption key.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Optional.
-
#guest_os_feature ⇒ Array<Google::Apis::BackupdrV1::GuestOsFeature>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#licenses ⇒ Array<String>
Optional.
-
#name ⇒ String
Required.
-
#physical_block_size_bytes ⇒ Fixnum
Optional.
-
#provisioned_iops ⇒ Fixnum
Optional.
-
#provisioned_throughput ⇒ Fixnum
Optional.
-
#resource_manager_tags ⇒ Hash<String,String>
Optional.
-
#resource_policy ⇒ Array<String>
Optional.
-
#size_gb ⇒ Fixnum
Required.
-
#storage_pool ⇒ String
Optional.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskRestoreProperties
constructor
A new instance of DiskRestoreProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskRestoreProperties
Returns a new instance of DiskRestoreProperties.
3206 3207 3208 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_mode ⇒ String
Optional. The access mode of the disk.
Corresponds to the JSON property accessMode
3111 3112 3113 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3111 def access_mode @access_mode end |
#architecture ⇒ String
Optional. The architecture of the source disk. Valid values are ARM64 or
X86_64.
Corresponds to the JSON property architecture
3117 3118 3119 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3117 def architecture @architecture end |
#description ⇒ String
Optional. An optional description of this resource. Provide this property when
you create the resource.
Corresponds to the JSON property description
3123 3124 3125 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3123 def description @description end |
#disk_encryption_key ⇒ Google::Apis::BackupdrV1::CustomerEncryptionKey
A customer-supplied encryption key.
Corresponds to the JSON property diskEncryptionKey
3128 3129 3130 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3128 def disk_encryption_key @disk_encryption_key end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Optional. Indicates whether this disk is using confidential compute mode.
Encryption with a Cloud KMS key is required to enable this option.
Corresponds to the JSON property enableConfidentialCompute
3134 3135 3136 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3134 def enable_confidential_compute @enable_confidential_compute end |
#guest_os_feature ⇒ Array<Google::Apis::BackupdrV1::GuestOsFeature>
Optional. A list of features to enable in the guest operating system. This is
applicable only for bootable images.
Corresponds to the JSON property guestOsFeature
3141 3142 3143 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3141 def guest_os_feature @guest_os_feature end |
#labels ⇒ Hash<String,String>
Optional. Labels to apply to this disk. These can be modified later using
setLabels method. Label values can be empty.
Corresponds to the JSON property labels
3147 3148 3149 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3147 def labels @labels end |
#licenses ⇒ Array<String>
Optional. A list of publicly available licenses that are applicable to this
backup. This is applicable if the original image had licenses attached, e.g.
Windows image
Corresponds to the JSON property licenses
3154 3155 3156 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3154 def licenses @licenses end |
#name ⇒ String
Required. Name of the disk.
Corresponds to the JSON property name
3159 3160 3161 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3159 def name @name end |
#physical_block_size_bytes ⇒ Fixnum
Optional. Physical block size of the persistent disk, in bytes. If not present
in a request, a default value is used. Currently, the supported size is 4096.
Corresponds to the JSON property physicalBlockSizeBytes
3165 3166 3167 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3165 def physical_block_size_bytes @physical_block_size_bytes end |
#provisioned_iops ⇒ Fixnum
Optional. Indicates how many IOPS to provision for the disk. This sets the
number of I/O operations per second that the disk can handle.
Corresponds to the JSON property provisionedIops
3171 3172 3173 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3171 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
Optional. Indicates how much throughput to provision for the disk. This sets
the number of throughput MB per second that the disk can handle.
Corresponds to the JSON property provisionedThroughput
3177 3178 3179 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3177 def provisioned_throughput @provisioned_throughput end |
#resource_manager_tags ⇒ Hash<String,String>
Optional. Resource manager tags to be bound to the disk.
Corresponds to the JSON property resourceManagerTags
3182 3183 3184 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3182 def @resource_manager_tags end |
#resource_policy ⇒ Array<String>
Optional. Resource policies applied to this disk.
Corresponds to the JSON property resourcePolicy
3187 3188 3189 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3187 def resource_policy @resource_policy end |
#size_gb ⇒ Fixnum
Required. The size of the disk in GB.
Corresponds to the JSON property sizeGb
3192 3193 3194 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3192 def size_gb @size_gb end |
#storage_pool ⇒ String
Optional. The storage pool in which the new disk is created. You can provide
this as a partial or full URL to the resource.
Corresponds to the JSON property storagePool
3198 3199 3200 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3198 def storage_pool @storage_pool end |
#type ⇒ String
Required. URL of the disk type resource describing which disk type to use to
create the disk.
Corresponds to the JSON property type
3204 3205 3206 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3204 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3211 def update!(**args) @access_mode = args[:access_mode] if args.key?(:access_mode) @architecture = args[:architecture] if args.key?(:architecture) @description = args[:description] if args.key?(:description) @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @guest_os_feature = args[:guest_os_feature] if args.key?(:guest_os_feature) @labels = args[:labels] if args.key?(:labels) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @physical_block_size_bytes = args[:physical_block_size_bytes] if args.key?(:physical_block_size_bytes) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @resource_policy = args[:resource_policy] if args.key?(:resource_policy) @size_gb = args[:size_gb] if args.key?(:size_gb) @storage_pool = args[:storage_pool] if args.key?(:storage_pool) @type = args[:type] if args.key?(:type) end |