Class: Google::Apis::BackupdrV1::EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::EncryptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Message describing the EncryptionConfig of backup vault. This determines how data within the vault is encrypted at rest.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionConfig
constructor
A new instance of EncryptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionConfig
Returns a new instance of EncryptionConfig.
3253 3254 3255 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The Cloud KMS key name to encrypt backups in this backup vault. Must
be in the same region as the vault. Some workload backups like compute disk
backups may use their inherited source key instead. Format: projects/project/
locations/location/keyRings/ring/cryptoKeys/key
Corresponds to the JSON property kmsKeyName
3251 3252 3253 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3251 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3258 3259 3260 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3258 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |