Class: Google::Apis::BackupdrV1::Entry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A key/value pair to be used for storing metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Entry

Returns a new instance of Entry.



3359
3360
3361
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Optional. Key for the metadata entry. Corresponds to the JSON property key

Returns:

  • (String)


3349
3350
3351
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3349

def key
  @key
end

#valueString

Optional. Value for the metadata entry. These are free-form strings, and only have meaning as interpreted by the image running in the instance. The only restriction placed on values is that their size must be less than or equal to 262144 bytes (256 KiB). Corresponds to the JSON property value

Returns:

  • (String)


3357
3358
3359
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3357

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3364
3365
3366
3367
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3364

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end