Class: Google::Apis::BackupdrV1::FetchMsComplianceMetadataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Response message for GetMsComplianceMetadata

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchMsComplianceMetadataResponse

Returns a new instance of FetchMsComplianceMetadataResponse.



3543
3544
3545
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3543

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_assured_workloadBoolean Also known as: is_assured_workload?

The ms compliance metadata of the target project, if the project is an Assured Workloads project, values will be true, otherwise false. Corresponds to the JSON property isAssuredWorkload

Returns:

  • (Boolean)


3540
3541
3542
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3540

def is_assured_workload
  @is_assured_workload
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3548
3549
3550
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3548

def update!(**args)
  @is_assured_workload = args[:is_assured_workload] if args.key?(:is_assured_workload)
end