Class: Google::Apis::BackupdrV1::FetchMsComplianceMetadataResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::FetchMsComplianceMetadataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response message for GetMsComplianceMetadata
Instance Attribute Summary collapse
-
#is_assured_workload ⇒ Boolean
(also: #is_assured_workload?)
The ms compliance metadata of the target project, if the project is an Assured Workloads project, values will be true, otherwise false.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchMsComplianceMetadataResponse
constructor
A new instance of FetchMsComplianceMetadataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchMsComplianceMetadataResponse
Returns a new instance of FetchMsComplianceMetadataResponse.
3528 3529 3530 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3528 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_assured_workload ⇒ Boolean Also known as: is_assured_workload?
The ms compliance metadata of the target project, if the project is an Assured
Workloads project, values will be true, otherwise false.
Corresponds to the JSON property isAssuredWorkload
3525 3526 3527 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3525 def is_assured_workload @is_assured_workload end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3533 3534 3535 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3533 def update!(**args) @is_assured_workload = args[:is_assured_workload] if args.key?(:is_assured_workload) end |