Class: Google::Apis::BackupdrV1::FilestoreInstanceDataSourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

FilestoreInstanceDataSourceProperties represents the properties of a Filestore resource that are stored in the DataSource. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilestoreInstanceDataSourceProperties

Returns a new instance of FilestoreInstanceDataSourceProperties.



3652
3653
3654
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_create_timeString

Output only. The instance creation timestamp. Corresponds to the JSON property instanceCreateTime

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3645

def instance_create_time
  @instance_create_time
end

#nameString

Output only. Name of the Filestore instance backed up by the datasource. Corresponds to the JSON property name

Returns:

  • (String)


3650
3651
3652
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3650

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3657
3658
3659
3660
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3657

def update!(**args)
  @instance_create_time = args[:instance_create_time] if args.key?(:instance_create_time)
  @name = args[:name] if args.key?(:name)
end