Class: Google::Apis::BackupdrV1::FilestoreInstanceDataSourceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

FilestoreInstanceDataSourceProperties represents the properties of a Filestore resource that are stored in the DataSource. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilestoreInstanceDataSourceProperties

Returns a new instance of FilestoreInstanceDataSourceProperties.



3627
3628
3629
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_create_timeString

Output only. The instance creation timestamp. Corresponds to the JSON property instanceCreateTime

Returns:

  • (String)


3620
3621
3622
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3620

def instance_create_time
  @instance_create_time
end

#nameString

Output only. Name of the Filestore instance backed up by the datasource. Corresponds to the JSON property name

Returns:

  • (String)


3625
3626
3627
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3625

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3632
3633
3634
3635
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3632

def update!(**args)
  @instance_create_time = args[:instance_create_time] if args.key?(:instance_create_time)
  @name = args[:name] if args.key?(:name)
end