Class: Google::Apis::BackupdrV1::FilestoreInstanceDataSourceReferenceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

FilestoreInstanceDataSourceReferenceProperties represents the properties of a Filestore resource that are stored in the DataSourceReference. .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilestoreInstanceDataSourceReferenceProperties

Returns a new instance of FilestoreInstanceDataSourceReferenceProperties.



3654
3655
3656
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_create_timeString

Output only. The instance creation timestamp. Corresponds to the JSON property instanceCreateTime

Returns:

  • (String)


3646
3647
3648
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3646

def instance_create_time
  @instance_create_time
end

#nameString

Output only. Name of the Filestore instance backed up by the datasource. Format: projects/project/instances/instance Corresponds to the JSON property name

Returns:

  • (String)


3652
3653
3654
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3652

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3659
3660
3661
3662
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3659

def update!(**args)
  @instance_create_time = args[:instance_create_time] if args.key?(:instance_create_time)
  @name = args[:name] if args.key?(:name)
end