Class: Google::Apis::BackupdrV1::FinalizeBackupRequest
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::FinalizeBackupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Message for finalizing a Backup.
Instance Attribute Summary collapse
-
#backup_id ⇒ String
Required.
-
#consistency_time ⇒ String
The point in time when this backup was captured from the source.
-
#description ⇒ String
This will be assigned to the description field of the newly created Backup.
-
#recovery_range_end_time ⇒ String
The latest timestamp of data available in this Backup.
-
#recovery_range_start_time ⇒ String
The earliest timestamp of data available in this Backup.
-
#request_id ⇒ String
Optional.
-
#retention_duration ⇒ String
The ExpireTime on the backup will be set to FinalizeTime plus this duration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FinalizeBackupRequest
constructor
A new instance of FinalizeBackupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FinalizeBackupRequest
Returns a new instance of FinalizeBackupRequest.
3759 3760 3761 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_id ⇒ String
Required. Resource ID of the Backup resource to be finalized. This must be the
same backup_id that was used in the InitiateBackupRequest.
Corresponds to the JSON property backupId
3713 3714 3715 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3713 def backup_id @backup_id end |
#consistency_time ⇒ String
The point in time when this backup was captured from the source. This will be
assigned to the consistency_time field of the newly created Backup.
Corresponds to the JSON property consistencyTime
3719 3720 3721 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3719 def consistency_time @consistency_time end |
#description ⇒ String
This will be assigned to the description field of the newly created Backup.
Corresponds to the JSON property description
3724 3725 3726 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3724 def description @description end |
#recovery_range_end_time ⇒ String
The latest timestamp of data available in this Backup. This will be set on the
newly created Backup.
Corresponds to the JSON property recoveryRangeEndTime
3730 3731 3732 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3730 def recovery_range_end_time @recovery_range_end_time end |
#recovery_range_start_time ⇒ String
The earliest timestamp of data available in this Backup. This will set on the
newly created Backup.
Corresponds to the JSON property recoveryRangeStartTime
3736 3737 3738 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3736 def recovery_range_start_time @recovery_range_start_time end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3750 3751 3752 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3750 def request_id @request_id end |
#retention_duration ⇒ String
The ExpireTime on the backup will be set to FinalizeTime plus this duration.
If the resulting ExpireTime is less than EnforcedRetentionEndTime, then
ExpireTime is set to EnforcedRetentionEndTime.
Corresponds to the JSON property retentionDuration
3757 3758 3759 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3757 def retention_duration @retention_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3764 3765 3766 3767 3768 3769 3770 3771 3772 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3764 def update!(**args) @backup_id = args[:backup_id] if args.key?(:backup_id) @consistency_time = args[:consistency_time] if args.key?(:consistency_time) @description = args[:description] if args.key?(:description) @recovery_range_end_time = args[:recovery_range_end_time] if args.key?(:recovery_range_end_time) @recovery_range_start_time = args[:recovery_range_start_time] if args.key?(:recovery_range_start_time) @request_id = args[:request_id] if args.key?(:request_id) @retention_duration = args[:retention_duration] if args.key?(:retention_duration) end |