Class: Google::Apis::BackupdrV1::FinalizeBackupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message for finalizing a Backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FinalizeBackupRequest

Returns a new instance of FinalizeBackupRequest.



3719
3720
3721
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_idString

Required. Resource ID of the Backup resource to be finalized. This must be the same backup_id that was used in the InitiateBackupRequest. Corresponds to the JSON property backupId

Returns:

  • (String)


3673
3674
3675
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3673

def backup_id
  @backup_id
end

#consistency_timeString

The point in time when this backup was captured from the source. This will be assigned to the consistency_time field of the newly created Backup. Corresponds to the JSON property consistencyTime

Returns:

  • (String)


3679
3680
3681
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3679

def consistency_time
  @consistency_time
end

#descriptionString

This will be assigned to the description field of the newly created Backup. Corresponds to the JSON property description

Returns:

  • (String)


3684
3685
3686
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3684

def description
  @description
end

#recovery_range_end_timeString

The latest timestamp of data available in this Backup. This will be set on the newly created Backup. Corresponds to the JSON property recoveryRangeEndTime

Returns:

  • (String)


3690
3691
3692
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3690

def recovery_range_end_time
  @recovery_range_end_time
end

#recovery_range_start_timeString

The earliest timestamp of data available in this Backup. This will set on the newly created Backup. Corresponds to the JSON property recoveryRangeStartTime

Returns:

  • (String)


3696
3697
3698
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3696

def recovery_range_start_time
  @recovery_range_start_time
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3710
3711
3712
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3710

def request_id
  @request_id
end

#retention_durationString

The ExpireTime on the backup will be set to FinalizeTime plus this duration. If the resulting ExpireTime is less than EnforcedRetentionEndTime, then ExpireTime is set to EnforcedRetentionEndTime. Corresponds to the JSON property retentionDuration

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3717

def retention_duration
  @retention_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3724
3725
3726
3727
3728
3729
3730
3731
3732
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3724

def update!(**args)
  @backup_id = args[:backup_id] if args.key?(:backup_id)
  @consistency_time = args[:consistency_time] if args.key?(:consistency_time)
  @description = args[:description] if args.key?(:description)
  @recovery_range_end_time = args[:recovery_range_end_time] if args.key?(:recovery_range_end_time)
  @recovery_range_start_time = args[:recovery_range_start_time] if args.key?(:recovery_range_start_time)
  @request_id = args[:request_id] if args.key?(:request_id)
  @retention_duration = args[:retention_duration] if args.key?(:retention_duration)
end