Class: Google::Apis::BackupdrV1::GcpBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::GcpBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
GcpBackupConfig captures the Backup configuration details for Google Cloud resources. All Google Cloud resources regardless of type are protected with backup plan associations.
Instance Attribute Summary collapse
-
#backup_plan ⇒ String
The name of the backup plan.
-
#backup_plan_association ⇒ String
The name of the backup plan association.
-
#backup_plan_description ⇒ String
The description of the backup plan.
-
#backup_plan_revision_id ⇒ String
The user friendly id of the backup plan revision.
-
#backup_plan_revision_name ⇒ String
The name of the backup plan revision.
-
#backup_plan_rules ⇒ Array<String>
The names of the backup plan rules which point to this backupvault Corresponds to the JSON property
backupPlanRules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpBackupConfig
constructor
A new instance of GcpBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpBackupConfig
Returns a new instance of GcpBackupConfig.
3855 3856 3857 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan ⇒ String
The name of the backup plan.
Corresponds to the JSON property backupPlan
3828 3829 3830 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3828 def backup_plan @backup_plan end |
#backup_plan_association ⇒ String
The name of the backup plan association.
Corresponds to the JSON property backupPlanAssociation
3833 3834 3835 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3833 def backup_plan_association @backup_plan_association end |
#backup_plan_description ⇒ String
The description of the backup plan.
Corresponds to the JSON property backupPlanDescription
3838 3839 3840 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3838 def backup_plan_description @backup_plan_description end |
#backup_plan_revision_id ⇒ String
The user friendly id of the backup plan revision. E.g. v0, v1 etc.
Corresponds to the JSON property backupPlanRevisionId
3843 3844 3845 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3843 def backup_plan_revision_id @backup_plan_revision_id end |
#backup_plan_revision_name ⇒ String
The name of the backup plan revision.
Corresponds to the JSON property backupPlanRevisionName
3848 3849 3850 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3848 def backup_plan_revision_name @backup_plan_revision_name end |
#backup_plan_rules ⇒ Array<String>
The names of the backup plan rules which point to this backupvault
Corresponds to the JSON property backupPlanRules
3853 3854 3855 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3853 def backup_plan_rules @backup_plan_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3860 3861 3862 3863 3864 3865 3866 3867 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3860 def update!(**args) @backup_plan = args[:backup_plan] if args.key?(:backup_plan) @backup_plan_association = args[:backup_plan_association] if args.key?(:backup_plan_association) @backup_plan_description = args[:backup_plan_description] if args.key?(:backup_plan_description) @backup_plan_revision_id = args[:backup_plan_revision_id] if args.key?(:backup_plan_revision_id) @backup_plan_revision_name = args[:backup_plan_revision_name] if args.key?(:backup_plan_revision_name) @backup_plan_rules = args[:backup_plan_rules] if args.key?(:backup_plan_rules) end |