Class: Google::Apis::BackupdrV1::GcpBackupPlanInfo
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::GcpBackupPlanInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
GCPBackupPlanInfo captures the plan configuration details of Google Cloud resources at the time of backup.
Instance Attribute Summary collapse
-
#backup_plan ⇒ String
Resource name of backup plan by which workload is protected at the time of the backup.
-
#backup_plan_revision_id ⇒ String
The user friendly id of the backup plan revision which triggered this backup in case of scheduled backup or used for on demand backup.
-
#backup_plan_revision_name ⇒ String
Resource name of the backup plan revision which triggered this backup in case of scheduled backup or used for on demand backup.
-
#backup_plan_rule_id ⇒ String
The rule id of the backup plan which triggered this backup in case of scheduled backup or used for Corresponds to the JSON property
backupPlanRuleId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpBackupPlanInfo
constructor
A new instance of GcpBackupPlanInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpBackupPlanInfo
Returns a new instance of GcpBackupPlanInfo.
3791 3792 3793 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan ⇒ String
Resource name of backup plan by which workload is protected at the time of the
backup. Format: projects/project/locations/location/backupPlans/
backupPlanId
Corresponds to the JSON property backupPlan
3770 3771 3772 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3770 def backup_plan @backup_plan end |
#backup_plan_revision_id ⇒ String
The user friendly id of the backup plan revision which triggered this backup
in case of scheduled backup or used for on demand backup.
Corresponds to the JSON property backupPlanRevisionId
3776 3777 3778 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3776 def backup_plan_revision_id @backup_plan_revision_id end |
#backup_plan_revision_name ⇒ String
Resource name of the backup plan revision which triggered this backup in case
of scheduled backup or used for on demand backup. Format: projects/project/
locations/location/backupPlans/backupPlanId/revisions/revisionId
Corresponds to the JSON property backupPlanRevisionName
3783 3784 3785 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3783 def backup_plan_revision_name @backup_plan_revision_name end |
#backup_plan_rule_id ⇒ String
The rule id of the backup plan which triggered this backup in case of
scheduled backup or used for
Corresponds to the JSON property backupPlanRuleId
3789 3790 3791 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3789 def backup_plan_rule_id @backup_plan_rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3796 3797 3798 3799 3800 3801 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3796 def update!(**args) @backup_plan = args[:backup_plan] if args.key?(:backup_plan) @backup_plan_revision_id = args[:backup_plan_revision_id] if args.key?(:backup_plan_revision_id) @backup_plan_revision_name = args[:backup_plan_revision_name] if args.key?(:backup_plan_revision_name) @backup_plan_rule_id = args[:backup_plan_rule_id] if args.key?(:backup_plan_rule_id) end |