Class: Google::Apis::BackupdrV1::GcpBackupPlanInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

GCPBackupPlanInfo captures the plan configuration details of Google Cloud resources at the time of backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpBackupPlanInfo

Returns a new instance of GcpBackupPlanInfo.



3766
3767
3768
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_planString

Resource name of backup plan by which workload is protected at the time of the backup. Format: projects/project/locations/location/backupPlans/ backupPlanId Corresponds to the JSON property backupPlan

Returns:

  • (String)


3745
3746
3747
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3745

def backup_plan
  @backup_plan
end

#backup_plan_revision_idString

The user friendly id of the backup plan revision which triggered this backup in case of scheduled backup or used for on demand backup. Corresponds to the JSON property backupPlanRevisionId

Returns:

  • (String)


3751
3752
3753
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3751

def backup_plan_revision_id
  @backup_plan_revision_id
end

#backup_plan_revision_nameString

Resource name of the backup plan revision which triggered this backup in case of scheduled backup or used for on demand backup. Format: projects/project/ locations/location/backupPlans/backupPlanId/revisions/revisionId Corresponds to the JSON property backupPlanRevisionName

Returns:

  • (String)


3758
3759
3760
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3758

def backup_plan_revision_name
  @backup_plan_revision_name
end

#backup_plan_rule_idString

The rule id of the backup plan which triggered this backup in case of scheduled backup or used for Corresponds to the JSON property backupPlanRuleId

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3764

def backup_plan_rule_id
  @backup_plan_rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3771
3772
3773
3774
3775
3776
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3771

def update!(**args)
  @backup_plan = args[:backup_plan] if args.key?(:backup_plan)
  @backup_plan_revision_id = args[:backup_plan_revision_id] if args.key?(:backup_plan_revision_id)
  @backup_plan_revision_name = args[:backup_plan_revision_name] if args.key?(:backup_plan_revision_name)
  @backup_plan_rule_id = args[:backup_plan_rule_id] if args.key?(:backup_plan_rule_id)
end