Class: Google::Apis::BackupdrV1::GoogleCloudBackupdrV1OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBackupdrV1OperationMetadata

Returns a new instance of GoogleCloudBackupdrV1OperationMetadata.



3911
3912
3913
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_infoHash<String,String>

Output only. AdditionalInfo contains additional Info related to backup plan association resource. Corresponds to the JSON property additionalInfo

Returns:

  • (Hash<String,String>)


3870
3871
3872
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3870

def additional_info
  @additional_info
end

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3875
3876
3877
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3875

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3880
3881
3882
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3880

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


3885
3886
3887
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3885

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to 'Code.CANCELLED'. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


3893
3894
3895
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3893

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


3899
3900
3901
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3899

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


3904
3905
3906
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3904

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


3909
3910
3911
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3909

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3916
3917
3918
3919
3920
3921
3922
3923
3924
3925
# File 'lib/google/apis/backupdr_v1/classes.rb', line 3916

def update!(**args)
  @additional_info = args[:additional_info] if args.key?(:additional_info)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end