Class: Google::Apis::BackupdrV1::InitializeServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Request message for initializing the service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InitializeServiceRequest

Returns a new instance of InitializeServiceRequest.



4062
4063
4064
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plan_locationString

Optional. The location where the BackupPlan will be created. This field is required for multi-region BackupVaults and is optional for regional BackupVaults. It is useful when creating a Backup Vault in a multi-region, allowing the BackupPlan to reside in a specific region within that multi- region. If this field is not provided, the BackupPlan will be created in the same location as specified in the name field. Corresponds to the JSON property backupPlanLocation

Returns:

  • (String)


4026
4027
4028
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4026

def backup_plan_location
  @backup_plan_location
end

#cloud_sql_instance_initialization_configGoogle::Apis::BackupdrV1::CloudSqlInstanceInitializationConfig

CloudSqlInstanceInitializationConfig contains the configuration for initializing a Cloud SQL instance. Corresponds to the JSON property cloudSqlInstanceInitializationConfig



4032
4033
4034
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4032

def cloud_sql_instance_initialization_config
  @cloud_sql_instance_initialization_config
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


4046
4047
4048
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4046

def request_id
  @request_id
end

#resource_typeString

Required. The resource type to which the default service config will be applied. Examples include, "compute.googleapis.com/Instance" and "storage. googleapis.com/Bucket". Corresponds to the JSON property resourceType

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4053

def resource_type
  @resource_type
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validates the request and returns the result, but does not actually run it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


4059
4060
4061
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4059

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4067
4068
4069
4070
4071
4072
4073
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4067

def update!(**args)
  @backup_plan_location = args[:backup_plan_location] if args.key?(:backup_plan_location)
  @cloud_sql_instance_initialization_config = args[:cloud_sql_instance_initialization_config] if args.key?(:cloud_sql_instance_initialization_config)
  @request_id = args[:request_id] if args.key?(:request_id)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end