Class: Google::Apis::BackupdrV1::InitiateBackupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

request message for InitiateBackup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InitiateBackupRequest

Returns a new instance of InitiateBackupRequest.



4059
4060
4061
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_idString

Required. Resource ID of the Backup resource. Corresponds to the JSON property backupId

Returns:

  • (String)


4043
4044
4045
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4043

def backup_id
  @backup_id
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


4057
4058
4059
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4057

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4064
4065
4066
4067
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4064

def update!(**args)
  @backup_id = args[:backup_id] if args.key?(:backup_id)
  @request_id = args[:request_id] if args.key?(:request_id)
end