Class: Google::Apis::BackupdrV1::ListBackupPlanAssociationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Response message for List BackupPlanAssociation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupPlanAssociationsResponse

Returns a new instance of ListBackupPlanAssociationsResponse.



4260
4261
4262
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plan_associationsArray<Google::Apis::BackupdrV1::BackupPlanAssociation>

The list of Backup Plan Associations in the project for the specified location. If the location value in the request is "-", the response contains a list of instances from all locations. In case any location is unreachable, the response will only return backup plan associations in reachable locations and the 'unreachable' field will be populated with a list of unreachable locations. Corresponds to the JSON property backupPlanAssociations



4248
4249
4250
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4248

def backup_plan_associations
  @backup_plan_associations
end

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4253
4254
4255
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4253

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4258
4259
4260
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4258

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4265
4266
4267
4268
4269
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4265

def update!(**args)
  @backup_plan_associations = args[:backup_plan_associations] if args.key?(:backup_plan_associations)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end