Class: Google::Apis::BackupdrV1::ListBackupPlanRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListBackupPlanRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
The response message for getting a list of BackupPlanRevision.
Instance Attribute Summary collapse
-
#backup_plan_revisions ⇒ Array<Google::Apis::BackupdrV1::BackupPlanRevision>
The list of
BackupPlanRevisionsin the project for the specified location. -
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListBackupPlanRevisionscall to retrieve the next page of results. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupPlanRevisionsResponse
constructor
A new instance of ListBackupPlanRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupPlanRevisionsResponse
Returns a new instance of ListBackupPlanRevisionsResponse.
4303 4304 4305 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plan_revisions ⇒ Array<Google::Apis::BackupdrV1::BackupPlanRevision>
The list of BackupPlanRevisions in the project for the specified location.
If the location value in the request is "-", the response contains a list
of resources from all locations. In case any location is unreachable, the
response will only return backup plans in reachable locations and the '
unreachable' field will be populated with a list of unreachable locations.
Corresponds to the JSON property backupPlanRevisions
4289 4290 4291 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4289 def backup_plan_revisions @backup_plan_revisions end |
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListBackupPlanRevisions call to retrieve the next page of results. If this
field is omitted or empty, then there are no more results to return.
Corresponds to the JSON property nextPageToken
4296 4297 4298 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4296 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4301 4302 4303 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4301 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4308 4309 4310 4311 4312 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4308 def update!(**args) @backup_plan_revisions = args[:backup_plan_revisions] if args.key?(:backup_plan_revisions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |