Class: Google::Apis::BackupdrV1::ListBackupPlanRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

The response message for getting a list of BackupPlanRevision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupPlanRevisionsResponse

Returns a new instance of ListBackupPlanRevisionsResponse.



4180
4181
4182
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plan_revisionsArray<Google::Apis::BackupdrV1::BackupPlanRevision>

The list of BackupPlanRevisions in the project for the specified location. If the location value in the request is "-", the response contains a list of resources from all locations. In case any location is unreachable, the response will only return backup plans in reachable locations and the ' unreachable' field will be populated with a list of unreachable locations. Corresponds to the JSON property backupPlanRevisions



4166
4167
4168
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4166

def backup_plan_revisions
  @backup_plan_revisions
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackupPlanRevisions call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4173

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4178
4179
4180
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4178

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4185
4186
4187
4188
4189
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4185

def update!(**args)
  @backup_plan_revisions = args[:backup_plan_revisions] if args.key?(:backup_plan_revisions)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end