Class: Google::Apis::BackupdrV1::ListBackupPlansResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

The response message for getting a list of BackupPlan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupPlansResponse

Returns a new instance of ListBackupPlansResponse.



4335
4336
4337
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_plansArray<Google::Apis::BackupdrV1::BackupPlan>

The list of BackupPlans in the project for the specified location. If the location value in the request is "-", the response contains a list of resources from all locations. In case any location is unreachable, the response will only return backup plans in reachable locations and the ' unreachable' field will be populated with a list of unreachable locations. BackupPlan Corresponds to the JSON property backupPlans



4321
4322
4323
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4321

def backup_plans
  @backup_plans
end

#next_page_tokenString

A token which may be sent as page_token in a subsequent ListBackupPlans call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4328
4329
4330
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4328

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4333
4334
4335
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4333

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4340
4341
4342
4343
4344
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4340

def update!(**args)
  @backup_plans = args[:backup_plans] if args.key?(:backup_plans)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end