Class: Google::Apis::BackupdrV1::ListBackupPlansResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListBackupPlansResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
The response message for getting a list of BackupPlan.
Instance Attribute Summary collapse
-
#backup_plans ⇒ Array<Google::Apis::BackupdrV1::BackupPlan>
The list of
BackupPlansin the project for the specified location. -
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent
ListBackupPlanscall to retrieve the next page of results. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupPlansResponse
constructor
A new instance of ListBackupPlansResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupPlansResponse
Returns a new instance of ListBackupPlansResponse.
4243 4244 4245 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_plans ⇒ Array<Google::Apis::BackupdrV1::BackupPlan>
The list of BackupPlans in the project for the specified location. If the
location value in the request is "-", the response contains a list of
resources from all locations. In case any location is unreachable, the
response will only return backup plans in reachable locations and the '
unreachable' field will be populated with a list of unreachable locations.
BackupPlan
Corresponds to the JSON property backupPlans
4229 4230 4231 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4229 def backup_plans @backup_plans end |
#next_page_token ⇒ String
A token which may be sent as page_token in a subsequent ListBackupPlans call
to retrieve the next page of results. If this field is omitted or empty, then
there are no more results to return.
Corresponds to the JSON property nextPageToken
4236 4237 4238 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4236 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4241 4242 4243 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4241 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4248 4249 4250 4251 4252 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4248 def update!(**args) @backup_plans = args[:backup_plans] if args.key?(:backup_plans) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |