Class: Google::Apis::BackupdrV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Response message for listing Backups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



4288
4289
4290
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::BackupdrV1::Backup>

The list of Backup instances in the project for the specified location. If the 'location' value in the request is "-", the response contains a list of instances from all locations. In case any location is unreachable, the response will only return data sources in reachable locations and the ' unreachable' field will be populated with a list of unreachable locations. Corresponds to the JSON property backups



4276
4277
4278
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4276

def backups
  @backups
end

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4281

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4286
4287
4288
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4286

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4293
4294
4295
4296
4297
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4293

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end