Class: Google::Apis::BackupdrV1::ListManagementServersResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListManagementServersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response message for listing management servers.
Instance Attribute Summary collapse
-
#management_servers ⇒ Array<Google::Apis::BackupdrV1::ManagementServer>
The list of ManagementServer instances in the project for the specified location.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListManagementServersResponse
constructor
A new instance of ListManagementServersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListManagementServersResponse
Returns a new instance of ListManagementServersResponse.
4456 4457 4458 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#management_servers ⇒ Array<Google::Apis::BackupdrV1::ManagementServer>
The list of ManagementServer instances in the project for the specified
location. If the 'location' value in the request is "-", the response
contains a list of instances from all locations. In case any location is
unreachable, the response will only return management servers in reachable
locations and the 'unreachable' field will be populated with a list of
unreachable locations.
Corresponds to the JSON property managementServers
4444 4445 4446 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4444 def management_servers @management_servers end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4449 4450 4451 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4449 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4454 4455 4456 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4454 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4461 4462 4463 4464 4465 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4461 def update!(**args) @management_servers = args[:management_servers] if args.key?(:management_servers) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |