Class: Google::Apis::BackupdrV1::ListResourceBackupConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ListResourceBackupConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Response for ListResourceBackupConfigs.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#resource_backup_configs ⇒ Array<Google::Apis::BackupdrV1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListResourceBackupConfigsResponse
constructor
A new instance of ListResourceBackupConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListResourceBackupConfigsResponse
Returns a new instance of ListResourceBackupConfigsResponse.
4501 4502 4503 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4494 4495 4496 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4494 def next_page_token @next_page_token end |
#resource_backup_configs ⇒ Array<Google::Apis::BackupdrV1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Corresponds to the JSON property resourceBackupConfigs
4499 4500 4501 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4499 def resource_backup_configs @resource_backup_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4506 4507 4508 4509 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4506 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_backup_configs = args[:resource_backup_configs] if args.key?(:resource_backup_configs) end |