Class: Google::Apis::BackupdrV1::LocationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::LocationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Instance Attribute Summary collapse
-
#unsupported_features ⇒ Array<String>
List of features that are not supported in the location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationMetadata
constructor
A new instance of LocationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationMetadata
Returns a new instance of LocationMetadata.
4543 4544 4545 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#unsupported_features ⇒ Array<String>
List of features that are not supported in the location.
Corresponds to the JSON property unsupportedFeatures
4541 4542 4543 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4541 def unsupported_features @unsupported_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4548 4549 4550 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4548 def update!(**args) @unsupported_features = args[:unsupported_features] if args.key?(:unsupported_features) end |