Class: Google::Apis::BackupdrV1::ManagementServer
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ManagementServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
ManagementServer describes a single BackupDR ManagementServer instance.
Instance Attribute Summary collapse
-
#ba_proxy_uri ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#management_uri ⇒ Google::Apis::BackupdrV1::ManagementUri
ManagementURI for the Management Server resource.
-
#name ⇒ String
Output only.
-
#networks ⇒ Array<Google::Apis::BackupdrV1::NetworkConfig>
Optional.
-
#oauth2_client_id ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#workforce_identity_based_management_uri ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri
ManagementURI depending on the Workforce Identity i.e.
-
#workforce_identity_based_oauth2_client_id ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId
OAuth Client ID depending on the Workforce Identity i.e.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagementServer
constructor
A new instance of ManagementServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagementServer
Returns a new instance of ManagementServer.
4766 4767 4768 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ba_proxy_uri ⇒ Array<String>
Output only. The hostname or ip address of the exposed AGM endpoints, used by
BAs to connect to BA proxy.
Corresponds to the JSON property baProxyUri
4678 4679 4680 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4678 def ba_proxy_uri @ba_proxy_uri end |
#create_time ⇒ String
Output only. The time when the instance was created.
Corresponds to the JSON property createTime
4683 4684 4685 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4683 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ManagementServer instance (2048 characters or
less).
Corresponds to the JSON property description
4689 4690 4691 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4689 def description @description end |
#etag ⇒ String
Optional. Server specified ETag for the ManagementServer resource to prevent
simultaneous updates from overwiting each other.
Corresponds to the JSON property etag
4695 4696 4697 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4695 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user provided metadata. Labels
currently defined: 1. migrate_from_go= If set to true, the MS is created in
migration ready mode.
Corresponds to the JSON property labels
4702 4703 4704 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4702 def labels @labels end |
#management_uri ⇒ Google::Apis::BackupdrV1::ManagementUri
ManagementURI for the Management Server resource.
Corresponds to the JSON property managementUri
4707 4708 4709 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4707 def management_uri @management_uri end |
#name ⇒ String
Output only. Identifier. The resource name.
Corresponds to the JSON property name
4712 4713 4714 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4712 def name @name end |
#networks ⇒ Array<Google::Apis::BackupdrV1::NetworkConfig>
Optional. VPC networks to which the ManagementServer instance is connected.
For this version, only a single network is supported. This field is optional
if MS is created without PSA
Corresponds to the JSON property networks
4719 4720 4721 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4719 def networks @networks end |
#oauth2_client_id ⇒ String
Output only. The OAuth 2.0 client id is required to make API calls to the
Backup and DR instance API of this ManagementServer. This is the value that
should be provided in the 'aud' field of the OIDC ID Token (see openid
specification https://openid.net/specs/openid-connect-core-1_0.html#IDToken).
Corresponds to the JSON property oauth2ClientId
4727 4728 4729 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4727 def oauth2_client_id @oauth2_client_id end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
4732 4733 4734 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4732 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
4738 4739 4740 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4738 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The ManagementServer state.
Corresponds to the JSON property state
4744 4745 4746 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4744 def state @state end |
#type ⇒ String
Optional. The type of the ManagementServer resource.
Corresponds to the JSON property type
4749 4750 4751 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4749 def type @type end |
#update_time ⇒ String
Output only. The time when the instance was updated.
Corresponds to the JSON property updateTime
4754 4755 4756 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4754 def update_time @update_time end |
#workforce_identity_based_management_uri ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri
ManagementURI depending on the Workforce Identity i.e. either 1p or 3p.
Corresponds to the JSON property workforceIdentityBasedManagementUri
4759 4760 4761 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4759 def workforce_identity_based_management_uri @workforce_identity_based_management_uri end |
#workforce_identity_based_oauth2_client_id ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId
OAuth Client ID depending on the Workforce Identity i.e. either 1p or 3p,
Corresponds to the JSON property workforceIdentityBasedOauth2ClientId
4764 4765 4766 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4764 def workforce_identity_based_oauth2_client_id @workforce_identity_based_oauth2_client_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4771 def update!(**args) @ba_proxy_uri = args[:ba_proxy_uri] if args.key?(:ba_proxy_uri) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @management_uri = args[:management_uri] if args.key?(:management_uri) @name = args[:name] if args.key?(:name) @networks = args[:networks] if args.key?(:networks) @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @workforce_identity_based_management_uri = args[:workforce_identity_based_management_uri] if args.key?(:workforce_identity_based_management_uri) @workforce_identity_based_oauth2_client_id = args[:workforce_identity_based_oauth2_client_id] if args.key?(:workforce_identity_based_oauth2_client_id) end |