Class: Google::Apis::BackupdrV1::ManagementServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ManagementServer describes a single BackupDR ManagementServer instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementServer

Returns a new instance of ManagementServer.



4689
4690
4691
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ba_proxy_uriArray<String>

Output only. The hostname or ip address of the exposed AGM endpoints, used by BAs to connect to BA proxy. Corresponds to the JSON property baProxyUri

Returns:

  • (Array<String>)


4601
4602
4603
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4601

def ba_proxy_uri
  @ba_proxy_uri
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4606
4607
4608
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4606

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ManagementServer instance (2048 characters or less). Corresponds to the JSON property description

Returns:

  • (String)


4612
4613
4614
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4612

def description
  @description
end

#etagString

Optional. Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other. Corresponds to the JSON property etag

Returns:

  • (String)


4618
4619
4620
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4618

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. Labels currently defined: 1. migrate_from_go= If set to true, the MS is created in migration ready mode. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4625
4626
4627
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4625

def labels
  @labels
end

#management_uriGoogle::Apis::BackupdrV1::ManagementUri

ManagementURI for the Management Server resource. Corresponds to the JSON property managementUri



4630
4631
4632
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4630

def management_uri
  @management_uri
end

#nameString

Output only. Identifier. The resource name. Corresponds to the JSON property name

Returns:

  • (String)


4635
4636
4637
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4635

def name
  @name
end

#networksArray<Google::Apis::BackupdrV1::NetworkConfig>

Optional. VPC networks to which the ManagementServer instance is connected. For this version, only a single network is supported. This field is optional if MS is created without PSA Corresponds to the JSON property networks



4642
4643
4644
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4642

def networks
  @networks
end

#oauth2_client_idString

Output only. The OAuth 2.0 client id is required to make API calls to the Backup and DR instance API of this ManagementServer. This is the value that should be provided in the 'aud' field of the OIDC ID Token (see openid specification https://openid.net/specs/openid-connect-core-1_0.html#IDToken). Corresponds to the JSON property oauth2ClientId

Returns:

  • (String)


4650
4651
4652
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4650

def oauth2_client_id
  @oauth2_client_id
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


4655
4656
4657
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4655

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


4661
4662
4663
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4661

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The ManagementServer state. Corresponds to the JSON property state

Returns:

  • (String)


4667
4668
4669
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4667

def state
  @state
end

#typeString

Optional. The type of the ManagementServer resource. Corresponds to the JSON property type

Returns:

  • (String)


4672
4673
4674
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4672

def type
  @type
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4677
4678
4679
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4677

def update_time
  @update_time
end

#workforce_identity_based_management_uriGoogle::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri

ManagementURI depending on the Workforce Identity i.e. either 1p or 3p. Corresponds to the JSON property workforceIdentityBasedManagementUri



4682
4683
4684
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4682

def workforce_identity_based_management_uri
  @workforce_identity_based_management_uri
end

#workforce_identity_based_oauth2_client_idGoogle::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId

OAuth Client ID depending on the Workforce Identity i.e. either 1p or 3p, Corresponds to the JSON property workforceIdentityBasedOauth2ClientId



4687
4688
4689
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4687

def workforce_identity_based_oauth2_client_id
  @workforce_identity_based_oauth2_client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
4708
4709
4710
4711
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4694

def update!(**args)
  @ba_proxy_uri = args[:ba_proxy_uri] if args.key?(:ba_proxy_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @management_uri = args[:management_uri] if args.key?(:management_uri)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workforce_identity_based_management_uri = args[:workforce_identity_based_management_uri] if args.key?(:workforce_identity_based_management_uri)
  @workforce_identity_based_oauth2_client_id = args[:workforce_identity_based_oauth2_client_id] if args.key?(:workforce_identity_based_oauth2_client_id)
end