Class: Google::Apis::BackupdrV1::ManagementServer
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ManagementServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
ManagementServer describes a single BackupDR ManagementServer instance.
Instance Attribute Summary collapse
-
#ba_proxy_uri ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#management_uri ⇒ Google::Apis::BackupdrV1::ManagementUri
ManagementURI for the Management Server resource.
-
#name ⇒ String
Output only.
-
#networks ⇒ Array<Google::Apis::BackupdrV1::NetworkConfig>
Optional.
-
#oauth2_client_id ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#workforce_identity_based_management_uri ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri
ManagementURI depending on the Workforce Identity i.e.
-
#workforce_identity_based_oauth2_client_id ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId
OAuth Client ID depending on the Workforce Identity i.e.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagementServer
constructor
A new instance of ManagementServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagementServer
Returns a new instance of ManagementServer.
4674 4675 4676 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ba_proxy_uri ⇒ Array<String>
Output only. The hostname or ip address of the exposed AGM endpoints, used by
BAs to connect to BA proxy.
Corresponds to the JSON property baProxyUri
4586 4587 4588 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4586 def ba_proxy_uri @ba_proxy_uri end |
#create_time ⇒ String
Output only. The time when the instance was created.
Corresponds to the JSON property createTime
4591 4592 4593 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4591 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ManagementServer instance (2048 characters or
less).
Corresponds to the JSON property description
4597 4598 4599 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4597 def description @description end |
#etag ⇒ String
Optional. Server specified ETag for the ManagementServer resource to prevent
simultaneous updates from overwiting each other.
Corresponds to the JSON property etag
4603 4604 4605 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4603 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user provided metadata. Labels
currently defined: 1. migrate_from_go= If set to true, the MS is created in
migration ready mode.
Corresponds to the JSON property labels
4610 4611 4612 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4610 def labels @labels end |
#management_uri ⇒ Google::Apis::BackupdrV1::ManagementUri
ManagementURI for the Management Server resource.
Corresponds to the JSON property managementUri
4615 4616 4617 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4615 def management_uri @management_uri end |
#name ⇒ String
Output only. Identifier. The resource name.
Corresponds to the JSON property name
4620 4621 4622 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4620 def name @name end |
#networks ⇒ Array<Google::Apis::BackupdrV1::NetworkConfig>
Optional. VPC networks to which the ManagementServer instance is connected.
For this version, only a single network is supported. This field is optional
if MS is created without PSA
Corresponds to the JSON property networks
4627 4628 4629 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4627 def networks @networks end |
#oauth2_client_id ⇒ String
Output only. The OAuth 2.0 client id is required to make API calls to the
Backup and DR instance API of this ManagementServer. This is the value that
should be provided in the 'aud' field of the OIDC ID Token (see openid
specification https://openid.net/specs/openid-connect-core-1_0.html#IDToken).
Corresponds to the JSON property oauth2ClientId
4635 4636 4637 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4635 def oauth2_client_id @oauth2_client_id end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
4640 4641 4642 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4640 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
4646 4647 4648 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4646 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The ManagementServer state.
Corresponds to the JSON property state
4652 4653 4654 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4652 def state @state end |
#type ⇒ String
Optional. The type of the ManagementServer resource.
Corresponds to the JSON property type
4657 4658 4659 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4657 def type @type end |
#update_time ⇒ String
Output only. The time when the instance was updated.
Corresponds to the JSON property updateTime
4662 4663 4664 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4662 def update_time @update_time end |
#workforce_identity_based_management_uri ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri
ManagementURI depending on the Workforce Identity i.e. either 1p or 3p.
Corresponds to the JSON property workforceIdentityBasedManagementUri
4667 4668 4669 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4667 def workforce_identity_based_management_uri @workforce_identity_based_management_uri end |
#workforce_identity_based_oauth2_client_id ⇒ Google::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId
OAuth Client ID depending on the Workforce Identity i.e. either 1p or 3p,
Corresponds to the JSON property workforceIdentityBasedOauth2ClientId
4672 4673 4674 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4672 def workforce_identity_based_oauth2_client_id @workforce_identity_based_oauth2_client_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4679 4680 4681 4682 4683 4684 4685 4686 4687 4688 4689 4690 4691 4692 4693 4694 4695 4696 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4679 def update!(**args) @ba_proxy_uri = args[:ba_proxy_uri] if args.key?(:ba_proxy_uri) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @management_uri = args[:management_uri] if args.key?(:management_uri) @name = args[:name] if args.key?(:name) @networks = args[:networks] if args.key?(:networks) @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @workforce_identity_based_management_uri = args[:workforce_identity_based_management_uri] if args.key?(:workforce_identity_based_management_uri) @workforce_identity_based_oauth2_client_id = args[:workforce_identity_based_oauth2_client_id] if args.key?(:workforce_identity_based_oauth2_client_id) end |