Class: Google::Apis::BackupdrV1::ManagementServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ManagementServer describes a single BackupDR ManagementServer instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementServer

Returns a new instance of ManagementServer.



4649
4650
4651
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ba_proxy_uriArray<String>

Output only. The hostname or ip address of the exposed AGM endpoints, used by BAs to connect to BA proxy. Corresponds to the JSON property baProxyUri

Returns:

  • (Array<String>)


4561
4562
4563
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4561

def ba_proxy_uri
  @ba_proxy_uri
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4566
4567
4568
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4566

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ManagementServer instance (2048 characters or less). Corresponds to the JSON property description

Returns:

  • (String)


4572
4573
4574
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4572

def description
  @description
end

#etagString

Optional. Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other. Corresponds to the JSON property etag

Returns:

  • (String)


4578
4579
4580
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4578

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels to represent user provided metadata. Labels currently defined: 1. migrate_from_go= If set to true, the MS is created in migration ready mode. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4585
4586
4587
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4585

def labels
  @labels
end

#management_uriGoogle::Apis::BackupdrV1::ManagementUri

ManagementURI for the Management Server resource. Corresponds to the JSON property managementUri



4590
4591
4592
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4590

def management_uri
  @management_uri
end

#nameString

Output only. Identifier. The resource name. Corresponds to the JSON property name

Returns:

  • (String)


4595
4596
4597
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4595

def name
  @name
end

#networksArray<Google::Apis::BackupdrV1::NetworkConfig>

Optional. VPC networks to which the ManagementServer instance is connected. For this version, only a single network is supported. This field is optional if MS is created without PSA Corresponds to the JSON property networks



4602
4603
4604
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4602

def networks
  @networks
end

#oauth2_client_idString

Output only. The OAuth 2.0 client id is required to make API calls to the Backup and DR instance API of this ManagementServer. This is the value that should be provided in the 'aud' field of the OIDC ID Token (see openid specification https://openid.net/specs/openid-connect-core-1_0.html#IDToken). Corresponds to the JSON property oauth2ClientId

Returns:

  • (String)


4610
4611
4612
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4610

def oauth2_client_id
  @oauth2_client_id
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


4615
4616
4617
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4615

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


4621
4622
4623
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4621

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The ManagementServer state. Corresponds to the JSON property state

Returns:

  • (String)


4627
4628
4629
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4627

def state
  @state
end

#typeString

Optional. The type of the ManagementServer resource. Corresponds to the JSON property type

Returns:

  • (String)


4632
4633
4634
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4632

def type
  @type
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4637
4638
4639
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4637

def update_time
  @update_time
end

#workforce_identity_based_management_uriGoogle::Apis::BackupdrV1::WorkforceIdentityBasedManagementUri

ManagementURI depending on the Workforce Identity i.e. either 1p or 3p. Corresponds to the JSON property workforceIdentityBasedManagementUri



4642
4643
4644
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4642

def workforce_identity_based_management_uri
  @workforce_identity_based_management_uri
end

#workforce_identity_based_oauth2_client_idGoogle::Apis::BackupdrV1::WorkforceIdentityBasedOAuth2ClientId

OAuth Client ID depending on the Workforce Identity i.e. either 1p or 3p, Corresponds to the JSON property workforceIdentityBasedOauth2ClientId



4647
4648
4649
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4647

def workforce_identity_based_oauth2_client_id
  @workforce_identity_based_oauth2_client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4654

def update!(**args)
  @ba_proxy_uri = args[:ba_proxy_uri] if args.key?(:ba_proxy_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @management_uri = args[:management_uri] if args.key?(:management_uri)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workforce_identity_based_management_uri = args[:workforce_identity_based_management_uri] if args.key?(:workforce_identity_based_management_uri)
  @workforce_identity_based_oauth2_client_id = args[:workforce_identity_based_oauth2_client_id] if args.key?(:workforce_identity_based_oauth2_client_id)
end