Class: Google::Apis::BackupdrV1::NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A network interface resource attached to an instance. s

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInterface

Returns a new instance of NetworkInterface.



4956
4957
4958
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configsArray<Google::Apis::BackupdrV1::AccessConfig>

Optional. An array of configurations for this interface. Currently, only one access config,ONE_TO_ONE_NAT is supported. If there are no accessConfigs specified, then this instance will have no external internet access. Corresponds to the JSON property accessConfigs



4872
4873
4874
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4872

def access_configs
  @access_configs
end

#alias_ip_rangesArray<Google::Apis::BackupdrV1::AliasIpRange>

Optional. An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpRanges



4878
4879
4880
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4878

def alias_ip_ranges
  @alias_ip_ranges
end

#internal_ipv6_prefix_lengthFixnum

Optional. The prefix length of the primary internal IPv6 range. Corresponds to the JSON property internalIpv6PrefixLength

Returns:

  • (Fixnum)


4883
4884
4885
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4883

def internal_ipv6_prefix_length
  @internal_ipv6_prefix_length
end

#ipv6_access_configsArray<Google::Apis::BackupdrV1::AccessConfig>

Optional. An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access. Corresponds to the JSON property ipv6AccessConfigs



4891
4892
4893
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4891

def ipv6_access_configs
  @ipv6_access_configs
end

#ipv6_access_typeString

Optional. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


4898
4899
4900
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4898

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_addressString

Optional. An IPv6 internal network address for this network interface. To use a static internal IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an internal IPv6 address from the instance's subnetwork. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


4906
4907
4908
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4906

def ipv6_address
  @ipv6_address
end

#nameString

Output only. [Output Only] The name of the network interface, which is generated by the server. Corresponds to the JSON property name

Returns:

  • (String)


4912
4913
4914
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4912

def name
  @name
end

#networkString

Optional. URL of the VPC network resource for this instance. Corresponds to the JSON property network

Returns:

  • (String)


4917
4918
4919
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4917

def network
  @network
end

#network_attachmentString

Optional. The URL of the network attachment that this interface should connect to in the following format: projects/project_number/regions/region_name/ networkAttachments/network_attachment_name. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


4924
4925
4926
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4924

def network_attachment
  @network_attachment
end

#network_ipString

Optional. An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system. Corresponds to the JSON property networkIP

Returns:

  • (String)


4931
4932
4933
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4931

def network_ip
  @network_ip
end

#nic_typeString

Optional. The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. Corresponds to the JSON property nicType

Returns:

  • (String)


4937
4938
4939
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4937

def nic_type
  @nic_type
end

#queue_countFixnum

Optional. The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users. Corresponds to the JSON property queueCount

Returns:

  • (Fixnum)


4944
4945
4946
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4944

def queue_count
  @queue_count
end

#stack_typeString

The stack type for this network interface. Corresponds to the JSON property stackType

Returns:

  • (String)


4949
4950
4951
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4949

def stack_type
  @stack_type
end

#subnetworkString

Optional. The URL of the Subnetwork resource for this instance. Corresponds to the JSON property subnetwork

Returns:

  • (String)


4954
4955
4956
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4954

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
4971
4972
4973
4974
4975
4976
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4961

def update!(**args)
  @access_configs = args[:access_configs] if args.key?(:access_configs)
  @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges)
  @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length)
  @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
  @network_ip = args[:network_ip] if args.key?(:network_ip)
  @nic_type = args[:nic_type] if args.key?(:nic_type)
  @queue_count = args[:queue_count] if args.key?(:queue_count)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end