Class: Google::Apis::BackupdrV1::NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A network interface resource attached to an instance. s

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInterface

Returns a new instance of NetworkInterface.



4879
4880
4881
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configsArray<Google::Apis::BackupdrV1::AccessConfig>

Optional. An array of configurations for this interface. Currently, only one access config,ONE_TO_ONE_NAT is supported. If there are no accessConfigs specified, then this instance will have no external internet access. Corresponds to the JSON property accessConfigs



4795
4796
4797
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4795

def access_configs
  @access_configs
end

#alias_ip_rangesArray<Google::Apis::BackupdrV1::AliasIpRange>

Optional. An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpRanges



4801
4802
4803
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4801

def alias_ip_ranges
  @alias_ip_ranges
end

#internal_ipv6_prefix_lengthFixnum

Optional. The prefix length of the primary internal IPv6 range. Corresponds to the JSON property internalIpv6PrefixLength

Returns:

  • (Fixnum)


4806
4807
4808
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4806

def internal_ipv6_prefix_length
  @internal_ipv6_prefix_length
end

#ipv6_access_configsArray<Google::Apis::BackupdrV1::AccessConfig>

Optional. An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access. Corresponds to the JSON property ipv6AccessConfigs



4814
4815
4816
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4814

def ipv6_access_configs
  @ipv6_access_configs
end

#ipv6_access_typeString

Optional. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


4821
4822
4823
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4821

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_addressString

Optional. An IPv6 internal network address for this network interface. To use a static internal IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an internal IPv6 address from the instance's subnetwork. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


4829
4830
4831
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4829

def ipv6_address
  @ipv6_address
end

#nameString

Output only. [Output Only] The name of the network interface, which is generated by the server. Corresponds to the JSON property name

Returns:

  • (String)


4835
4836
4837
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4835

def name
  @name
end

#networkString

Optional. URL of the VPC network resource for this instance. Corresponds to the JSON property network

Returns:

  • (String)


4840
4841
4842
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4840

def network
  @network
end

#network_attachmentString

Optional. The URL of the network attachment that this interface should connect to in the following format: projects/project_number/regions/region_name/ networkAttachments/network_attachment_name. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


4847
4848
4849
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4847

def network_attachment
  @network_attachment
end

#network_ipString

Optional. An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system. Corresponds to the JSON property networkIP

Returns:

  • (String)


4854
4855
4856
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4854

def network_ip
  @network_ip
end

#nic_typeString

Optional. The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. Corresponds to the JSON property nicType

Returns:

  • (String)


4860
4861
4862
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4860

def nic_type
  @nic_type
end

#queue_countFixnum

Optional. The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users. Corresponds to the JSON property queueCount

Returns:

  • (Fixnum)


4867
4868
4869
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4867

def queue_count
  @queue_count
end

#stack_typeString

The stack type for this network interface. Corresponds to the JSON property stackType

Returns:

  • (String)


4872
4873
4874
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4872

def stack_type
  @stack_type
end

#subnetworkString

Optional. The URL of the Subnetwork resource for this instance. Corresponds to the JSON property subnetwork

Returns:

  • (String)


4877
4878
4879
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4877

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/google/apis/backupdr_v1/classes.rb', line 4884

def update!(**args)
  @access_configs = args[:access_configs] if args.key?(:access_configs)
  @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges)
  @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length)
  @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
  @network_ip = args[:network_ip] if args.key?(:network_ip)
  @nic_type = args[:nic_type] if args.key?(:nic_type)
  @queue_count = args[:queue_count] if args.key?(:queue_count)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end