Class: Google::Apis::BackupdrV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#additional_info ⇒ Hash<String,String>
Output only.
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
5049 5050 5051 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_info ⇒ Hash<String,String>
Output only. AdditionalInfo contains additional Info related to backup plan
association resource.
Corresponds to the JSON property additionalInfo
5008 5009 5010 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5008 def additional_info @additional_info end |
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
5013 5014 5015 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5013 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
5018 5019 5020 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5018 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
5023 5024 5025 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5023 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to 'Code.CANCELLED'.
Corresponds to the JSON property requestedCancellation
5031 5032 5033 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5031 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
5037 5038 5039 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5037 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
5042 5043 5044 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5042 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
5047 5048 5049 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5047 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5054 def update!(**args) @additional_info = args[:additional_info] if args.key?(:additional_info) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |