Class: Google::Apis::BackupdrV1::ResourceBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ResourceBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
ResourceBackupConfig represents a resource along with its backup configurations.
Instance Attribute Summary collapse
-
#backup_configs_details ⇒ Array<Google::Apis::BackupdrV1::BackupConfigDetails>
Backup configurations applying to the target resource, including those targeting its related/child resources.
-
#backup_configured ⇒ Boolean
(also: #backup_configured?)
Output only.
-
#name ⇒ String
Identifier.
-
#target_resource ⇒ String
Output only.
-
#target_resource_display_name ⇒ String
Output only.
-
#target_resource_labels ⇒ Hash<String,String>
Labels associated with the target resource.
-
#target_resource_type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#vaulted ⇒ Boolean
(also: #vaulted?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceBackupConfig
constructor
A new instance of ResourceBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceBackupConfig
Returns a new instance of ResourceBackupConfig.
5400 5401 5402 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configs_details ⇒ Array<Google::Apis::BackupdrV1::BackupConfigDetails>
Backup configurations applying to the target resource, including those
targeting its related/child resources. For example, backup configuration
applicable to Compute Engine disks will be populated in this field for a
Compute Engine VM which has the disk associated.
Corresponds to the JSON property backupConfigsDetails
5349 5350 5351 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5349 def backup_configs_details @backup_configs_details end |
#backup_configured ⇒ Boolean Also known as: backup_configured?
Output only. Whether the target resource is configured for backup. This is
true if the backup_configs_details is not empty.
Corresponds to the JSON property backupConfigured
5355 5356 5357 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5355 def backup_configured @backup_configured end |
#name ⇒ String
Identifier. The resource name of the ResourceBackupConfig. Format: projects/
project/locations/location/resourceBackupConfigs/uid
Corresponds to the JSON property name
5362 5363 5364 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5362 def name @name end |
#target_resource ⇒ String
Output only. The full resource name of the cloud resource that this configuration
applies to. Supported resource types are ResourceBackupConfig.ResourceType.
Corresponds to the JSON property targetResource
5369 5370 5371 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5369 def target_resource @target_resource end |
#target_resource_display_name ⇒ String
Output only. The human friendly name of the target resource.
Corresponds to the JSON property targetResourceDisplayName
5374 5375 5376 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5374 def target_resource_display_name @target_resource_display_name end |
#target_resource_labels ⇒ Hash<String,String>
Labels associated with the target resource.
Corresponds to the JSON property targetResourceLabels
5379 5380 5381 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5379 def target_resource_labels @target_resource_labels end |
#target_resource_type ⇒ String
Output only. The type of the target resource.
Corresponds to the JSON property targetResourceType
5384 5385 5386 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5384 def target_resource_type @target_resource_type end |
#uid ⇒ String
Output only. The unique identifier of the resource backup config.
Corresponds to the JSON property uid
5389 5390 5391 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5389 def uid @uid end |
#vaulted ⇒ Boolean Also known as: vaulted?
Output only. Whether the target resource is protected by a backup vault. This
is true if the backup_configs_details is not empty and any of the
ResourceBackupConfig.backup_configs_details has a backup configuration with
BackupConfigDetails.backup_vault set.
Corresponds to the JSON property vaulted
5397 5398 5399 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5397 def vaulted @vaulted end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5405 def update!(**args) @backup_configs_details = args[:backup_configs_details] if args.key?(:backup_configs_details) @backup_configured = args[:backup_configured] if args.key?(:backup_configured) @name = args[:name] if args.key?(:name) @target_resource = args[:target_resource] if args.key?(:target_resource) @target_resource_display_name = args[:target_resource_display_name] if args.key?(:target_resource_display_name) @target_resource_labels = args[:target_resource_labels] if args.key?(:target_resource_labels) @target_resource_type = args[:target_resource_type] if args.key?(:target_resource_type) @uid = args[:uid] if args.key?(:uid) @vaulted = args[:vaulted] if args.key?(:vaulted) end |