Class: Google::Apis::BackupdrV1::ResourceBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ResourceBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
ResourceBackupConfig represents a resource along with its backup configurations.
Instance Attribute Summary collapse
-
#backup_configs_details ⇒ Array<Google::Apis::BackupdrV1::BackupConfigDetails>
Backup configurations applying to the target resource, including those targeting its related/child resources.
-
#backup_configured ⇒ Boolean
(also: #backup_configured?)
Output only.
-
#name ⇒ String
Identifier.
-
#target_resource ⇒ String
Output only.
-
#target_resource_display_name ⇒ String
Output only.
-
#target_resource_labels ⇒ Hash<String,String>
Labels associated with the target resource.
-
#target_resource_type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#vaulted ⇒ Boolean
(also: #vaulted?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceBackupConfig
constructor
A new instance of ResourceBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceBackupConfig
Returns a new instance of ResourceBackupConfig.
5235 5236 5237 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configs_details ⇒ Array<Google::Apis::BackupdrV1::BackupConfigDetails>
Backup configurations applying to the target resource, including those
targeting its related/child resources. For example, backup configuration
applicable to Compute Engine disks will be populated in this field for a
Compute Engine VM which has the disk associated.
Corresponds to the JSON property backupConfigsDetails
5184 5185 5186 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5184 def backup_configs_details @backup_configs_details end |
#backup_configured ⇒ Boolean Also known as: backup_configured?
Output only. Whether the target resource is configured for backup. This is
true if the backup_configs_details is not empty.
Corresponds to the JSON property backupConfigured
5190 5191 5192 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5190 def backup_configured @backup_configured end |
#name ⇒ String
Identifier. The resource name of the ResourceBackupConfig. Format: projects/
project/locations/location/resourceBackupConfigs/uid
Corresponds to the JSON property name
5197 5198 5199 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5197 def name @name end |
#target_resource ⇒ String
Output only. The full resource name of the cloud resource that this configuration
applies to. Supported resource types are ResourceBackupConfig.ResourceType.
Corresponds to the JSON property targetResource
5204 5205 5206 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5204 def target_resource @target_resource end |
#target_resource_display_name ⇒ String
Output only. The human friendly name of the target resource.
Corresponds to the JSON property targetResourceDisplayName
5209 5210 5211 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5209 def target_resource_display_name @target_resource_display_name end |
#target_resource_labels ⇒ Hash<String,String>
Labels associated with the target resource.
Corresponds to the JSON property targetResourceLabels
5214 5215 5216 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5214 def target_resource_labels @target_resource_labels end |
#target_resource_type ⇒ String
Output only. The type of the target resource.
Corresponds to the JSON property targetResourceType
5219 5220 5221 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5219 def target_resource_type @target_resource_type end |
#uid ⇒ String
Output only. The unique identifier of the resource backup config.
Corresponds to the JSON property uid
5224 5225 5226 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5224 def uid @uid end |
#vaulted ⇒ Boolean Also known as: vaulted?
Output only. Whether the target resource is protected by a backup vault. This
is true if the backup_configs_details is not empty and any of the
ResourceBackupConfig.backup_configs_details has a backup configuration with
BackupConfigDetails.backup_vault set.
Corresponds to the JSON property vaulted
5232 5233 5234 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5232 def vaulted @vaulted end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 5250 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5240 def update!(**args) @backup_configs_details = args[:backup_configs_details] if args.key?(:backup_configs_details) @backup_configured = args[:backup_configured] if args.key?(:backup_configured) @name = args[:name] if args.key?(:name) @target_resource = args[:target_resource] if args.key?(:target_resource) @target_resource_display_name = args[:target_resource_display_name] if args.key?(:target_resource_display_name) @target_resource_labels = args[:target_resource_labels] if args.key?(:target_resource_labels) @target_resource_type = args[:target_resource_type] if args.key?(:target_resource_type) @uid = args[:uid] if args.key?(:uid) @vaulted = args[:vaulted] if args.key?(:vaulted) end |