Class: Google::Apis::BackupdrV1::ResourceBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

ResourceBackupConfig represents a resource along with its backup configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceBackupConfig

Returns a new instance of ResourceBackupConfig.



5210
5211
5212
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configs_detailsArray<Google::Apis::BackupdrV1::BackupConfigDetails>

Backup configurations applying to the target resource, including those targeting its related/child resources. For example, backup configuration applicable to Compute Engine disks will be populated in this field for a Compute Engine VM which has the disk associated. Corresponds to the JSON property backupConfigsDetails



5159
5160
5161
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5159

def backup_configs_details
  @backup_configs_details
end

#backup_configuredBoolean Also known as: backup_configured?

Output only. Whether the target resource is configured for backup. This is true if the backup_configs_details is not empty. Corresponds to the JSON property backupConfigured

Returns:

  • (Boolean)


5165
5166
5167
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5165

def backup_configured
  @backup_configured
end

#nameString

Identifier. The resource name of the ResourceBackupConfig. Format: projects/ project/locations/location/resourceBackupConfigs/uid Corresponds to the JSON property name

Returns:

  • (String)


5172
5173
5174
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5172

def name
  @name
end

#target_resourceString

Output only. The full resource name of the cloud resource that this configuration applies to. Supported resource types are ResourceBackupConfig.ResourceType. Corresponds to the JSON property targetResource

Returns:

  • (String)


5179
5180
5181
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5179

def target_resource
  @target_resource
end

#target_resource_display_nameString

Output only. The human friendly name of the target resource. Corresponds to the JSON property targetResourceDisplayName

Returns:

  • (String)


5184
5185
5186
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5184

def target_resource_display_name
  @target_resource_display_name
end

#target_resource_labelsHash<String,String>

Labels associated with the target resource. Corresponds to the JSON property targetResourceLabels

Returns:

  • (Hash<String,String>)


5189
5190
5191
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5189

def target_resource_labels
  @target_resource_labels
end

#target_resource_typeString

Output only. The type of the target resource. Corresponds to the JSON property targetResourceType

Returns:

  • (String)


5194
5195
5196
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5194

def target_resource_type
  @target_resource_type
end

#uidString

Output only. The unique identifier of the resource backup config. Corresponds to the JSON property uid

Returns:

  • (String)


5199
5200
5201
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5199

def uid
  @uid
end

#vaultedBoolean Also known as: vaulted?

Output only. Whether the target resource is protected by a backup vault. This is true if the backup_configs_details is not empty and any of the ResourceBackupConfig.backup_configs_details has a backup configuration with BackupConfigDetails.backup_vault set. Corresponds to the JSON property vaulted

Returns:

  • (Boolean)


5207
5208
5209
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5207

def vaulted
  @vaulted
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5215

def update!(**args)
  @backup_configs_details = args[:backup_configs_details] if args.key?(:backup_configs_details)
  @backup_configured = args[:backup_configured] if args.key?(:backup_configured)
  @name = args[:name] if args.key?(:name)
  @target_resource = args[:target_resource] if args.key?(:target_resource)
  @target_resource_display_name = args[:target_resource_display_name] if args.key?(:target_resource_display_name)
  @target_resource_labels = args[:target_resource_labels] if args.key?(:target_resource_labels)
  @target_resource_type = args[:target_resource_type] if args.key?(:target_resource_type)
  @uid = args[:uid] if args.key?(:uid)
  @vaulted = args[:vaulted] if args.key?(:vaulted)
end