Class: Google::Apis::BackupdrV1::RestoreBackupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Request message for restoring from a Backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreBackupRequest

Returns a new instance of RestoreBackupRequest.



5284
5285
5286
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clear_overrides_field_maskString

Optional. A field mask used to clear server-side default values for fields within the instance_properties oneof. When a field in this mask is cleared, the server will not apply its default logic (like inheriting a value from the source) for that field. The most common current use case is clearing default encryption keys. Examples of field mask paths: - Compute Instance Disks: compute_instance_restore_properties.disks.*.disk_encryption_key - Single Disk: disk_restore_properties.disk_encryption_key Corresponds to the JSON property clearOverridesFieldMask

Returns:

  • (String)


5241
5242
5243
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5241

def clear_overrides_field_mask
  @clear_overrides_field_mask
end

#compute_instance_restore_propertiesGoogle::Apis::BackupdrV1::ComputeInstanceRestoreProperties

ComputeInstanceRestoreProperties represents Compute Engine instance properties to be overridden during restore. Corresponds to the JSON property computeInstanceRestoreProperties



5247
5248
5249
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5247

def compute_instance_restore_properties
  @compute_instance_restore_properties
end

#compute_instance_target_environmentGoogle::Apis::BackupdrV1::ComputeInstanceTargetEnvironment

ComputeInstanceTargetEnvironment represents Compute Engine target environment to be used during restore. Corresponds to the JSON property computeInstanceTargetEnvironment



5253
5254
5255
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5253

def compute_instance_target_environment
  @compute_instance_target_environment
end

#disk_restore_propertiesGoogle::Apis::BackupdrV1::DiskRestoreProperties

DiskRestoreProperties represents the properties of a Disk restore. Corresponds to the JSON property diskRestoreProperties



5258
5259
5260
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5258

def disk_restore_properties
  @disk_restore_properties
end

#disk_target_environmentGoogle::Apis::BackupdrV1::DiskTargetEnvironment

DiskTargetEnvironment represents the target environment for the disk. Corresponds to the JSON property diskTargetEnvironment



5263
5264
5265
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5263

def disk_target_environment
  @disk_target_environment
end

#region_disk_target_environmentGoogle::Apis::BackupdrV1::RegionDiskTargetEnvironment

RegionDiskTargetEnvironment represents the target environment for the disk. Corresponds to the JSON property regionDiskTargetEnvironment



5268
5269
5270
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5268

def region_disk_target_environment
  @region_disk_target_environment
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


5282
5283
5284
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5282

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5289
5290
5291
5292
5293
5294
5295
5296
5297
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5289

def update!(**args)
  @clear_overrides_field_mask = args[:clear_overrides_field_mask] if args.key?(:clear_overrides_field_mask)
  @compute_instance_restore_properties = args[:compute_instance_restore_properties] if args.key?(:compute_instance_restore_properties)
  @compute_instance_target_environment = args[:compute_instance_target_environment] if args.key?(:compute_instance_target_environment)
  @disk_restore_properties = args[:disk_restore_properties] if args.key?(:disk_restore_properties)
  @disk_target_environment = args[:disk_target_environment] if args.key?(:disk_target_environment)
  @region_disk_target_environment = args[:region_disk_target_environment] if args.key?(:region_disk_target_environment)
  @request_id = args[:request_id] if args.key?(:request_id)
end