Class: Google::Apis::BackupdrV1::RuleConfigInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message for rules config info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuleConfigInfo

Returns a new instance of RuleConfigInfo.



5539
5540
5541
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_backup_errorGoogle::Apis::BackupdrV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property lastBackupError



5521
5522
5523
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5521

def last_backup_error
  @last_backup_error
end

#last_backup_stateString

Output only. The last backup state for rule. Corresponds to the JSON property lastBackupState

Returns:

  • (String)


5526
5527
5528
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5526

def last_backup_state
  @last_backup_state
end

#last_successful_backup_consistency_timeString

Output only. The point in time when the last successful backup was captured from the source. Corresponds to the JSON property lastSuccessfulBackupConsistencyTime

Returns:

  • (String)


5532
5533
5534
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5532

def last_successful_backup_consistency_time
  @last_successful_backup_consistency_time
end

#rule_idString

Output only. Backup Rule id fetched from backup plan. Corresponds to the JSON property ruleId

Returns:

  • (String)


5537
5538
5539
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5537

def rule_id
  @rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5544
5545
5546
5547
5548
5549
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5544

def update!(**args)
  @last_backup_error = args[:last_backup_error] if args.key?(:last_backup_error)
  @last_backup_state = args[:last_backup_state] if args.key?(:last_backup_state)
  @last_successful_backup_consistency_time = args[:last_successful_backup_consistency_time] if args.key?(:last_successful_backup_consistency_time)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
end