Class: Google::Apis::BackupdrV1::RuleConfigInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

Message for rules config info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuleConfigInfo

Returns a new instance of RuleConfigInfo.



5462
5463
5464
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_backup_errorGoogle::Apis::BackupdrV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property lastBackupError



5444
5445
5446
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5444

def last_backup_error
  @last_backup_error
end

#last_backup_stateString

Output only. The last backup state for rule. Corresponds to the JSON property lastBackupState

Returns:

  • (String)


5449
5450
5451
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5449

def last_backup_state
  @last_backup_state
end

#last_successful_backup_consistency_timeString

Output only. The point in time when the last successful backup was captured from the source. Corresponds to the JSON property lastSuccessfulBackupConsistencyTime

Returns:

  • (String)


5455
5456
5457
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5455

def last_successful_backup_consistency_time
  @last_successful_backup_consistency_time
end

#rule_idString

Output only. Backup Rule id fetched from backup plan. Corresponds to the JSON property ruleId

Returns:

  • (String)


5460
5461
5462
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5460

def rule_id
  @rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5467
5468
5469
5470
5471
5472
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5467

def update!(**args)
  @last_backup_error = args[:last_backup_error] if args.key?(:last_backup_error)
  @last_backup_state = args[:last_backup_state] if args.key?(:last_backup_state)
  @last_successful_backup_consistency_time = args[:last_successful_backup_consistency_time] if args.key?(:last_successful_backup_consistency_time)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
end