Class: Google::Apis::BackupdrV1::RuleConfigInfo
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::RuleConfigInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Message for rules config info.
Instance Attribute Summary collapse
-
#last_backup_error ⇒ Google::Apis::BackupdrV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#last_backup_state ⇒ String
Output only.
-
#last_successful_backup_consistency_time ⇒ String
Output only.
-
#rule_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuleConfigInfo
constructor
A new instance of RuleConfigInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuleConfigInfo
Returns a new instance of RuleConfigInfo.
5440 5441 5442 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_backup_error ⇒ Google::Apis::BackupdrV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property lastBackupError
5422 5423 5424 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5422 def last_backup_error @last_backup_error end |
#last_backup_state ⇒ String
Output only. The last backup state for rule.
Corresponds to the JSON property lastBackupState
5427 5428 5429 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5427 def last_backup_state @last_backup_state end |
#last_successful_backup_consistency_time ⇒ String
Output only. The point in time when the last successful backup was captured
from the source.
Corresponds to the JSON property lastSuccessfulBackupConsistencyTime
5433 5434 5435 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5433 def last_successful_backup_consistency_time @last_successful_backup_consistency_time end |
#rule_id ⇒ String
Output only. Backup Rule id fetched from backup plan.
Corresponds to the JSON property ruleId
5438 5439 5440 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5438 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5445 5446 5447 5448 5449 5450 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5445 def update!(**args) @last_backup_error = args[:last_backup_error] if args.key?(:last_backup_error) @last_backup_state = args[:last_backup_state] if args.key?(:last_backup_state) @last_successful_backup_consistency_time = args[:last_successful_backup_consistency_time] if args.key?(:last_successful_backup_consistency_time) @rule_id = args[:rule_id] if args.key?(:rule_id) end |