Class: Google::Apis::BackupdrV1::Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::Scheduling
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Sets the scheduling options for an Instance.
Instance Attribute Summary collapse
-
#automatic_restart ⇒ Boolean
(also: #automatic_restart?)
Optional.
-
#instance_termination_action ⇒ String
Optional.
-
#local_ssd_recovery_timeout ⇒ Google::Apis::BackupdrV1::SchedulingDuration
A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#min_node_cpus ⇒ Fixnum
Optional.
-
#node_affinities ⇒ Array<Google::Apis::BackupdrV1::NodeAffinity>
Optional.
-
#on_host_maintenance ⇒ String
Optional.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Optional.
-
#provisioning_model ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scheduling
constructor
A new instance of Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scheduling
Returns a new instance of Scheduling.
5527 5528 5529 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_restart ⇒ Boolean Also known as: automatic_restart?
Optional. Specifies whether the instance should be automatically restarted if
it is terminated by Compute Engine (not terminated by a user).
Corresponds to the JSON property automaticRestart
5483 5484 5485 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5483 def automatic_restart @automatic_restart end |
#instance_termination_action ⇒ String
Optional. Specifies the termination action for the instance.
Corresponds to the JSON property instanceTerminationAction
5489 5490 5491 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5489 def instance_termination_action @instance_termination_action end |
#local_ssd_recovery_timeout ⇒ Google::Apis::BackupdrV1::SchedulingDuration
A SchedulingDuration represents a fixed-length span of time represented as a
count of seconds and fractions of seconds at nanosecond resolution. It is
independent of any calendar and concepts like "day" or "month". Range is
approximately 10,000 years.
Corresponds to the JSON property localSsdRecoveryTimeout
5497 5498 5499 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5497 def local_ssd_recovery_timeout @local_ssd_recovery_timeout end |
#min_node_cpus ⇒ Fixnum
Optional. The minimum number of virtual CPUs this instance will consume when
running on a sole-tenant node.
Corresponds to the JSON property minNodeCpus
5503 5504 5505 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5503 def min_node_cpus @min_node_cpus end |
#node_affinities ⇒ Array<Google::Apis::BackupdrV1::NodeAffinity>
Optional. A set of node affinity and anti-affinity configurations. Overrides
reservationAffinity.
Corresponds to the JSON property nodeAffinities
5509 5510 5511 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5509 def node_affinities @node_affinities end |
#on_host_maintenance ⇒ String
Optional. Defines the maintenance behavior for this instance.
Corresponds to the JSON property onHostMaintenance
5514 5515 5516 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5514 def on_host_maintenance @on_host_maintenance end |
#preemptible ⇒ Boolean Also known as: preemptible?
Optional. Defines whether the instance is preemptible.
Corresponds to the JSON property preemptible
5519 5520 5521 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5519 def preemptible @preemptible end |
#provisioning_model ⇒ String
Optional. Specifies the provisioning model of the instance.
Corresponds to the JSON property provisioningModel
5525 5526 5527 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5525 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5532 def update!(**args) @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart) @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action) @local_ssd_recovery_timeout = args[:local_ssd_recovery_timeout] if args.key?(:local_ssd_recovery_timeout) @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus) @node_affinities = args[:node_affinities] if args.key?(:node_affinities) @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance) @preemptible = args[:preemptible] if args.key?(:preemptible) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |