Class: Google::Apis::BackupdrV1::SchedulingDuration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingDuration

Returns a new instance of SchedulingDuration.



5638
5639
5640
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Optional. Span of time that's a fraction of a second at nanosecond resolution. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


5631
5632
5633
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5631

def nanos
  @nanos
end

#secondsFixnum

Optional. Span of time at a resolution of a second. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


5636
5637
5638
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5636

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5643
5644
5645
5646
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5643

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end