Class: Google::Apis::BackupdrV1::SchedulingDuration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingDuration

Returns a new instance of SchedulingDuration.



5539
5540
5541
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Optional. Span of time that's a fraction of a second at nanosecond resolution. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


5532
5533
5534
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5532

def nanos
  @nanos
end

#secondsFixnum

Optional. Span of time at a resolution of a second. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


5537
5538
5539
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5537

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5544
5545
5546
5547
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5544

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end