Class: Google::Apis::BackupdrV1::SchedulingDuration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb

Overview

A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingDuration

Returns a new instance of SchedulingDuration.



5473
5474
5475
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nanosFixnum

Optional. Span of time that's a fraction of a second at nanosecond resolution. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


5466
5467
5468
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5466

def nanos
  @nanos
end

#secondsFixnum

Optional. Span of time at a resolution of a second. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


5471
5472
5473
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5471

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5478
5479
5480
5481
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5478

def update!(**args)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end