Class: Google::Apis::BackupdrV1::SchedulingDuration
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::SchedulingDuration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
A SchedulingDuration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.
Instance Attribute Summary collapse
-
#nanos ⇒ Fixnum
Optional.
-
#seconds ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchedulingDuration
constructor
A new instance of SchedulingDuration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchedulingDuration
Returns a new instance of SchedulingDuration.
5448 5449 5450 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#nanos ⇒ Fixnum
Optional. Span of time that's a fraction of a second at nanosecond resolution.
Corresponds to the JSON property nanos
5441 5442 5443 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5441 def nanos @nanos end |
#seconds ⇒ Fixnum
Optional. Span of time at a resolution of a second.
Corresponds to the JSON property seconds
5446 5447 5448 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5446 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5453 5454 5455 5456 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5453 def update!(**args) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |