Class: Google::Apis::BackupdrV1::ServiceLockInfo
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::ServiceLockInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
ServiceLockInfo represents the details of a lock taken by the service on a Backup resource.
Instance Attribute Summary collapse
-
#operation ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceLockInfo
constructor
A new instance of ServiceLockInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceLockInfo
Returns a new instance of ServiceLockInfo.
5495 5496 5497 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ String
Output only. The name of the operation that created this lock. The lock will
automatically be released when the operation completes.
Corresponds to the JSON property operation
5493 5494 5495 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5493 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5500 5501 5502 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5500 def update!(**args) @operation = args[:operation] if args.key?(:operation) end |