Class: Google::Apis::BackupdrV1::SetInternalStatusRequest
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::SetInternalStatusRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Request message for SetStatusInternal method.
Instance Attribute Summary collapse
-
#backup_config_state ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#value ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetInternalStatusRequest
constructor
A new instance of SetInternalStatusRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetInternalStatusRequest
Returns a new instance of SetInternalStatusRequest.
5587 5588 5589 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5587 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_config_state ⇒ String
Required. Output only. The new BackupConfigState to set for the DataSource.
Corresponds to the JSON property backupConfigState
5565 5566 5567 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5565 def backup_config_state @backup_config_state end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. The request ID must be a
valid UUID with the exception that zero UUID is not supported (00000000-0000-
0000-0000-000000000000).
Corresponds to the JSON property requestId
5575 5576 5577 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5575 def request_id @request_id end |
#value ⇒ String
Required. The value required for this method to work. This field must be the
32-byte SHA256 hash of the DataSourceID. The DataSourceID used here is only
the final piece of the fully qualified resource path for this DataSource (i.e.
the part after '.../dataSources/'). This field exists to make this method
difficult to call since it is intended for use only by Backup Appliances.
Corresponds to the JSON property value
NOTE: Values are automatically base64 encoded/decoded in the client library.
5585 5586 5587 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5585 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5592 5593 5594 5595 5596 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5592 def update!(**args) @backup_config_state = args[:backup_config_state] if args.key?(:backup_config_state) @request_id = args[:request_id] if args.key?(:request_id) @value = args[:value] if args.key?(:value) end |