Class: Google::Apis::BackupdrV1::StandardSchedule
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::StandardSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
StandardSchedule defines a schedule that run within the confines of a
defined window of days. We can define recurrence type for schedule as HOURLY,
DAILY, WEEKLY, MONTHLY or YEARLY.
Instance Attribute Summary collapse
-
#backup_window ⇒ Google::Apis::BackupdrV1::BackupWindow
BackupWindowdefines a window of the day during which backup jobs will run. -
#days_of_month ⇒ Array<Fixnum>
Optional.
-
#days_of_week ⇒ Array<String>
Optional.
-
#hourly_frequency ⇒ Fixnum
Optional.
-
#months ⇒ Array<String>
Optional.
-
#recurrence_type ⇒ String
Required.
-
#time_zone ⇒ String
Required.
-
#week_day_of_month ⇒ Google::Apis::BackupdrV1::WeekDayOfMonth
WeekDayOfMonthdefines the week day of the month on which the backups will run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StandardSchedule
constructor
A new instance of StandardSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StandardSchedule
Returns a new instance of StandardSchedule.
5678 5679 5680 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_window ⇒ Google::Apis::BackupdrV1::BackupWindow
BackupWindow defines a window of the day during which backup jobs will run.
Corresponds to the JSON property backupWindow
5621 5622 5623 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5621 def backup_window @backup_window end |
#days_of_month ⇒ Array<Fixnum>
Optional. Specifies days of months like 1, 5, or 14 on which jobs will run.
Values for days_of_month are only applicable for recurrence_type, MONTHLY
and YEARLY. A validation error will occur if other values are supplied.
Corresponds to the JSON property daysOfMonth
5628 5629 5630 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5628 def days_of_month @days_of_month end |
#days_of_week ⇒ Array<String>
Optional. Specifies days of week like, MONDAY or TUESDAY, on which jobs will
run. This is required for recurrence_type, WEEKLY and is not applicable
otherwise. A validation error will occur if a value is supplied and
recurrence_type is not WEEKLY.
Corresponds to the JSON property daysOfWeek
5636 5637 5638 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5636 def days_of_week @days_of_week end |
#hourly_frequency ⇒ Fixnum
Optional. Specifies frequency for hourly backups. A hourly frequency of 2
means jobs will run every 2 hours from start time till end time defined. This
is required for recurrence_type, HOURLY and is not applicable otherwise. A
validation error will occur if a value is supplied and recurrence_type is
not HOURLY. Value of hourly frequency should be between 4 and 23. Reason for
limit : We found that there is bandwidth limitation of 3GB/S for GMI while
taking a backup and 5GB/S while doing a restore. Given the amount of parallel
backups and restore we are targeting, this will potentially take the backup
time to mins and hours (in worst case scenario).
Corresponds to the JSON property hourlyFrequency
5649 5650 5651 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5649 def hourly_frequency @hourly_frequency end |
#months ⇒ Array<String>
Optional. Specifies the months of year, like FEBRUARY and/or MAY, on which
jobs will run. This field is only applicable when recurrence_type is YEARLY
. A validation error will occur if other values are supplied.
Corresponds to the JSON property months
5656 5657 5658 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5656 def months @months end |
#recurrence_type ⇒ String
Required. Specifies the RecurrenceType for the schedule.
Corresponds to the JSON property recurrenceType
5661 5662 5663 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5661 def recurrence_type @recurrence_type end |
#time_zone ⇒ String
Required. The time zone to be used when interpreting the schedule. The value
of this field must be a time zone name from the IANA tz database. See https://
en.wikipedia.org/wiki/List_of_tz_database_time_zones for the list of valid
timezone names. For example, Europe/Paris.
Corresponds to the JSON property timeZone
5669 5670 5671 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5669 def time_zone @time_zone end |
#week_day_of_month ⇒ Google::Apis::BackupdrV1::WeekDayOfMonth
WeekDayOfMonth defines the week day of the month on which the backups will
run. The message combines a WeekOfMonth and DayOfWeek to produce values
like FIRST/MONDAY or LAST/FRIDAY.
Corresponds to the JSON property weekDayOfMonth
5676 5677 5678 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5676 def week_day_of_month @week_day_of_month end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5683 def update!(**args) @backup_window = args[:backup_window] if args.key?(:backup_window) @days_of_month = args[:days_of_month] if args.key?(:days_of_month) @days_of_week = args[:days_of_week] if args.key?(:days_of_week) @hourly_frequency = args[:hourly_frequency] if args.key?(:hourly_frequency) @months = args[:months] if args.key?(:months) @recurrence_type = args[:recurrence_type] if args.key?(:recurrence_type) @time_zone = args[:time_zone] if args.key?(:time_zone) @week_day_of_month = args[:week_day_of_month] if args.key?(:week_day_of_month) end |