Class: Google::Apis::BackupdrV1::TriggerBackupRequest
- Inherits:
-
Object
- Object
- Google::Apis::BackupdrV1::TriggerBackupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/backupdr_v1/classes.rb,
lib/google/apis/backupdr_v1/representations.rb,
lib/google/apis/backupdr_v1/representations.rb
Overview
Request message for triggering a backup.
Instance Attribute Summary collapse
-
#custom_retention_days ⇒ Fixnum
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#request_id ⇒ String
Optional.
-
#rule_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TriggerBackupRequest
constructor
A new instance of TriggerBackupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TriggerBackupRequest
Returns a new instance of TriggerBackupRequest.
5906 5907 5908 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_retention_days ⇒ Fixnum
Optional. The duration for which backup data will be kept, while taking an on-
demand backup with custom retention. It is defined in "days". It is mutually
exclusive with rule_id. This field is required if rule_id is not provided.
Corresponds to the JSON property customRetentionDays
5879 5880 5881 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5879 def custom_retention_days @custom_retention_days end |
#labels ⇒ Hash<String,String>
Optional. Labels to be applied on the backup.
Corresponds to the JSON property labels
5884 5885 5886 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5884 def labels @labels end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
5898 5899 5900 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5898 def request_id @request_id end |
#rule_id ⇒ String
Optional. backup rule_id for which a backup needs to be triggered. If not
specified, on-demand backup with custom retention will be triggered.
Corresponds to the JSON property ruleId
5904 5905 5906 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5904 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5911 5912 5913 5914 5915 5916 |
# File 'lib/google/apis/backupdr_v1/classes.rb', line 5911 def update!(**args) @custom_retention_days = args[:custom_retention_days] if args.key?(:custom_retention_days) @labels = args[:labels] if args.key?(:labels) @request_id = args[:request_id] if args.key?(:request_id) @rule_id = args[:rule_id] if args.key?(:rule_id) end |